# Autogenerated by get_module_idx.py

d = { 'syms': { 'torch': { 'torch.__config__': 'https://pytorch.org/docs/stable/__config__.html#module-torch.__config__',
                       'torch.autograd': 'https://pytorch.org/docs/stable/autograd.html#module-torch.autograd',
                       'torch.cuda': 'https://pytorch.org/docs/stable/cuda.html#module-torch.cuda',
                       'torch.distributed': 'https://pytorch.org/docs/stable/distributed.html#module-torch.distributed',
                       'torch.distributions': 'https://pytorch.org/docs/stable/distributions.html#module-torch.distributions',
                       'torch.futures': 'https://pytorch.org/docs/stable/futures.html#module-torch.futures',
                       'torch.fx': 'https://pytorch.org/docs/stable/fx.html#module-torch.fx',
                       'torch.hub': 'https://pytorch.org/docs/stable/hub.html#module-torch.hub',
                       'torch.jit': 'https://pytorch.org/docs/stable/jit.html#module-torch.jit',
                       'torch.linalg': 'https://pytorch.org/docs/stable/linalg.html#module-torch.linalg',
                       'torch.monitor': 'https://pytorch.org/docs/stable/monitor.html#module-torch.monitor',
                       'torch.multiprocessing': 'https://pytorch.org/docs/stable/multiprocessing.html#module-torch.multiprocessing',
                       'torch.onnx': 'https://pytorch.org/docs/stable/onnx.html#module-torch.onnx',
                       'torch.optim': 'https://pytorch.org/docs/stable/optim.html#module-torch.optim',
                       'torch.profiler': 'https://pytorch.org/docs/stable/profiler.html#module-torch.profiler',
                       'torch.random': 'https://pytorch.org/docs/stable/random.html#module-torch.random',
                       'torch.testing': 'https://pytorch.org/docs/stable/testing.html#module-torch.testing',
                       'torch.BFloat16Storage': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage',
                       'torch.BoolStorage': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage',
                       'torch.ByteStorage': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage',
                       'torch.CharStorage': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage',
                       'torch.ComplexDoubleStorage': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage',
                       'torch.ComplexFloatStorage': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage',
                       'torch.DoubleStorage': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage',
                       'torch.FloatStorage': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage',
                       'torch.Generator': 'https://pytorch.org/docs/stable/generated/torch.Generator.html#torch.Generator',
                       'torch.HalfStorage': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage',
                       'torch.IntStorage': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage',
                       'torch.LongStorage': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage',
                       'torch.QInt32Storage': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage',
                       'torch.QInt8Storage': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage',
                       'torch.QUInt4x2Storage': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage',
                       'torch.QUInt8Storage': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage',
                       'torch.ShortStorage': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage',
                       'torch.Tensor': 'https://pytorch.org/docs/stable/tensors.html#torch.Tensor',
                       'torch.autocast': 'https://pytorch.org/docs/stable/amp.html#torch.autocast',
                       'torch.enable_grad': 'https://pytorch.org/docs/stable/generated/torch.enable_grad.html#torch.enable_grad',
                       'torch.inference_mode': 'https://pytorch.org/docs/stable/generated/torch.inference_mode.html#torch.inference_mode',
                       'torch.no_grad': 'https://pytorch.org/docs/stable/generated/torch.no_grad.html#torch.no_grad',
                       'torch.set_grad_enabled': 'https://pytorch.org/docs/stable/generated/torch.set_grad_enabled.html#torch.set_grad_enabled',
                       'torch.BFloat16Storage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.bfloat16',
                       'torch.BFloat16Storage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.bool',
                       'torch.BFloat16Storage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.byte',
                       'torch.BFloat16Storage.char': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.char',
                       'torch.BFloat16Storage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.clone',
                       'torch.BFloat16Storage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.complex_double',
                       'torch.BFloat16Storage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.complex_float',
                       'torch.BFloat16Storage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.copy_',
                       'torch.BFloat16Storage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.cpu',
                       'torch.BFloat16Storage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.cuda',
                       'torch.BFloat16Storage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.data_ptr',
                       'torch.BFloat16Storage.device': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.device',
                       'torch.BFloat16Storage.double': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.double',
                       'torch.BFloat16Storage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.element_size',
                       'torch.BFloat16Storage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.fill_',
                       'torch.BFloat16Storage.float': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.float',
                       'torch.BFloat16Storage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.from_buffer',
                       'torch.BFloat16Storage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.from_file',
                       'torch.BFloat16Storage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.get_device',
                       'torch.BFloat16Storage.half': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.half',
                       'torch.BFloat16Storage.int': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.int',
                       'torch.BFloat16Storage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.is_cuda',
                       'torch.BFloat16Storage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.is_pinned',
                       'torch.BFloat16Storage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.is_shared',
                       'torch.BFloat16Storage.long': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.long',
                       'torch.BFloat16Storage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.nbytes',
                       'torch.BFloat16Storage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.pickle_storage_type',
                       'torch.BFloat16Storage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.pin_memory',
                       'torch.BFloat16Storage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.resize_',
                       'torch.BFloat16Storage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.share_memory_',
                       'torch.BFloat16Storage.short': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.short',
                       'torch.BFloat16Storage.size': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.size',
                       'torch.BFloat16Storage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.tolist',
                       'torch.BFloat16Storage.type': 'https://pytorch.org/docs/stable/storage.html#torch.BFloat16Storage.type',
                       'torch.BoolStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.bfloat16',
                       'torch.BoolStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.bool',
                       'torch.BoolStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.byte',
                       'torch.BoolStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.char',
                       'torch.BoolStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.clone',
                       'torch.BoolStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.complex_double',
                       'torch.BoolStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.complex_float',
                       'torch.BoolStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.copy_',
                       'torch.BoolStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.cpu',
                       'torch.BoolStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.cuda',
                       'torch.BoolStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.data_ptr',
                       'torch.BoolStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.device',
                       'torch.BoolStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.double',
                       'torch.BoolStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.element_size',
                       'torch.BoolStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.fill_',
                       'torch.BoolStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.float',
                       'torch.BoolStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.from_buffer',
                       'torch.BoolStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.from_file',
                       'torch.BoolStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.get_device',
                       'torch.BoolStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.half',
                       'torch.BoolStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.int',
                       'torch.BoolStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.is_cuda',
                       'torch.BoolStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.is_pinned',
                       'torch.BoolStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.is_shared',
                       'torch.BoolStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.long',
                       'torch.BoolStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.nbytes',
                       'torch.BoolStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.pickle_storage_type',
                       'torch.BoolStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.pin_memory',
                       'torch.BoolStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.resize_',
                       'torch.BoolStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.share_memory_',
                       'torch.BoolStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.short',
                       'torch.BoolStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.size',
                       'torch.BoolStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.tolist',
                       'torch.BoolStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.BoolStorage.type',
                       'torch.ByteStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.bfloat16',
                       'torch.ByteStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.bool',
                       'torch.ByteStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.byte',
                       'torch.ByteStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.char',
                       'torch.ByteStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.clone',
                       'torch.ByteStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.complex_double',
                       'torch.ByteStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.complex_float',
                       'torch.ByteStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.copy_',
                       'torch.ByteStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.cpu',
                       'torch.ByteStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.cuda',
                       'torch.ByteStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.data_ptr',
                       'torch.ByteStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.device',
                       'torch.ByteStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.double',
                       'torch.ByteStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.element_size',
                       'torch.ByteStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.fill_',
                       'torch.ByteStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.float',
                       'torch.ByteStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.from_buffer',
                       'torch.ByteStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.from_file',
                       'torch.ByteStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.get_device',
                       'torch.ByteStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.half',
                       'torch.ByteStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.int',
                       'torch.ByteStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.is_cuda',
                       'torch.ByteStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.is_pinned',
                       'torch.ByteStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.is_shared',
                       'torch.ByteStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.long',
                       'torch.ByteStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.nbytes',
                       'torch.ByteStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.pickle_storage_type',
                       'torch.ByteStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.pin_memory',
                       'torch.ByteStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.resize_',
                       'torch.ByteStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.share_memory_',
                       'torch.ByteStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.short',
                       'torch.ByteStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.size',
                       'torch.ByteStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.tolist',
                       'torch.ByteStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.ByteStorage.type',
                       'torch.CharStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.bfloat16',
                       'torch.CharStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.bool',
                       'torch.CharStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.byte',
                       'torch.CharStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.char',
                       'torch.CharStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.clone',
                       'torch.CharStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.complex_double',
                       'torch.CharStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.complex_float',
                       'torch.CharStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.copy_',
                       'torch.CharStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.cpu',
                       'torch.CharStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.cuda',
                       'torch.CharStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.data_ptr',
                       'torch.CharStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.device',
                       'torch.CharStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.double',
                       'torch.CharStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.element_size',
                       'torch.CharStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.fill_',
                       'torch.CharStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.float',
                       'torch.CharStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.from_buffer',
                       'torch.CharStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.from_file',
                       'torch.CharStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.get_device',
                       'torch.CharStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.half',
                       'torch.CharStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.int',
                       'torch.CharStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.is_cuda',
                       'torch.CharStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.is_pinned',
                       'torch.CharStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.is_shared',
                       'torch.CharStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.long',
                       'torch.CharStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.nbytes',
                       'torch.CharStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.pickle_storage_type',
                       'torch.CharStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.pin_memory',
                       'torch.CharStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.resize_',
                       'torch.CharStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.share_memory_',
                       'torch.CharStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.short',
                       'torch.CharStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.size',
                       'torch.CharStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.tolist',
                       'torch.CharStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.CharStorage.type',
                       'torch.ComplexDoubleStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.bfloat16',
                       'torch.ComplexDoubleStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.bool',
                       'torch.ComplexDoubleStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.byte',
                       'torch.ComplexDoubleStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.char',
                       'torch.ComplexDoubleStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.clone',
                       'torch.ComplexDoubleStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.complex_double',
                       'torch.ComplexDoubleStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.complex_float',
                       'torch.ComplexDoubleStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.copy_',
                       'torch.ComplexDoubleStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.cpu',
                       'torch.ComplexDoubleStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.cuda',
                       'torch.ComplexDoubleStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.data_ptr',
                       'torch.ComplexDoubleStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.device',
                       'torch.ComplexDoubleStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.double',
                       'torch.ComplexDoubleStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.element_size',
                       'torch.ComplexDoubleStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.fill_',
                       'torch.ComplexDoubleStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.float',
                       'torch.ComplexDoubleStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.from_buffer',
                       'torch.ComplexDoubleStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.from_file',
                       'torch.ComplexDoubleStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.get_device',
                       'torch.ComplexDoubleStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.half',
                       'torch.ComplexDoubleStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.int',
                       'torch.ComplexDoubleStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.is_cuda',
                       'torch.ComplexDoubleStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.is_pinned',
                       'torch.ComplexDoubleStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.is_shared',
                       'torch.ComplexDoubleStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.long',
                       'torch.ComplexDoubleStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.nbytes',
                       'torch.ComplexDoubleStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.pickle_storage_type',
                       'torch.ComplexDoubleStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.pin_memory',
                       'torch.ComplexDoubleStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.resize_',
                       'torch.ComplexDoubleStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.share_memory_',
                       'torch.ComplexDoubleStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.short',
                       'torch.ComplexDoubleStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.size',
                       'torch.ComplexDoubleStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.tolist',
                       'torch.ComplexDoubleStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexDoubleStorage.type',
                       'torch.ComplexFloatStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.bfloat16',
                       'torch.ComplexFloatStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.bool',
                       'torch.ComplexFloatStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.byte',
                       'torch.ComplexFloatStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.char',
                       'torch.ComplexFloatStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.clone',
                       'torch.ComplexFloatStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.complex_double',
                       'torch.ComplexFloatStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.complex_float',
                       'torch.ComplexFloatStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.copy_',
                       'torch.ComplexFloatStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.cpu',
                       'torch.ComplexFloatStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.cuda',
                       'torch.ComplexFloatStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.data_ptr',
                       'torch.ComplexFloatStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.device',
                       'torch.ComplexFloatStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.double',
                       'torch.ComplexFloatStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.element_size',
                       'torch.ComplexFloatStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.fill_',
                       'torch.ComplexFloatStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.float',
                       'torch.ComplexFloatStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.from_buffer',
                       'torch.ComplexFloatStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.from_file',
                       'torch.ComplexFloatStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.get_device',
                       'torch.ComplexFloatStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.half',
                       'torch.ComplexFloatStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.int',
                       'torch.ComplexFloatStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.is_cuda',
                       'torch.ComplexFloatStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.is_pinned',
                       'torch.ComplexFloatStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.is_shared',
                       'torch.ComplexFloatStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.long',
                       'torch.ComplexFloatStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.nbytes',
                       'torch.ComplexFloatStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.pickle_storage_type',
                       'torch.ComplexFloatStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.pin_memory',
                       'torch.ComplexFloatStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.resize_',
                       'torch.ComplexFloatStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.share_memory_',
                       'torch.ComplexFloatStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.short',
                       'torch.ComplexFloatStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.size',
                       'torch.ComplexFloatStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.tolist',
                       'torch.ComplexFloatStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.ComplexFloatStorage.type',
                       'torch.DoubleStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.bfloat16',
                       'torch.DoubleStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.bool',
                       'torch.DoubleStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.byte',
                       'torch.DoubleStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.char',
                       'torch.DoubleStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.clone',
                       'torch.DoubleStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.complex_double',
                       'torch.DoubleStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.complex_float',
                       'torch.DoubleStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.copy_',
                       'torch.DoubleStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.cpu',
                       'torch.DoubleStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.cuda',
                       'torch.DoubleStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.data_ptr',
                       'torch.DoubleStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.device',
                       'torch.DoubleStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.double',
                       'torch.DoubleStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.element_size',
                       'torch.DoubleStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.fill_',
                       'torch.DoubleStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.float',
                       'torch.DoubleStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.from_buffer',
                       'torch.DoubleStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.from_file',
                       'torch.DoubleStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.get_device',
                       'torch.DoubleStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.half',
                       'torch.DoubleStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.int',
                       'torch.DoubleStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.is_cuda',
                       'torch.DoubleStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.is_pinned',
                       'torch.DoubleStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.is_shared',
                       'torch.DoubleStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.long',
                       'torch.DoubleStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.nbytes',
                       'torch.DoubleStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.pickle_storage_type',
                       'torch.DoubleStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.pin_memory',
                       'torch.DoubleStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.resize_',
                       'torch.DoubleStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.share_memory_',
                       'torch.DoubleStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.short',
                       'torch.DoubleStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.size',
                       'torch.DoubleStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.tolist',
                       'torch.DoubleStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.DoubleStorage.type',
                       'torch.FloatStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.bfloat16',
                       'torch.FloatStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.bool',
                       'torch.FloatStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.byte',
                       'torch.FloatStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.char',
                       'torch.FloatStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.clone',
                       'torch.FloatStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.complex_double',
                       'torch.FloatStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.complex_float',
                       'torch.FloatStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.copy_',
                       'torch.FloatStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.cpu',
                       'torch.FloatStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.cuda',
                       'torch.FloatStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.data_ptr',
                       'torch.FloatStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.device',
                       'torch.FloatStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.double',
                       'torch.FloatStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.element_size',
                       'torch.FloatStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.fill_',
                       'torch.FloatStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.float',
                       'torch.FloatStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.from_buffer',
                       'torch.FloatStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.from_file',
                       'torch.FloatStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.get_device',
                       'torch.FloatStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.half',
                       'torch.FloatStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.int',
                       'torch.FloatStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.is_cuda',
                       'torch.FloatStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.is_pinned',
                       'torch.FloatStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.is_shared',
                       'torch.FloatStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.long',
                       'torch.FloatStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.nbytes',
                       'torch.FloatStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.pickle_storage_type',
                       'torch.FloatStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.pin_memory',
                       'torch.FloatStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.resize_',
                       'torch.FloatStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.share_memory_',
                       'torch.FloatStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.short',
                       'torch.FloatStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.size',
                       'torch.FloatStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.tolist',
                       'torch.FloatStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.FloatStorage.type',
                       'torch.Generator.get_state': 'https://pytorch.org/docs/stable/generated/torch.Generator.html#torch.Generator.get_state',
                       'torch.Generator.initial_seed': 'https://pytorch.org/docs/stable/generated/torch.Generator.html#torch.Generator.initial_seed',
                       'torch.Generator.manual_seed': 'https://pytorch.org/docs/stable/generated/torch.Generator.html#torch.Generator.manual_seed',
                       'torch.Generator.seed': 'https://pytorch.org/docs/stable/generated/torch.Generator.html#torch.Generator.seed',
                       'torch.Generator.set_state': 'https://pytorch.org/docs/stable/generated/torch.Generator.html#torch.Generator.set_state',
                       'torch.HalfStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.bfloat16',
                       'torch.HalfStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.bool',
                       'torch.HalfStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.byte',
                       'torch.HalfStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.char',
                       'torch.HalfStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.clone',
                       'torch.HalfStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.complex_double',
                       'torch.HalfStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.complex_float',
                       'torch.HalfStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.copy_',
                       'torch.HalfStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.cpu',
                       'torch.HalfStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.cuda',
                       'torch.HalfStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.data_ptr',
                       'torch.HalfStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.device',
                       'torch.HalfStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.double',
                       'torch.HalfStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.element_size',
                       'torch.HalfStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.fill_',
                       'torch.HalfStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.float',
                       'torch.HalfStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.from_buffer',
                       'torch.HalfStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.from_file',
                       'torch.HalfStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.get_device',
                       'torch.HalfStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.half',
                       'torch.HalfStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.int',
                       'torch.HalfStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.is_cuda',
                       'torch.HalfStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.is_pinned',
                       'torch.HalfStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.is_shared',
                       'torch.HalfStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.long',
                       'torch.HalfStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.nbytes',
                       'torch.HalfStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.pickle_storage_type',
                       'torch.HalfStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.pin_memory',
                       'torch.HalfStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.resize_',
                       'torch.HalfStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.share_memory_',
                       'torch.HalfStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.short',
                       'torch.HalfStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.size',
                       'torch.HalfStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.tolist',
                       'torch.HalfStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.HalfStorage.type',
                       'torch.IntStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.bfloat16',
                       'torch.IntStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.bool',
                       'torch.IntStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.byte',
                       'torch.IntStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.char',
                       'torch.IntStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.clone',
                       'torch.IntStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.complex_double',
                       'torch.IntStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.complex_float',
                       'torch.IntStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.copy_',
                       'torch.IntStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.cpu',
                       'torch.IntStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.cuda',
                       'torch.IntStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.data_ptr',
                       'torch.IntStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.device',
                       'torch.IntStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.double',
                       'torch.IntStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.element_size',
                       'torch.IntStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.fill_',
                       'torch.IntStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.float',
                       'torch.IntStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.from_buffer',
                       'torch.IntStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.from_file',
                       'torch.IntStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.get_device',
                       'torch.IntStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.half',
                       'torch.IntStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.int',
                       'torch.IntStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.is_cuda',
                       'torch.IntStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.is_pinned',
                       'torch.IntStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.is_shared',
                       'torch.IntStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.long',
                       'torch.IntStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.nbytes',
                       'torch.IntStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.pickle_storage_type',
                       'torch.IntStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.pin_memory',
                       'torch.IntStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.resize_',
                       'torch.IntStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.share_memory_',
                       'torch.IntStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.short',
                       'torch.IntStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.size',
                       'torch.IntStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.tolist',
                       'torch.IntStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.IntStorage.type',
                       'torch.LongStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.bfloat16',
                       'torch.LongStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.bool',
                       'torch.LongStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.byte',
                       'torch.LongStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.char',
                       'torch.LongStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.clone',
                       'torch.LongStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.complex_double',
                       'torch.LongStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.complex_float',
                       'torch.LongStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.copy_',
                       'torch.LongStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.cpu',
                       'torch.LongStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.cuda',
                       'torch.LongStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.data_ptr',
                       'torch.LongStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.device',
                       'torch.LongStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.double',
                       'torch.LongStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.element_size',
                       'torch.LongStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.fill_',
                       'torch.LongStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.float',
                       'torch.LongStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.from_buffer',
                       'torch.LongStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.from_file',
                       'torch.LongStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.get_device',
                       'torch.LongStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.half',
                       'torch.LongStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.int',
                       'torch.LongStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.is_cuda',
                       'torch.LongStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.is_pinned',
                       'torch.LongStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.is_shared',
                       'torch.LongStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.long',
                       'torch.LongStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.nbytes',
                       'torch.LongStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.pickle_storage_type',
                       'torch.LongStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.pin_memory',
                       'torch.LongStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.resize_',
                       'torch.LongStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.share_memory_',
                       'torch.LongStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.short',
                       'torch.LongStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.size',
                       'torch.LongStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.tolist',
                       'torch.LongStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.LongStorage.type',
                       'torch.QInt32Storage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.bfloat16',
                       'torch.QInt32Storage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.bool',
                       'torch.QInt32Storage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.byte',
                       'torch.QInt32Storage.char': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.char',
                       'torch.QInt32Storage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.clone',
                       'torch.QInt32Storage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.complex_double',
                       'torch.QInt32Storage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.complex_float',
                       'torch.QInt32Storage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.copy_',
                       'torch.QInt32Storage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.cpu',
                       'torch.QInt32Storage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.cuda',
                       'torch.QInt32Storage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.data_ptr',
                       'torch.QInt32Storage.device': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.device',
                       'torch.QInt32Storage.double': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.double',
                       'torch.QInt32Storage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.element_size',
                       'torch.QInt32Storage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.fill_',
                       'torch.QInt32Storage.float': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.float',
                       'torch.QInt32Storage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.from_buffer',
                       'torch.QInt32Storage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.from_file',
                       'torch.QInt32Storage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.get_device',
                       'torch.QInt32Storage.half': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.half',
                       'torch.QInt32Storage.int': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.int',
                       'torch.QInt32Storage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.is_cuda',
                       'torch.QInt32Storage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.is_pinned',
                       'torch.QInt32Storage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.is_shared',
                       'torch.QInt32Storage.long': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.long',
                       'torch.QInt32Storage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.nbytes',
                       'torch.QInt32Storage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.pickle_storage_type',
                       'torch.QInt32Storage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.pin_memory',
                       'torch.QInt32Storage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.resize_',
                       'torch.QInt32Storage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.share_memory_',
                       'torch.QInt32Storage.short': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.short',
                       'torch.QInt32Storage.size': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.size',
                       'torch.QInt32Storage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.tolist',
                       'torch.QInt32Storage.type': 'https://pytorch.org/docs/stable/storage.html#torch.QInt32Storage.type',
                       'torch.QInt8Storage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.bfloat16',
                       'torch.QInt8Storage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.bool',
                       'torch.QInt8Storage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.byte',
                       'torch.QInt8Storage.char': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.char',
                       'torch.QInt8Storage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.clone',
                       'torch.QInt8Storage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.complex_double',
                       'torch.QInt8Storage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.complex_float',
                       'torch.QInt8Storage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.copy_',
                       'torch.QInt8Storage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.cpu',
                       'torch.QInt8Storage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.cuda',
                       'torch.QInt8Storage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.data_ptr',
                       'torch.QInt8Storage.device': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.device',
                       'torch.QInt8Storage.double': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.double',
                       'torch.QInt8Storage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.element_size',
                       'torch.QInt8Storage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.fill_',
                       'torch.QInt8Storage.float': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.float',
                       'torch.QInt8Storage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.from_buffer',
                       'torch.QInt8Storage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.from_file',
                       'torch.QInt8Storage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.get_device',
                       'torch.QInt8Storage.half': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.half',
                       'torch.QInt8Storage.int': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.int',
                       'torch.QInt8Storage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.is_cuda',
                       'torch.QInt8Storage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.is_pinned',
                       'torch.QInt8Storage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.is_shared',
                       'torch.QInt8Storage.long': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.long',
                       'torch.QInt8Storage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.nbytes',
                       'torch.QInt8Storage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.pickle_storage_type',
                       'torch.QInt8Storage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.pin_memory',
                       'torch.QInt8Storage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.resize_',
                       'torch.QInt8Storage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.share_memory_',
                       'torch.QInt8Storage.short': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.short',
                       'torch.QInt8Storage.size': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.size',
                       'torch.QInt8Storage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.tolist',
                       'torch.QInt8Storage.type': 'https://pytorch.org/docs/stable/storage.html#torch.QInt8Storage.type',
                       'torch.QUInt4x2Storage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.bfloat16',
                       'torch.QUInt4x2Storage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.bool',
                       'torch.QUInt4x2Storage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.byte',
                       'torch.QUInt4x2Storage.char': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.char',
                       'torch.QUInt4x2Storage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.clone',
                       'torch.QUInt4x2Storage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.complex_double',
                       'torch.QUInt4x2Storage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.complex_float',
                       'torch.QUInt4x2Storage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.copy_',
                       'torch.QUInt4x2Storage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.cpu',
                       'torch.QUInt4x2Storage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.cuda',
                       'torch.QUInt4x2Storage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.data_ptr',
                       'torch.QUInt4x2Storage.device': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.device',
                       'torch.QUInt4x2Storage.double': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.double',
                       'torch.QUInt4x2Storage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.element_size',
                       'torch.QUInt4x2Storage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.fill_',
                       'torch.QUInt4x2Storage.float': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.float',
                       'torch.QUInt4x2Storage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.from_buffer',
                       'torch.QUInt4x2Storage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.from_file',
                       'torch.QUInt4x2Storage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.get_device',
                       'torch.QUInt4x2Storage.half': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.half',
                       'torch.QUInt4x2Storage.int': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.int',
                       'torch.QUInt4x2Storage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.is_cuda',
                       'torch.QUInt4x2Storage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.is_pinned',
                       'torch.QUInt4x2Storage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.is_shared',
                       'torch.QUInt4x2Storage.long': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.long',
                       'torch.QUInt4x2Storage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.nbytes',
                       'torch.QUInt4x2Storage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.pickle_storage_type',
                       'torch.QUInt4x2Storage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.pin_memory',
                       'torch.QUInt4x2Storage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.resize_',
                       'torch.QUInt4x2Storage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.share_memory_',
                       'torch.QUInt4x2Storage.short': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.short',
                       'torch.QUInt4x2Storage.size': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.size',
                       'torch.QUInt4x2Storage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.tolist',
                       'torch.QUInt4x2Storage.type': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt4x2Storage.type',
                       'torch.QUInt8Storage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.bfloat16',
                       'torch.QUInt8Storage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.bool',
                       'torch.QUInt8Storage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.byte',
                       'torch.QUInt8Storage.char': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.char',
                       'torch.QUInt8Storage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.clone',
                       'torch.QUInt8Storage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.complex_double',
                       'torch.QUInt8Storage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.complex_float',
                       'torch.QUInt8Storage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.copy_',
                       'torch.QUInt8Storage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.cpu',
                       'torch.QUInt8Storage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.cuda',
                       'torch.QUInt8Storage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.data_ptr',
                       'torch.QUInt8Storage.device': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.device',
                       'torch.QUInt8Storage.double': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.double',
                       'torch.QUInt8Storage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.element_size',
                       'torch.QUInt8Storage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.fill_',
                       'torch.QUInt8Storage.float': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.float',
                       'torch.QUInt8Storage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.from_buffer',
                       'torch.QUInt8Storage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.from_file',
                       'torch.QUInt8Storage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.get_device',
                       'torch.QUInt8Storage.half': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.half',
                       'torch.QUInt8Storage.int': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.int',
                       'torch.QUInt8Storage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.is_cuda',
                       'torch.QUInt8Storage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.is_pinned',
                       'torch.QUInt8Storage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.is_shared',
                       'torch.QUInt8Storage.long': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.long',
                       'torch.QUInt8Storage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.nbytes',
                       'torch.QUInt8Storage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.pickle_storage_type',
                       'torch.QUInt8Storage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.pin_memory',
                       'torch.QUInt8Storage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.resize_',
                       'torch.QUInt8Storage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.share_memory_',
                       'torch.QUInt8Storage.short': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.short',
                       'torch.QUInt8Storage.size': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.size',
                       'torch.QUInt8Storage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.tolist',
                       'torch.QUInt8Storage.type': 'https://pytorch.org/docs/stable/storage.html#torch.QUInt8Storage.type',
                       'torch.ShortStorage.bfloat16': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.bfloat16',
                       'torch.ShortStorage.bool': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.bool',
                       'torch.ShortStorage.byte': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.byte',
                       'torch.ShortStorage.char': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.char',
                       'torch.ShortStorage.clone': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.clone',
                       'torch.ShortStorage.complex_double': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.complex_double',
                       'torch.ShortStorage.complex_float': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.complex_float',
                       'torch.ShortStorage.copy_': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.copy_',
                       'torch.ShortStorage.cpu': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.cpu',
                       'torch.ShortStorage.cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.cuda',
                       'torch.ShortStorage.data_ptr': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.data_ptr',
                       'torch.ShortStorage.device': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.device',
                       'torch.ShortStorage.double': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.double',
                       'torch.ShortStorage.element_size': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.element_size',
                       'torch.ShortStorage.fill_': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.fill_',
                       'torch.ShortStorage.float': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.float',
                       'torch.ShortStorage.from_buffer': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.from_buffer',
                       'torch.ShortStorage.from_file': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.from_file',
                       'torch.ShortStorage.get_device': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.get_device',
                       'torch.ShortStorage.half': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.half',
                       'torch.ShortStorage.int': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.int',
                       'torch.ShortStorage.is_cuda': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.is_cuda',
                       'torch.ShortStorage.is_pinned': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.is_pinned',
                       'torch.ShortStorage.is_shared': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.is_shared',
                       'torch.ShortStorage.long': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.long',
                       'torch.ShortStorage.nbytes': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.nbytes',
                       'torch.ShortStorage.pickle_storage_type': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.pickle_storage_type',
                       'torch.ShortStorage.pin_memory': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.pin_memory',
                       'torch.ShortStorage.resize_': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.resize_',
                       'torch.ShortStorage.share_memory_': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.share_memory_',
                       'torch.ShortStorage.short': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.short',
                       'torch.ShortStorage.size': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.size',
                       'torch.ShortStorage.tolist': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.tolist',
                       'torch.ShortStorage.type': 'https://pytorch.org/docs/stable/storage.html#torch.ShortStorage.type',
                       'torch.Tensor.abs': 'https://pytorch.org/docs/stable/generated/torch.Tensor.abs.html#torch.Tensor.abs',
                       'torch.Tensor.abs_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.abs_.html#torch.Tensor.abs_',
                       'torch.Tensor.absolute': 'https://pytorch.org/docs/stable/generated/torch.Tensor.absolute.html#torch.Tensor.absolute',
                       'torch.Tensor.absolute_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.absolute_.html#torch.Tensor.absolute_',
                       'torch.Tensor.acos': 'https://pytorch.org/docs/stable/generated/torch.Tensor.acos.html#torch.Tensor.acos',
                       'torch.Tensor.acos_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.acos_.html#torch.Tensor.acos_',
                       'torch.Tensor.acosh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.acosh.html#torch.Tensor.acosh',
                       'torch.Tensor.acosh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.acosh_.html#torch.Tensor.acosh_',
                       'torch.Tensor.add': 'https://pytorch.org/docs/stable/generated/torch.Tensor.add.html#torch.Tensor.add',
                       'torch.Tensor.add_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.add_.html#torch.Tensor.add_',
                       'torch.Tensor.addbmm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addbmm.html#torch.Tensor.addbmm',
                       'torch.Tensor.addbmm_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addbmm_.html#torch.Tensor.addbmm_',
                       'torch.Tensor.addcdiv': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addcdiv.html#torch.Tensor.addcdiv',
                       'torch.Tensor.addcdiv_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addcdiv_.html#torch.Tensor.addcdiv_',
                       'torch.Tensor.addcmul': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addcmul.html#torch.Tensor.addcmul',
                       'torch.Tensor.addcmul_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addcmul_.html#torch.Tensor.addcmul_',
                       'torch.Tensor.addmm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addmm.html#torch.Tensor.addmm',
                       'torch.Tensor.addmm_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addmm_.html#torch.Tensor.addmm_',
                       'torch.Tensor.addmv': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addmv.html#torch.Tensor.addmv',
                       'torch.Tensor.addmv_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addmv_.html#torch.Tensor.addmv_',
                       'torch.Tensor.addr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addr.html#torch.Tensor.addr',
                       'torch.Tensor.addr_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.addr_.html#torch.Tensor.addr_',
                       'torch.Tensor.adjoint': 'https://pytorch.org/docs/stable/generated/torch.Tensor.adjoint.html#torch.Tensor.adjoint',
                       'torch.Tensor.align_as': 'https://pytorch.org/docs/stable/named_tensor.html#torch.Tensor.align_as',
                       'torch.Tensor.align_to': 'https://pytorch.org/docs/stable/named_tensor.html#torch.Tensor.align_to',
                       'torch.Tensor.all': 'https://pytorch.org/docs/stable/generated/torch.Tensor.all.html#torch.Tensor.all',
                       'torch.Tensor.allclose': 'https://pytorch.org/docs/stable/generated/torch.Tensor.allclose.html#torch.Tensor.allclose',
                       'torch.Tensor.amax': 'https://pytorch.org/docs/stable/generated/torch.Tensor.amax.html#torch.Tensor.amax',
                       'torch.Tensor.amin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.amin.html#torch.Tensor.amin',
                       'torch.Tensor.aminmax': 'https://pytorch.org/docs/stable/generated/torch.Tensor.aminmax.html#torch.Tensor.aminmax',
                       'torch.Tensor.angle': 'https://pytorch.org/docs/stable/generated/torch.Tensor.angle.html#torch.Tensor.angle',
                       'torch.Tensor.any': 'https://pytorch.org/docs/stable/generated/torch.Tensor.any.html#torch.Tensor.any',
                       'torch.Tensor.apply_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.apply_.html#torch.Tensor.apply_',
                       'torch.Tensor.arccos': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arccos.html#torch.Tensor.arccos',
                       'torch.Tensor.arccos_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arccos_.html#torch.Tensor.arccos_',
                       'torch.Tensor.arccosh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arccosh.html#torch.Tensor.arccosh',
                       'torch.Tensor.arccosh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arccosh_.html#torch.Tensor.arccosh_',
                       'torch.Tensor.arcsin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arcsin.html#torch.Tensor.arcsin',
                       'torch.Tensor.arcsin_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arcsin_.html#torch.Tensor.arcsin_',
                       'torch.Tensor.arcsinh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arcsinh.html#torch.Tensor.arcsinh',
                       'torch.Tensor.arcsinh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arcsinh_.html#torch.Tensor.arcsinh_',
                       'torch.Tensor.arctan': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arctan.html#torch.Tensor.arctan',
                       'torch.Tensor.arctan2': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arctan2.html#torch.Tensor.arctan2',
                       'torch.Tensor.arctan2_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arctan2_.html#torch.Tensor.arctan2_',
                       'torch.Tensor.arctan_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arctan_.html#torch.Tensor.arctan_',
                       'torch.Tensor.arctanh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arctanh.html#torch.Tensor.arctanh',
                       'torch.Tensor.arctanh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.arctanh_.html#torch.Tensor.arctanh_',
                       'torch.Tensor.argmax': 'https://pytorch.org/docs/stable/generated/torch.Tensor.argmax.html#torch.Tensor.argmax',
                       'torch.Tensor.argmin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.argmin.html#torch.Tensor.argmin',
                       'torch.Tensor.argsort': 'https://pytorch.org/docs/stable/generated/torch.Tensor.argsort.html#torch.Tensor.argsort',
                       'torch.Tensor.argwhere': 'https://pytorch.org/docs/stable/generated/torch.Tensor.argwhere.html#torch.Tensor.argwhere',
                       'torch.Tensor.as_strided': 'https://pytorch.org/docs/stable/generated/torch.Tensor.as_strided.html#torch.Tensor.as_strided',
                       'torch.Tensor.as_subclass': 'https://pytorch.org/docs/stable/generated/torch.Tensor.as_subclass.html#torch.Tensor.as_subclass',
                       'torch.Tensor.asin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.asin.html#torch.Tensor.asin',
                       'torch.Tensor.asin_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.asin_.html#torch.Tensor.asin_',
                       'torch.Tensor.asinh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.asinh.html#torch.Tensor.asinh',
                       'torch.Tensor.asinh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.asinh_.html#torch.Tensor.asinh_',
                       'torch.Tensor.atan': 'https://pytorch.org/docs/stable/generated/torch.Tensor.atan.html#torch.Tensor.atan',
                       'torch.Tensor.atan2': 'https://pytorch.org/docs/stable/generated/torch.Tensor.atan2.html#torch.Tensor.atan2',
                       'torch.Tensor.atan2_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.atan2_.html#torch.Tensor.atan2_',
                       'torch.Tensor.atan_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.atan_.html#torch.Tensor.atan_',
                       'torch.Tensor.atanh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.atanh.html#torch.Tensor.atanh',
                       'torch.Tensor.atanh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.atanh_.html#torch.Tensor.atanh_',
                       'torch.Tensor.backward': 'https://pytorch.org/docs/stable/generated/torch.Tensor.backward.html#torch.Tensor.backward',
                       'torch.Tensor.baddbmm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.baddbmm.html#torch.Tensor.baddbmm',
                       'torch.Tensor.baddbmm_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.baddbmm_.html#torch.Tensor.baddbmm_',
                       'torch.Tensor.bernoulli': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bernoulli.html#torch.Tensor.bernoulli',
                       'torch.Tensor.bernoulli_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bernoulli_.html#torch.Tensor.bernoulli_',
                       'torch.Tensor.bfloat16': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bfloat16.html#torch.Tensor.bfloat16',
                       'torch.Tensor.bincount': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bincount.html#torch.Tensor.bincount',
                       'torch.Tensor.bitwise_and': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_and.html#torch.Tensor.bitwise_and',
                       'torch.Tensor.bitwise_and_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_and_.html#torch.Tensor.bitwise_and_',
                       'torch.Tensor.bitwise_left_shift': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_left_shift.html#torch.Tensor.bitwise_left_shift',
                       'torch.Tensor.bitwise_left_shift_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_left_shift_.html#torch.Tensor.bitwise_left_shift_',
                       'torch.Tensor.bitwise_not': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_not.html#torch.Tensor.bitwise_not',
                       'torch.Tensor.bitwise_not_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_not_.html#torch.Tensor.bitwise_not_',
                       'torch.Tensor.bitwise_or': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_or.html#torch.Tensor.bitwise_or',
                       'torch.Tensor.bitwise_or_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_or_.html#torch.Tensor.bitwise_or_',
                       'torch.Tensor.bitwise_right_shift': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_right_shift.html#torch.Tensor.bitwise_right_shift',
                       'torch.Tensor.bitwise_right_shift_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_right_shift_.html#torch.Tensor.bitwise_right_shift_',
                       'torch.Tensor.bitwise_xor': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_xor.html#torch.Tensor.bitwise_xor',
                       'torch.Tensor.bitwise_xor_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bitwise_xor_.html#torch.Tensor.bitwise_xor_',
                       'torch.Tensor.bmm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bmm.html#torch.Tensor.bmm',
                       'torch.Tensor.bool': 'https://pytorch.org/docs/stable/generated/torch.Tensor.bool.html#torch.Tensor.bool',
                       'torch.Tensor.broadcast_to': 'https://pytorch.org/docs/stable/generated/torch.Tensor.broadcast_to.html#torch.Tensor.broadcast_to',
                       'torch.Tensor.byte': 'https://pytorch.org/docs/stable/generated/torch.Tensor.byte.html#torch.Tensor.byte',
                       'torch.Tensor.cauchy_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cauchy_.html#torch.Tensor.cauchy_',
                       'torch.Tensor.ceil': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ceil.html#torch.Tensor.ceil',
                       'torch.Tensor.ceil_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ceil_.html#torch.Tensor.ceil_',
                       'torch.Tensor.char': 'https://pytorch.org/docs/stable/generated/torch.Tensor.char.html#torch.Tensor.char',
                       'torch.Tensor.cholesky': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cholesky.html#torch.Tensor.cholesky',
                       'torch.Tensor.cholesky_inverse': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cholesky_inverse.html#torch.Tensor.cholesky_inverse',
                       'torch.Tensor.cholesky_solve': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cholesky_solve.html#torch.Tensor.cholesky_solve',
                       'torch.Tensor.chunk': 'https://pytorch.org/docs/stable/generated/torch.Tensor.chunk.html#torch.Tensor.chunk',
                       'torch.Tensor.clamp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.clamp.html#torch.Tensor.clamp',
                       'torch.Tensor.clamp_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.clamp_.html#torch.Tensor.clamp_',
                       'torch.Tensor.clip': 'https://pytorch.org/docs/stable/generated/torch.Tensor.clip.html#torch.Tensor.clip',
                       'torch.Tensor.clip_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.clip_.html#torch.Tensor.clip_',
                       'torch.Tensor.clone': 'https://pytorch.org/docs/stable/generated/torch.Tensor.clone.html#torch.Tensor.clone',
                       'torch.Tensor.coalesce': 'https://pytorch.org/docs/stable/generated/torch.Tensor.coalesce.html#torch.Tensor.coalesce',
                       'torch.Tensor.conj': 'https://pytorch.org/docs/stable/generated/torch.Tensor.conj.html#torch.Tensor.conj',
                       'torch.Tensor.conj_physical': 'https://pytorch.org/docs/stable/generated/torch.Tensor.conj_physical.html#torch.Tensor.conj_physical',
                       'torch.Tensor.conj_physical_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.conj_physical_.html#torch.Tensor.conj_physical_',
                       'torch.Tensor.contiguous': 'https://pytorch.org/docs/stable/generated/torch.Tensor.contiguous.html#torch.Tensor.contiguous',
                       'torch.Tensor.copy_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.copy_.html#torch.Tensor.copy_',
                       'torch.Tensor.copysign': 'https://pytorch.org/docs/stable/generated/torch.Tensor.copysign.html#torch.Tensor.copysign',
                       'torch.Tensor.copysign_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.copysign_.html#torch.Tensor.copysign_',
                       'torch.Tensor.corrcoef': 'https://pytorch.org/docs/stable/generated/torch.Tensor.corrcoef.html#torch.Tensor.corrcoef',
                       'torch.Tensor.cos': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cos.html#torch.Tensor.cos',
                       'torch.Tensor.cos_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cos_.html#torch.Tensor.cos_',
                       'torch.Tensor.cosh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cosh.html#torch.Tensor.cosh',
                       'torch.Tensor.cosh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cosh_.html#torch.Tensor.cosh_',
                       'torch.Tensor.count_nonzero': 'https://pytorch.org/docs/stable/generated/torch.Tensor.count_nonzero.html#torch.Tensor.count_nonzero',
                       'torch.Tensor.cov': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cov.html#torch.Tensor.cov',
                       'torch.Tensor.cpu': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cpu.html#torch.Tensor.cpu',
                       'torch.Tensor.cross': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cross.html#torch.Tensor.cross',
                       'torch.Tensor.cuda': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cuda.html#torch.Tensor.cuda',
                       'torch.Tensor.cummax': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cummax.html#torch.Tensor.cummax',
                       'torch.Tensor.cummin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cummin.html#torch.Tensor.cummin',
                       'torch.Tensor.cumprod': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cumprod.html#torch.Tensor.cumprod',
                       'torch.Tensor.cumprod_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cumprod_.html#torch.Tensor.cumprod_',
                       'torch.Tensor.cumsum': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cumsum.html#torch.Tensor.cumsum',
                       'torch.Tensor.cumsum_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.cumsum_.html#torch.Tensor.cumsum_',
                       'torch.Tensor.data_ptr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.data_ptr.html#torch.Tensor.data_ptr',
                       'torch.Tensor.deg2rad': 'https://pytorch.org/docs/stable/generated/torch.Tensor.deg2rad.html#torch.Tensor.deg2rad',
                       'torch.Tensor.dense_dim': 'https://pytorch.org/docs/stable/generated/torch.Tensor.dense_dim.html#torch.Tensor.dense_dim',
                       'torch.Tensor.dequantize': 'https://pytorch.org/docs/stable/generated/torch.Tensor.dequantize.html#torch.Tensor.dequantize',
                       'torch.Tensor.det': 'https://pytorch.org/docs/stable/generated/torch.Tensor.det.html#torch.Tensor.det',
                       'torch.Tensor.detach': 'https://pytorch.org/docs/stable/generated/torch.Tensor.detach.html#torch.Tensor.detach',
                       'torch.Tensor.detach_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.detach_.html#torch.Tensor.detach_',
                       'torch.Tensor.diag': 'https://pytorch.org/docs/stable/generated/torch.Tensor.diag.html#torch.Tensor.diag',
                       'torch.Tensor.diag_embed': 'https://pytorch.org/docs/stable/generated/torch.Tensor.diag_embed.html#torch.Tensor.diag_embed',
                       'torch.Tensor.diagflat': 'https://pytorch.org/docs/stable/generated/torch.Tensor.diagflat.html#torch.Tensor.diagflat',
                       'torch.Tensor.diagonal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.diagonal.html#torch.Tensor.diagonal',
                       'torch.Tensor.diagonal_scatter': 'https://pytorch.org/docs/stable/generated/torch.Tensor.diagonal_scatter.html#torch.Tensor.diagonal_scatter',
                       'torch.Tensor.diff': 'https://pytorch.org/docs/stable/generated/torch.Tensor.diff.html#torch.Tensor.diff',
                       'torch.Tensor.digamma': 'https://pytorch.org/docs/stable/generated/torch.Tensor.digamma.html#torch.Tensor.digamma',
                       'torch.Tensor.digamma_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.digamma_.html#torch.Tensor.digamma_',
                       'torch.Tensor.dim': 'https://pytorch.org/docs/stable/generated/torch.Tensor.dim.html#torch.Tensor.dim',
                       'torch.Tensor.dist': 'https://pytorch.org/docs/stable/generated/torch.Tensor.dist.html#torch.Tensor.dist',
                       'torch.Tensor.div': 'https://pytorch.org/docs/stable/generated/torch.Tensor.div.html#torch.Tensor.div',
                       'torch.Tensor.div_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.div_.html#torch.Tensor.div_',
                       'torch.Tensor.divide': 'https://pytorch.org/docs/stable/generated/torch.Tensor.divide.html#torch.Tensor.divide',
                       'torch.Tensor.divide_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.divide_.html#torch.Tensor.divide_',
                       'torch.Tensor.dot': 'https://pytorch.org/docs/stable/generated/torch.Tensor.dot.html#torch.Tensor.dot',
                       'torch.Tensor.double': 'https://pytorch.org/docs/stable/generated/torch.Tensor.double.html#torch.Tensor.double',
                       'torch.Tensor.dsplit': 'https://pytorch.org/docs/stable/generated/torch.Tensor.dsplit.html#torch.Tensor.dsplit',
                       'torch.Tensor.eig': 'https://pytorch.org/docs/stable/generated/torch.Tensor.eig.html#torch.Tensor.eig',
                       'torch.Tensor.element_size': 'https://pytorch.org/docs/stable/generated/torch.Tensor.element_size.html#torch.Tensor.element_size',
                       'torch.Tensor.eq': 'https://pytorch.org/docs/stable/generated/torch.Tensor.eq.html#torch.Tensor.eq',
                       'torch.Tensor.eq_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.eq_.html#torch.Tensor.eq_',
                       'torch.Tensor.equal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.equal.html#torch.Tensor.equal',
                       'torch.Tensor.erf': 'https://pytorch.org/docs/stable/generated/torch.Tensor.erf.html#torch.Tensor.erf',
                       'torch.Tensor.erf_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.erf_.html#torch.Tensor.erf_',
                       'torch.Tensor.erfc': 'https://pytorch.org/docs/stable/generated/torch.Tensor.erfc.html#torch.Tensor.erfc',
                       'torch.Tensor.erfc_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.erfc_.html#torch.Tensor.erfc_',
                       'torch.Tensor.erfinv': 'https://pytorch.org/docs/stable/generated/torch.Tensor.erfinv.html#torch.Tensor.erfinv',
                       'torch.Tensor.erfinv_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.erfinv_.html#torch.Tensor.erfinv_',
                       'torch.Tensor.exp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.exp.html#torch.Tensor.exp',
                       'torch.Tensor.exp_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.exp_.html#torch.Tensor.exp_',
                       'torch.Tensor.expand': 'https://pytorch.org/docs/stable/generated/torch.Tensor.expand.html#torch.Tensor.expand',
                       'torch.Tensor.expand_as': 'https://pytorch.org/docs/stable/generated/torch.Tensor.expand_as.html#torch.Tensor.expand_as',
                       'torch.Tensor.expm1': 'https://pytorch.org/docs/stable/generated/torch.Tensor.expm1.html#torch.Tensor.expm1',
                       'torch.Tensor.expm1_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.expm1_.html#torch.Tensor.expm1_',
                       'torch.Tensor.exponential_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.exponential_.html#torch.Tensor.exponential_',
                       'torch.Tensor.fill_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fill_.html#torch.Tensor.fill_',
                       'torch.Tensor.fill_diagonal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fill_diagonal_.html#torch.Tensor.fill_diagonal_',
                       'torch.Tensor.fix': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fix.html#torch.Tensor.fix',
                       'torch.Tensor.fix_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fix_.html#torch.Tensor.fix_',
                       'torch.Tensor.flatten': 'https://pytorch.org/docs/stable/generated/torch.Tensor.flatten.html#torch.Tensor.flatten',
                       'torch.Tensor.flip': 'https://pytorch.org/docs/stable/generated/torch.Tensor.flip.html#torch.Tensor.flip',
                       'torch.Tensor.fliplr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fliplr.html#torch.Tensor.fliplr',
                       'torch.Tensor.flipud': 'https://pytorch.org/docs/stable/generated/torch.Tensor.flipud.html#torch.Tensor.flipud',
                       'torch.Tensor.float': 'https://pytorch.org/docs/stable/generated/torch.Tensor.float.html#torch.Tensor.float',
                       'torch.Tensor.float_power': 'https://pytorch.org/docs/stable/generated/torch.Tensor.float_power.html#torch.Tensor.float_power',
                       'torch.Tensor.float_power_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.float_power_.html#torch.Tensor.float_power_',
                       'torch.Tensor.floor': 'https://pytorch.org/docs/stable/generated/torch.Tensor.floor.html#torch.Tensor.floor',
                       'torch.Tensor.floor_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.floor_.html#torch.Tensor.floor_',
                       'torch.Tensor.floor_divide': 'https://pytorch.org/docs/stable/generated/torch.Tensor.floor_divide.html#torch.Tensor.floor_divide',
                       'torch.Tensor.floor_divide_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.floor_divide_.html#torch.Tensor.floor_divide_',
                       'torch.Tensor.fmax': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fmax.html#torch.Tensor.fmax',
                       'torch.Tensor.fmin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fmin.html#torch.Tensor.fmin',
                       'torch.Tensor.fmod': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fmod.html#torch.Tensor.fmod',
                       'torch.Tensor.fmod_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.fmod_.html#torch.Tensor.fmod_',
                       'torch.Tensor.frac': 'https://pytorch.org/docs/stable/generated/torch.Tensor.frac.html#torch.Tensor.frac',
                       'torch.Tensor.frac_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.frac_.html#torch.Tensor.frac_',
                       'torch.Tensor.frexp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.frexp.html#torch.Tensor.frexp',
                       'torch.Tensor.gather': 'https://pytorch.org/docs/stable/generated/torch.Tensor.gather.html#torch.Tensor.gather',
                       'torch.Tensor.gcd': 'https://pytorch.org/docs/stable/generated/torch.Tensor.gcd.html#torch.Tensor.gcd',
                       'torch.Tensor.gcd_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.gcd_.html#torch.Tensor.gcd_',
                       'torch.Tensor.ge': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ge.html#torch.Tensor.ge',
                       'torch.Tensor.ge_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ge_.html#torch.Tensor.ge_',
                       'torch.Tensor.geometric_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.geometric_.html#torch.Tensor.geometric_',
                       'torch.Tensor.geqrf': 'https://pytorch.org/docs/stable/generated/torch.Tensor.geqrf.html#torch.Tensor.geqrf',
                       'torch.Tensor.ger': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ger.html#torch.Tensor.ger',
                       'torch.Tensor.get_device': 'https://pytorch.org/docs/stable/generated/torch.Tensor.get_device.html#torch.Tensor.get_device',
                       'torch.Tensor.grad': 'https://pytorch.org/docs/stable/generated/torch.Tensor.grad.html#torch.Tensor.grad',
                       'torch.Tensor.greater': 'https://pytorch.org/docs/stable/generated/torch.Tensor.greater.html#torch.Tensor.greater',
                       'torch.Tensor.greater_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.greater_.html#torch.Tensor.greater_',
                       'torch.Tensor.greater_equal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.greater_equal.html#torch.Tensor.greater_equal',
                       'torch.Tensor.greater_equal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.greater_equal_.html#torch.Tensor.greater_equal_',
                       'torch.Tensor.gt': 'https://pytorch.org/docs/stable/generated/torch.Tensor.gt.html#torch.Tensor.gt',
                       'torch.Tensor.gt_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.gt_.html#torch.Tensor.gt_',
                       'torch.Tensor.half': 'https://pytorch.org/docs/stable/generated/torch.Tensor.half.html#torch.Tensor.half',
                       'torch.Tensor.hardshrink': 'https://pytorch.org/docs/stable/generated/torch.Tensor.hardshrink.html#torch.Tensor.hardshrink',
                       'torch.Tensor.heaviside': 'https://pytorch.org/docs/stable/generated/torch.Tensor.heaviside.html#torch.Tensor.heaviside',
                       'torch.Tensor.histc': 'https://pytorch.org/docs/stable/generated/torch.Tensor.histc.html#torch.Tensor.histc',
                       'torch.Tensor.histogram': 'https://pytorch.org/docs/stable/generated/torch.Tensor.histogram.html#torch.Tensor.histogram',
                       'torch.Tensor.hsplit': 'https://pytorch.org/docs/stable/generated/torch.Tensor.hsplit.html#torch.Tensor.hsplit',
                       'torch.Tensor.hypot': 'https://pytorch.org/docs/stable/generated/torch.Tensor.hypot.html#torch.Tensor.hypot',
                       'torch.Tensor.hypot_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.hypot_.html#torch.Tensor.hypot_',
                       'torch.Tensor.i0': 'https://pytorch.org/docs/stable/generated/torch.Tensor.i0.html#torch.Tensor.i0',
                       'torch.Tensor.i0_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.i0_.html#torch.Tensor.i0_',
                       'torch.Tensor.igamma': 'https://pytorch.org/docs/stable/generated/torch.Tensor.igamma.html#torch.Tensor.igamma',
                       'torch.Tensor.igamma_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.igamma_.html#torch.Tensor.igamma_',
                       'torch.Tensor.igammac': 'https://pytorch.org/docs/stable/generated/torch.Tensor.igammac.html#torch.Tensor.igammac',
                       'torch.Tensor.igammac_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.igammac_.html#torch.Tensor.igammac_',
                       'torch.Tensor.index_add': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_add.html#torch.Tensor.index_add',
                       'torch.Tensor.index_add_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_add_.html#torch.Tensor.index_add_',
                       'torch.Tensor.index_copy': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_copy.html#torch.Tensor.index_copy',
                       'torch.Tensor.index_copy_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_copy_.html#torch.Tensor.index_copy_',
                       'torch.Tensor.index_fill': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_fill.html#torch.Tensor.index_fill',
                       'torch.Tensor.index_fill_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_fill_.html#torch.Tensor.index_fill_',
                       'torch.Tensor.index_put': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_put.html#torch.Tensor.index_put',
                       'torch.Tensor.index_put_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_put_.html#torch.Tensor.index_put_',
                       'torch.Tensor.index_select': 'https://pytorch.org/docs/stable/generated/torch.Tensor.index_select.html#torch.Tensor.index_select',
                       'torch.Tensor.indices': 'https://pytorch.org/docs/stable/generated/torch.Tensor.indices.html#torch.Tensor.indices',
                       'torch.Tensor.inner': 'https://pytorch.org/docs/stable/generated/torch.Tensor.inner.html#torch.Tensor.inner',
                       'torch.Tensor.int': 'https://pytorch.org/docs/stable/generated/torch.Tensor.int.html#torch.Tensor.int',
                       'torch.Tensor.int_repr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.int_repr.html#torch.Tensor.int_repr',
                       'torch.Tensor.inverse': 'https://pytorch.org/docs/stable/generated/torch.Tensor.inverse.html#torch.Tensor.inverse',
                       'torch.Tensor.is_coalesced': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_coalesced.html#torch.Tensor.is_coalesced',
                       'torch.Tensor.is_complex': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_complex.html#torch.Tensor.is_complex',
                       'torch.Tensor.is_conj': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_conj.html#torch.Tensor.is_conj',
                       'torch.Tensor.is_contiguous': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_contiguous.html#torch.Tensor.is_contiguous',
                       'torch.Tensor.is_floating_point': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_floating_point.html#torch.Tensor.is_floating_point',
                       'torch.Tensor.is_inference': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_inference.html#torch.Tensor.is_inference',
                       'torch.Tensor.is_pinned': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_pinned.html#torch.Tensor.is_pinned',
                       'torch.Tensor.is_set_to': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_set_to.html#torch.Tensor.is_set_to',
                       'torch.Tensor.is_shared': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_shared.html#torch.Tensor.is_shared',
                       'torch.Tensor.is_signed': 'https://pytorch.org/docs/stable/generated/torch.Tensor.is_signed.html#torch.Tensor.is_signed',
                       'torch.Tensor.isclose': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isclose.html#torch.Tensor.isclose',
                       'torch.Tensor.isfinite': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isfinite.html#torch.Tensor.isfinite',
                       'torch.Tensor.isinf': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isinf.html#torch.Tensor.isinf',
                       'torch.Tensor.isnan': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isnan.html#torch.Tensor.isnan',
                       'torch.Tensor.isneginf': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isneginf.html#torch.Tensor.isneginf',
                       'torch.Tensor.isposinf': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isposinf.html#torch.Tensor.isposinf',
                       'torch.Tensor.isreal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.isreal.html#torch.Tensor.isreal',
                       'torch.Tensor.istft': 'https://pytorch.org/docs/stable/generated/torch.Tensor.istft.html#torch.Tensor.istft',
                       'torch.Tensor.item': 'https://pytorch.org/docs/stable/generated/torch.Tensor.item.html#torch.Tensor.item',
                       'torch.Tensor.kthvalue': 'https://pytorch.org/docs/stable/generated/torch.Tensor.kthvalue.html#torch.Tensor.kthvalue',
                       'torch.Tensor.lcm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lcm.html#torch.Tensor.lcm',
                       'torch.Tensor.lcm_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lcm_.html#torch.Tensor.lcm_',
                       'torch.Tensor.ldexp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ldexp.html#torch.Tensor.ldexp',
                       'torch.Tensor.ldexp_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ldexp_.html#torch.Tensor.ldexp_',
                       'torch.Tensor.le': 'https://pytorch.org/docs/stable/generated/torch.Tensor.le.html#torch.Tensor.le',
                       'torch.Tensor.le_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.le_.html#torch.Tensor.le_',
                       'torch.Tensor.lerp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lerp.html#torch.Tensor.lerp',
                       'torch.Tensor.lerp_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lerp_.html#torch.Tensor.lerp_',
                       'torch.Tensor.less': 'https://pytorch.org/docs/stable/generated/torch.Tensor.less.html#torch.Tensor.less',
                       'torch.Tensor.less_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.less_.html#torch.Tensor.less_',
                       'torch.Tensor.less_equal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.less_equal.html#torch.Tensor.less_equal',
                       'torch.Tensor.less_equal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.less_equal_.html#torch.Tensor.less_equal_',
                       'torch.Tensor.lgamma': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lgamma.html#torch.Tensor.lgamma',
                       'torch.Tensor.lgamma_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lgamma_.html#torch.Tensor.lgamma_',
                       'torch.Tensor.log': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log.html#torch.Tensor.log',
                       'torch.Tensor.log10': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log10.html#torch.Tensor.log10',
                       'torch.Tensor.log10_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log10_.html#torch.Tensor.log10_',
                       'torch.Tensor.log1p': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log1p.html#torch.Tensor.log1p',
                       'torch.Tensor.log1p_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log1p_.html#torch.Tensor.log1p_',
                       'torch.Tensor.log2': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log2.html#torch.Tensor.log2',
                       'torch.Tensor.log2_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log2_.html#torch.Tensor.log2_',
                       'torch.Tensor.log_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log_.html#torch.Tensor.log_',
                       'torch.Tensor.log_normal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.log_normal_.html#torch.Tensor.log_normal_',
                       'torch.Tensor.logaddexp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logaddexp.html#torch.Tensor.logaddexp',
                       'torch.Tensor.logaddexp2': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logaddexp2.html#torch.Tensor.logaddexp2',
                       'torch.Tensor.logcumsumexp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logcumsumexp.html#torch.Tensor.logcumsumexp',
                       'torch.Tensor.logdet': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logdet.html#torch.Tensor.logdet',
                       'torch.Tensor.logical_and': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_and.html#torch.Tensor.logical_and',
                       'torch.Tensor.logical_and_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_and_.html#torch.Tensor.logical_and_',
                       'torch.Tensor.logical_not': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_not.html#torch.Tensor.logical_not',
                       'torch.Tensor.logical_not_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_not_.html#torch.Tensor.logical_not_',
                       'torch.Tensor.logical_or': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_or.html#torch.Tensor.logical_or',
                       'torch.Tensor.logical_or_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_or_.html#torch.Tensor.logical_or_',
                       'torch.Tensor.logical_xor': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_xor.html#torch.Tensor.logical_xor',
                       'torch.Tensor.logical_xor_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logical_xor_.html#torch.Tensor.logical_xor_',
                       'torch.Tensor.logit': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logit.html#torch.Tensor.logit',
                       'torch.Tensor.logit_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logit_.html#torch.Tensor.logit_',
                       'torch.Tensor.logsumexp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.logsumexp.html#torch.Tensor.logsumexp',
                       'torch.Tensor.long': 'https://pytorch.org/docs/stable/generated/torch.Tensor.long.html#torch.Tensor.long',
                       'torch.Tensor.lstsq': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lstsq.html#torch.Tensor.lstsq',
                       'torch.Tensor.lt': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lt.html#torch.Tensor.lt',
                       'torch.Tensor.lt_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lt_.html#torch.Tensor.lt_',
                       'torch.Tensor.lu': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lu.html#torch.Tensor.lu',
                       'torch.Tensor.lu_solve': 'https://pytorch.org/docs/stable/generated/torch.Tensor.lu_solve.html#torch.Tensor.lu_solve',
                       'torch.Tensor.map_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.map_.html#torch.Tensor.map_',
                       'torch.Tensor.masked_fill': 'https://pytorch.org/docs/stable/generated/torch.Tensor.masked_fill.html#torch.Tensor.masked_fill',
                       'torch.Tensor.masked_fill_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.masked_fill_.html#torch.Tensor.masked_fill_',
                       'torch.Tensor.masked_scatter': 'https://pytorch.org/docs/stable/generated/torch.Tensor.masked_scatter.html#torch.Tensor.masked_scatter',
                       'torch.Tensor.masked_scatter_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.masked_scatter_.html#torch.Tensor.masked_scatter_',
                       'torch.Tensor.masked_select': 'https://pytorch.org/docs/stable/generated/torch.Tensor.masked_select.html#torch.Tensor.masked_select',
                       'torch.Tensor.matmul': 'https://pytorch.org/docs/stable/generated/torch.Tensor.matmul.html#torch.Tensor.matmul',
                       'torch.Tensor.matrix_exp': 'https://pytorch.org/docs/stable/generated/torch.Tensor.matrix_exp.html#torch.Tensor.matrix_exp',
                       'torch.Tensor.matrix_power': 'https://pytorch.org/docs/stable/generated/torch.Tensor.matrix_power.html#torch.Tensor.matrix_power',
                       'torch.Tensor.max': 'https://pytorch.org/docs/stable/generated/torch.Tensor.max.html#torch.Tensor.max',
                       'torch.Tensor.maximum': 'https://pytorch.org/docs/stable/generated/torch.Tensor.maximum.html#torch.Tensor.maximum',
                       'torch.Tensor.mean': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mean.html#torch.Tensor.mean',
                       'torch.Tensor.median': 'https://pytorch.org/docs/stable/generated/torch.Tensor.median.html#torch.Tensor.median',
                       'torch.Tensor.min': 'https://pytorch.org/docs/stable/generated/torch.Tensor.min.html#torch.Tensor.min',
                       'torch.Tensor.minimum': 'https://pytorch.org/docs/stable/generated/torch.Tensor.minimum.html#torch.Tensor.minimum',
                       'torch.Tensor.mm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mm.html#torch.Tensor.mm',
                       'torch.Tensor.mode': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mode.html#torch.Tensor.mode',
                       'torch.Tensor.moveaxis': 'https://pytorch.org/docs/stable/generated/torch.Tensor.moveaxis.html#torch.Tensor.moveaxis',
                       'torch.Tensor.movedim': 'https://pytorch.org/docs/stable/generated/torch.Tensor.movedim.html#torch.Tensor.movedim',
                       'torch.Tensor.msort': 'https://pytorch.org/docs/stable/generated/torch.Tensor.msort.html#torch.Tensor.msort',
                       'torch.Tensor.mul': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mul.html#torch.Tensor.mul',
                       'torch.Tensor.mul_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mul_.html#torch.Tensor.mul_',
                       'torch.Tensor.multinomial': 'https://pytorch.org/docs/stable/generated/torch.Tensor.multinomial.html#torch.Tensor.multinomial',
                       'torch.Tensor.multiply': 'https://pytorch.org/docs/stable/generated/torch.Tensor.multiply.html#torch.Tensor.multiply',
                       'torch.Tensor.multiply_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.multiply_.html#torch.Tensor.multiply_',
                       'torch.Tensor.mv': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mv.html#torch.Tensor.mv',
                       'torch.Tensor.mvlgamma': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mvlgamma.html#torch.Tensor.mvlgamma',
                       'torch.Tensor.mvlgamma_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.mvlgamma_.html#torch.Tensor.mvlgamma_',
                       'torch.Tensor.nan_to_num': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nan_to_num.html#torch.Tensor.nan_to_num',
                       'torch.Tensor.nan_to_num_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nan_to_num_.html#torch.Tensor.nan_to_num_',
                       'torch.Tensor.nanmean': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nanmean.html#torch.Tensor.nanmean',
                       'torch.Tensor.nanmedian': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nanmedian.html#torch.Tensor.nanmedian',
                       'torch.Tensor.nanquantile': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nanquantile.html#torch.Tensor.nanquantile',
                       'torch.Tensor.nansum': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nansum.html#torch.Tensor.nansum',
                       'torch.Tensor.narrow': 'https://pytorch.org/docs/stable/generated/torch.Tensor.narrow.html#torch.Tensor.narrow',
                       'torch.Tensor.narrow_copy': 'https://pytorch.org/docs/stable/generated/torch.Tensor.narrow_copy.html#torch.Tensor.narrow_copy',
                       'torch.Tensor.ndimension': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ndimension.html#torch.Tensor.ndimension',
                       'torch.Tensor.ne': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ne.html#torch.Tensor.ne',
                       'torch.Tensor.ne_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ne_.html#torch.Tensor.ne_',
                       'torch.Tensor.neg': 'https://pytorch.org/docs/stable/generated/torch.Tensor.neg.html#torch.Tensor.neg',
                       'torch.Tensor.neg_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.neg_.html#torch.Tensor.neg_',
                       'torch.Tensor.negative': 'https://pytorch.org/docs/stable/generated/torch.Tensor.negative.html#torch.Tensor.negative',
                       'torch.Tensor.negative_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.negative_.html#torch.Tensor.negative_',
                       'torch.Tensor.nelement': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nelement.html#torch.Tensor.nelement',
                       'torch.Tensor.new_empty': 'https://pytorch.org/docs/stable/generated/torch.Tensor.new_empty.html#torch.Tensor.new_empty',
                       'torch.Tensor.new_full': 'https://pytorch.org/docs/stable/generated/torch.Tensor.new_full.html#torch.Tensor.new_full',
                       'torch.Tensor.new_ones': 'https://pytorch.org/docs/stable/generated/torch.Tensor.new_ones.html#torch.Tensor.new_ones',
                       'torch.Tensor.new_tensor': 'https://pytorch.org/docs/stable/generated/torch.Tensor.new_tensor.html#torch.Tensor.new_tensor',
                       'torch.Tensor.new_zeros': 'https://pytorch.org/docs/stable/generated/torch.Tensor.new_zeros.html#torch.Tensor.new_zeros',
                       'torch.Tensor.nextafter': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nextafter.html#torch.Tensor.nextafter',
                       'torch.Tensor.nextafter_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nextafter_.html#torch.Tensor.nextafter_',
                       'torch.Tensor.nonzero': 'https://pytorch.org/docs/stable/generated/torch.Tensor.nonzero.html#torch.Tensor.nonzero',
                       'torch.Tensor.norm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.norm.html#torch.Tensor.norm',
                       'torch.Tensor.normal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.normal_.html#torch.Tensor.normal_',
                       'torch.Tensor.not_equal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.not_equal.html#torch.Tensor.not_equal',
                       'torch.Tensor.not_equal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.not_equal_.html#torch.Tensor.not_equal_',
                       'torch.Tensor.numel': 'https://pytorch.org/docs/stable/generated/torch.Tensor.numel.html#torch.Tensor.numel',
                       'torch.Tensor.numpy': 'https://pytorch.org/docs/stable/generated/torch.Tensor.numpy.html#torch.Tensor.numpy',
                       'torch.Tensor.orgqr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.orgqr.html#torch.Tensor.orgqr',
                       'torch.Tensor.ormqr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ormqr.html#torch.Tensor.ormqr',
                       'torch.Tensor.outer': 'https://pytorch.org/docs/stable/generated/torch.Tensor.outer.html#torch.Tensor.outer',
                       'torch.Tensor.permute': 'https://pytorch.org/docs/stable/generated/torch.Tensor.permute.html#torch.Tensor.permute',
                       'torch.Tensor.pin_memory': 'https://pytorch.org/docs/stable/generated/torch.Tensor.pin_memory.html#torch.Tensor.pin_memory',
                       'torch.Tensor.pinverse': 'https://pytorch.org/docs/stable/generated/torch.Tensor.pinverse.html#torch.Tensor.pinverse',
                       'torch.Tensor.polygamma': 'https://pytorch.org/docs/stable/generated/torch.Tensor.polygamma.html#torch.Tensor.polygamma',
                       'torch.Tensor.polygamma_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.polygamma_.html#torch.Tensor.polygamma_',
                       'torch.Tensor.positive': 'https://pytorch.org/docs/stable/generated/torch.Tensor.positive.html#torch.Tensor.positive',
                       'torch.Tensor.pow': 'https://pytorch.org/docs/stable/generated/torch.Tensor.pow.html#torch.Tensor.pow',
                       'torch.Tensor.pow_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.pow_.html#torch.Tensor.pow_',
                       'torch.Tensor.prod': 'https://pytorch.org/docs/stable/generated/torch.Tensor.prod.html#torch.Tensor.prod',
                       'torch.Tensor.put_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.put_.html#torch.Tensor.put_',
                       'torch.Tensor.q_per_channel_axis': 'https://pytorch.org/docs/stable/generated/torch.Tensor.q_per_channel_axis.html#torch.Tensor.q_per_channel_axis',
                       'torch.Tensor.q_per_channel_scales': 'https://pytorch.org/docs/stable/generated/torch.Tensor.q_per_channel_scales.html#torch.Tensor.q_per_channel_scales',
                       'torch.Tensor.q_per_channel_zero_points': 'https://pytorch.org/docs/stable/generated/torch.Tensor.q_per_channel_zero_points.html#torch.Tensor.q_per_channel_zero_points',
                       'torch.Tensor.q_scale': 'https://pytorch.org/docs/stable/generated/torch.Tensor.q_scale.html#torch.Tensor.q_scale',
                       'torch.Tensor.q_zero_point': 'https://pytorch.org/docs/stable/generated/torch.Tensor.q_zero_point.html#torch.Tensor.q_zero_point',
                       'torch.Tensor.qr': 'https://pytorch.org/docs/stable/generated/torch.Tensor.qr.html#torch.Tensor.qr',
                       'torch.Tensor.qscheme': 'https://pytorch.org/docs/stable/generated/torch.Tensor.qscheme.html#torch.Tensor.qscheme',
                       'torch.Tensor.quantile': 'https://pytorch.org/docs/stable/generated/torch.Tensor.quantile.html#torch.Tensor.quantile',
                       'torch.Tensor.rad2deg': 'https://pytorch.org/docs/stable/generated/torch.Tensor.rad2deg.html#torch.Tensor.rad2deg',
                       'torch.Tensor.random_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.random_.html#torch.Tensor.random_',
                       'torch.Tensor.ravel': 'https://pytorch.org/docs/stable/generated/torch.Tensor.ravel.html#torch.Tensor.ravel',
                       'torch.Tensor.reciprocal': 'https://pytorch.org/docs/stable/generated/torch.Tensor.reciprocal.html#torch.Tensor.reciprocal',
                       'torch.Tensor.reciprocal_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.reciprocal_.html#torch.Tensor.reciprocal_',
                       'torch.Tensor.record_stream': 'https://pytorch.org/docs/stable/generated/torch.Tensor.record_stream.html#torch.Tensor.record_stream',
                       'torch.Tensor.refine_names': 'https://pytorch.org/docs/stable/named_tensor.html#torch.Tensor.refine_names',
                       'torch.Tensor.register_hook': 'https://pytorch.org/docs/stable/generated/torch.Tensor.register_hook.html#torch.Tensor.register_hook',
                       'torch.Tensor.remainder': 'https://pytorch.org/docs/stable/generated/torch.Tensor.remainder.html#torch.Tensor.remainder',
                       'torch.Tensor.remainder_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.remainder_.html#torch.Tensor.remainder_',
                       'torch.Tensor.rename': 'https://pytorch.org/docs/stable/named_tensor.html#torch.Tensor.rename',
                       'torch.Tensor.rename_': 'https://pytorch.org/docs/stable/named_tensor.html#torch.Tensor.rename_',
                       'torch.Tensor.renorm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.renorm.html#torch.Tensor.renorm',
                       'torch.Tensor.renorm_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.renorm_.html#torch.Tensor.renorm_',
                       'torch.Tensor.repeat': 'https://pytorch.org/docs/stable/generated/torch.Tensor.repeat.html#torch.Tensor.repeat',
                       'torch.Tensor.repeat_interleave': 'https://pytorch.org/docs/stable/generated/torch.Tensor.repeat_interleave.html#torch.Tensor.repeat_interleave',
                       'torch.Tensor.requires_grad_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.requires_grad_.html#torch.Tensor.requires_grad_',
                       'torch.Tensor.reshape': 'https://pytorch.org/docs/stable/generated/torch.Tensor.reshape.html#torch.Tensor.reshape',
                       'torch.Tensor.reshape_as': 'https://pytorch.org/docs/stable/generated/torch.Tensor.reshape_as.html#torch.Tensor.reshape_as',
                       'torch.Tensor.resize_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.resize_.html#torch.Tensor.resize_',
                       'torch.Tensor.resize_as_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.resize_as_.html#torch.Tensor.resize_as_',
                       'torch.Tensor.resolve_conj': 'https://pytorch.org/docs/stable/generated/torch.Tensor.resolve_conj.html#torch.Tensor.resolve_conj',
                       'torch.Tensor.resolve_neg': 'https://pytorch.org/docs/stable/generated/torch.Tensor.resolve_neg.html#torch.Tensor.resolve_neg',
                       'torch.Tensor.retain_grad': 'https://pytorch.org/docs/stable/generated/torch.Tensor.retain_grad.html#torch.Tensor.retain_grad',
                       'torch.Tensor.roll': 'https://pytorch.org/docs/stable/generated/torch.Tensor.roll.html#torch.Tensor.roll',
                       'torch.Tensor.rot90': 'https://pytorch.org/docs/stable/generated/torch.Tensor.rot90.html#torch.Tensor.rot90',
                       'torch.Tensor.round': 'https://pytorch.org/docs/stable/generated/torch.Tensor.round.html#torch.Tensor.round',
                       'torch.Tensor.round_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.round_.html#torch.Tensor.round_',
                       'torch.Tensor.rsqrt': 'https://pytorch.org/docs/stable/generated/torch.Tensor.rsqrt.html#torch.Tensor.rsqrt',
                       'torch.Tensor.rsqrt_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.rsqrt_.html#torch.Tensor.rsqrt_',
                       'torch.Tensor.scatter': 'https://pytorch.org/docs/stable/generated/torch.Tensor.scatter.html#torch.Tensor.scatter',
                       'torch.Tensor.scatter_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.scatter_.html#torch.Tensor.scatter_',
                       'torch.Tensor.scatter_add': 'https://pytorch.org/docs/stable/generated/torch.Tensor.scatter_add.html#torch.Tensor.scatter_add',
                       'torch.Tensor.scatter_add_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.scatter_add_.html#torch.Tensor.scatter_add_',
                       'torch.Tensor.scatter_reduce': 'https://pytorch.org/docs/stable/generated/torch.Tensor.scatter_reduce.html#torch.Tensor.scatter_reduce',
                       'torch.Tensor.select': 'https://pytorch.org/docs/stable/generated/torch.Tensor.select.html#torch.Tensor.select',
                       'torch.Tensor.select_scatter': 'https://pytorch.org/docs/stable/generated/torch.Tensor.select_scatter.html#torch.Tensor.select_scatter',
                       'torch.Tensor.set_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.set_.html#torch.Tensor.set_',
                       'torch.Tensor.sgn': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sgn.html#torch.Tensor.sgn',
                       'torch.Tensor.sgn_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sgn_.html#torch.Tensor.sgn_',
                       'torch.Tensor.share_memory_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.share_memory_.html#torch.Tensor.share_memory_',
                       'torch.Tensor.short': 'https://pytorch.org/docs/stable/generated/torch.Tensor.short.html#torch.Tensor.short',
                       'torch.Tensor.sigmoid': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sigmoid.html#torch.Tensor.sigmoid',
                       'torch.Tensor.sigmoid_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sigmoid_.html#torch.Tensor.sigmoid_',
                       'torch.Tensor.sign': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sign.html#torch.Tensor.sign',
                       'torch.Tensor.sign_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sign_.html#torch.Tensor.sign_',
                       'torch.Tensor.signbit': 'https://pytorch.org/docs/stable/generated/torch.Tensor.signbit.html#torch.Tensor.signbit',
                       'torch.Tensor.sin': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sin.html#torch.Tensor.sin',
                       'torch.Tensor.sin_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sin_.html#torch.Tensor.sin_',
                       'torch.Tensor.sinc': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sinc.html#torch.Tensor.sinc',
                       'torch.Tensor.sinc_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sinc_.html#torch.Tensor.sinc_',
                       'torch.Tensor.sinh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sinh.html#torch.Tensor.sinh',
                       'torch.Tensor.sinh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sinh_.html#torch.Tensor.sinh_',
                       'torch.Tensor.size': 'https://pytorch.org/docs/stable/generated/torch.Tensor.size.html#torch.Tensor.size',
                       'torch.Tensor.slice_scatter': 'https://pytorch.org/docs/stable/generated/torch.Tensor.slice_scatter.html#torch.Tensor.slice_scatter',
                       'torch.Tensor.slogdet': 'https://pytorch.org/docs/stable/generated/torch.Tensor.slogdet.html#torch.Tensor.slogdet',
                       'torch.Tensor.smm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.smm.html#torch.Tensor.smm',
                       'torch.Tensor.solve': 'https://pytorch.org/docs/stable/generated/torch.Tensor.solve.html#torch.Tensor.solve',
                       'torch.Tensor.sort': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sort.html#torch.Tensor.sort',
                       'torch.Tensor.sparse_dim': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sparse_dim.html#torch.Tensor.sparse_dim',
                       'torch.Tensor.sparse_mask': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sparse_mask.html#torch.Tensor.sparse_mask',
                       'torch.Tensor.sparse_resize_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sparse_resize_.html#torch.Tensor.sparse_resize_',
                       'torch.Tensor.sparse_resize_and_clear_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sparse_resize_and_clear_.html#torch.Tensor.sparse_resize_and_clear_',
                       'torch.Tensor.split': 'https://pytorch.org/docs/stable/generated/torch.Tensor.split.html#torch.Tensor.split',
                       'torch.Tensor.sqrt': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sqrt.html#torch.Tensor.sqrt',
                       'torch.Tensor.sqrt_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sqrt_.html#torch.Tensor.sqrt_',
                       'torch.Tensor.square': 'https://pytorch.org/docs/stable/generated/torch.Tensor.square.html#torch.Tensor.square',
                       'torch.Tensor.square_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.square_.html#torch.Tensor.square_',
                       'torch.Tensor.squeeze': 'https://pytorch.org/docs/stable/generated/torch.Tensor.squeeze.html#torch.Tensor.squeeze',
                       'torch.Tensor.squeeze_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.squeeze_.html#torch.Tensor.squeeze_',
                       'torch.Tensor.sspaddmm': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sspaddmm.html#torch.Tensor.sspaddmm',
                       'torch.Tensor.std': 'https://pytorch.org/docs/stable/generated/torch.Tensor.std.html#torch.Tensor.std',
                       'torch.Tensor.stft': 'https://pytorch.org/docs/stable/generated/torch.Tensor.stft.html#torch.Tensor.stft',
                       'torch.Tensor.storage': 'https://pytorch.org/docs/stable/generated/torch.Tensor.storage.html#torch.Tensor.storage',
                       'torch.Tensor.storage_offset': 'https://pytorch.org/docs/stable/generated/torch.Tensor.storage_offset.html#torch.Tensor.storage_offset',
                       'torch.Tensor.storage_type': 'https://pytorch.org/docs/stable/generated/torch.Tensor.storage_type.html#torch.Tensor.storage_type',
                       'torch.Tensor.stride': 'https://pytorch.org/docs/stable/generated/torch.Tensor.stride.html#torch.Tensor.stride',
                       'torch.Tensor.sub': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sub.html#torch.Tensor.sub',
                       'torch.Tensor.sub_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sub_.html#torch.Tensor.sub_',
                       'torch.Tensor.subtract': 'https://pytorch.org/docs/stable/generated/torch.Tensor.subtract.html#torch.Tensor.subtract',
                       'torch.Tensor.subtract_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.subtract_.html#torch.Tensor.subtract_',
                       'torch.Tensor.sum': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sum.html#torch.Tensor.sum',
                       'torch.Tensor.sum_to_size': 'https://pytorch.org/docs/stable/generated/torch.Tensor.sum_to_size.html#torch.Tensor.sum_to_size',
                       'torch.Tensor.svd': 'https://pytorch.org/docs/stable/generated/torch.Tensor.svd.html#torch.Tensor.svd',
                       'torch.Tensor.swapaxes': 'https://pytorch.org/docs/stable/generated/torch.Tensor.swapaxes.html#torch.Tensor.swapaxes',
                       'torch.Tensor.swapdims': 'https://pytorch.org/docs/stable/generated/torch.Tensor.swapdims.html#torch.Tensor.swapdims',
                       'torch.Tensor.symeig': 'https://pytorch.org/docs/stable/generated/torch.Tensor.symeig.html#torch.Tensor.symeig',
                       'torch.Tensor.t': 'https://pytorch.org/docs/stable/generated/torch.Tensor.t.html#torch.Tensor.t',
                       'torch.Tensor.t_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.t_.html#torch.Tensor.t_',
                       'torch.Tensor.take': 'https://pytorch.org/docs/stable/generated/torch.Tensor.take.html#torch.Tensor.take',
                       'torch.Tensor.take_along_dim': 'https://pytorch.org/docs/stable/generated/torch.Tensor.take_along_dim.html#torch.Tensor.take_along_dim',
                       'torch.Tensor.tan': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tan.html#torch.Tensor.tan',
                       'torch.Tensor.tan_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tan_.html#torch.Tensor.tan_',
                       'torch.Tensor.tanh': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tanh.html#torch.Tensor.tanh',
                       'torch.Tensor.tanh_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tanh_.html#torch.Tensor.tanh_',
                       'torch.Tensor.tensor_split': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tensor_split.html#torch.Tensor.tensor_split',
                       'torch.Tensor.tile': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tile.html#torch.Tensor.tile',
                       'torch.Tensor.to': 'https://pytorch.org/docs/stable/generated/torch.Tensor.to.html#torch.Tensor.to',
                       'torch.Tensor.to_dense': 'https://pytorch.org/docs/stable/generated/torch.Tensor.to_dense.html#torch.Tensor.to_dense',
                       'torch.Tensor.to_mkldnn': 'https://pytorch.org/docs/stable/generated/torch.Tensor.to_mkldnn.html#torch.Tensor.to_mkldnn',
                       'torch.Tensor.to_sparse': 'https://pytorch.org/docs/stable/generated/torch.Tensor.to_sparse.html#torch.Tensor.to_sparse',
                       'torch.Tensor.tolist': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tolist.html#torch.Tensor.tolist',
                       'torch.Tensor.topk': 'https://pytorch.org/docs/stable/generated/torch.Tensor.topk.html#torch.Tensor.topk',
                       'torch.Tensor.trace': 'https://pytorch.org/docs/stable/generated/torch.Tensor.trace.html#torch.Tensor.trace',
                       'torch.Tensor.transpose': 'https://pytorch.org/docs/stable/generated/torch.Tensor.transpose.html#torch.Tensor.transpose',
                       'torch.Tensor.transpose_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.transpose_.html#torch.Tensor.transpose_',
                       'torch.Tensor.triangular_solve': 'https://pytorch.org/docs/stable/generated/torch.Tensor.triangular_solve.html#torch.Tensor.triangular_solve',
                       'torch.Tensor.tril': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tril.html#torch.Tensor.tril',
                       'torch.Tensor.tril_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.tril_.html#torch.Tensor.tril_',
                       'torch.Tensor.triu': 'https://pytorch.org/docs/stable/generated/torch.Tensor.triu.html#torch.Tensor.triu',
                       'torch.Tensor.triu_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.triu_.html#torch.Tensor.triu_',
                       'torch.Tensor.true_divide': 'https://pytorch.org/docs/stable/generated/torch.Tensor.true_divide.html#torch.Tensor.true_divide',
                       'torch.Tensor.true_divide_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.true_divide_.html#torch.Tensor.true_divide_',
                       'torch.Tensor.trunc': 'https://pytorch.org/docs/stable/generated/torch.Tensor.trunc.html#torch.Tensor.trunc',
                       'torch.Tensor.trunc_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.trunc_.html#torch.Tensor.trunc_',
                       'torch.Tensor.type': 'https://pytorch.org/docs/stable/generated/torch.Tensor.type.html#torch.Tensor.type',
                       'torch.Tensor.type_as': 'https://pytorch.org/docs/stable/generated/torch.Tensor.type_as.html#torch.Tensor.type_as',
                       'torch.Tensor.unbind': 'https://pytorch.org/docs/stable/generated/torch.Tensor.unbind.html#torch.Tensor.unbind',
                       'torch.Tensor.unflatten': 'https://pytorch.org/docs/stable/named_tensor.html#torch.Tensor.unflatten',
                       'torch.Tensor.unfold': 'https://pytorch.org/docs/stable/generated/torch.Tensor.unfold.html#torch.Tensor.unfold',
                       'torch.Tensor.uniform_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.uniform_.html#torch.Tensor.uniform_',
                       'torch.Tensor.unique': 'https://pytorch.org/docs/stable/generated/torch.Tensor.unique.html#torch.Tensor.unique',
                       'torch.Tensor.unique_consecutive': 'https://pytorch.org/docs/stable/generated/torch.Tensor.unique_consecutive.html#torch.Tensor.unique_consecutive',
                       'torch.Tensor.unsqueeze': 'https://pytorch.org/docs/stable/generated/torch.Tensor.unsqueeze.html#torch.Tensor.unsqueeze',
                       'torch.Tensor.unsqueeze_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.unsqueeze_.html#torch.Tensor.unsqueeze_',
                       'torch.Tensor.values': 'https://pytorch.org/docs/stable/generated/torch.Tensor.values.html#torch.Tensor.values',
                       'torch.Tensor.var': 'https://pytorch.org/docs/stable/generated/torch.Tensor.var.html#torch.Tensor.var',
                       'torch.Tensor.vdot': 'https://pytorch.org/docs/stable/generated/torch.Tensor.vdot.html#torch.Tensor.vdot',
                       'torch.Tensor.view': 'https://pytorch.org/docs/stable/generated/torch.Tensor.view.html#torch.Tensor.view',
                       'torch.Tensor.view_as': 'https://pytorch.org/docs/stable/generated/torch.Tensor.view_as.html#torch.Tensor.view_as',
                       'torch.Tensor.vsplit': 'https://pytorch.org/docs/stable/generated/torch.Tensor.vsplit.html#torch.Tensor.vsplit',
                       'torch.Tensor.where': 'https://pytorch.org/docs/stable/generated/torch.Tensor.where.html#torch.Tensor.where',
                       'torch.Tensor.xlogy': 'https://pytorch.org/docs/stable/generated/torch.Tensor.xlogy.html#torch.Tensor.xlogy',
                       'torch.Tensor.xlogy_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.xlogy_.html#torch.Tensor.xlogy_',
                       'torch.Tensor.zero_': 'https://pytorch.org/docs/stable/generated/torch.Tensor.zero_.html#torch.Tensor.zero_',
                       'torch._assert': 'https://pytorch.org/docs/stable/generated/torch._assert.html#torch._assert',
                       'torch.abs': 'https://pytorch.org/docs/stable/generated/torch.abs.html#torch.abs',
                       'torch.absolute': 'https://pytorch.org/docs/stable/generated/torch.absolute.html#torch.absolute',
                       'torch.acos': 'https://pytorch.org/docs/stable/generated/torch.acos.html#torch.acos',
                       'torch.acosh': 'https://pytorch.org/docs/stable/generated/torch.acosh.html#torch.acosh',
                       'torch.add': 'https://pytorch.org/docs/stable/generated/torch.add.html#torch.add',
                       'torch.addbmm': 'https://pytorch.org/docs/stable/generated/torch.addbmm.html#torch.addbmm',
                       'torch.addcdiv': 'https://pytorch.org/docs/stable/generated/torch.addcdiv.html#torch.addcdiv',
                       'torch.addcmul': 'https://pytorch.org/docs/stable/generated/torch.addcmul.html#torch.addcmul',
                       'torch.addmm': 'https://pytorch.org/docs/stable/generated/torch.addmm.html#torch.addmm',
                       'torch.addmv': 'https://pytorch.org/docs/stable/generated/torch.addmv.html#torch.addmv',
                       'torch.addr': 'https://pytorch.org/docs/stable/generated/torch.addr.html#torch.addr',
                       'torch.adjoint': 'https://pytorch.org/docs/stable/generated/torch.adjoint.html#torch.adjoint',
                       'torch.all': 'https://pytorch.org/docs/stable/generated/torch.all.html#torch.all',
                       'torch.allclose': 'https://pytorch.org/docs/stable/generated/torch.allclose.html#torch.allclose',
                       'torch.amax': 'https://pytorch.org/docs/stable/generated/torch.amax.html#torch.amax',
                       'torch.amin': 'https://pytorch.org/docs/stable/generated/torch.amin.html#torch.amin',
                       'torch.aminmax': 'https://pytorch.org/docs/stable/generated/torch.aminmax.html#torch.aminmax',
                       'torch.angle': 'https://pytorch.org/docs/stable/generated/torch.angle.html#torch.angle',
                       'torch.any': 'https://pytorch.org/docs/stable/generated/torch.any.html#torch.any',
                       'torch.arange': 'https://pytorch.org/docs/stable/generated/torch.arange.html#torch.arange',
                       'torch.arccos': 'https://pytorch.org/docs/stable/generated/torch.arccos.html#torch.arccos',
                       'torch.arccosh': 'https://pytorch.org/docs/stable/generated/torch.arccosh.html#torch.arccosh',
                       'torch.arcsin': 'https://pytorch.org/docs/stable/generated/torch.arcsin.html#torch.arcsin',
                       'torch.arcsinh': 'https://pytorch.org/docs/stable/generated/torch.arcsinh.html#torch.arcsinh',
                       'torch.arctan': 'https://pytorch.org/docs/stable/generated/torch.arctan.html#torch.arctan',
                       'torch.arctan2': 'https://pytorch.org/docs/stable/generated/torch.arctan2.html#torch.arctan2',
                       'torch.arctanh': 'https://pytorch.org/docs/stable/generated/torch.arctanh.html#torch.arctanh',
                       'torch.are_deterministic_algorithms_enabled': 'https://pytorch.org/docs/stable/generated/torch.are_deterministic_algorithms_enabled.html#torch.are_deterministic_algorithms_enabled',
                       'torch.argmax': 'https://pytorch.org/docs/stable/generated/torch.argmax.html#torch.argmax',
                       'torch.argmin': 'https://pytorch.org/docs/stable/generated/torch.argmin.html#torch.argmin',
                       'torch.argsort': 'https://pytorch.org/docs/stable/generated/torch.argsort.html#torch.argsort',
                       'torch.argwhere': 'https://pytorch.org/docs/stable/generated/torch.argwhere.html#torch.argwhere',
                       'torch.as_strided': 'https://pytorch.org/docs/stable/generated/torch.as_strided.html#torch.as_strided',
                       'torch.as_tensor': 'https://pytorch.org/docs/stable/generated/torch.as_tensor.html#torch.as_tensor',
                       'torch.asarray': 'https://pytorch.org/docs/stable/generated/torch.asarray.html#torch.asarray',
                       'torch.asin': 'https://pytorch.org/docs/stable/generated/torch.asin.html#torch.asin',
                       'torch.asinh': 'https://pytorch.org/docs/stable/generated/torch.asinh.html#torch.asinh',
                       'torch.atan': 'https://pytorch.org/docs/stable/generated/torch.atan.html#torch.atan',
                       'torch.atan2': 'https://pytorch.org/docs/stable/generated/torch.atan2.html#torch.atan2',
                       'torch.atanh': 'https://pytorch.org/docs/stable/generated/torch.atanh.html#torch.atanh',
                       'torch.atleast_1d': 'https://pytorch.org/docs/stable/generated/torch.atleast_1d.html#torch.atleast_1d',
                       'torch.atleast_2d': 'https://pytorch.org/docs/stable/generated/torch.atleast_2d.html#torch.atleast_2d',
                       'torch.atleast_3d': 'https://pytorch.org/docs/stable/generated/torch.atleast_3d.html#torch.atleast_3d',
                       'torch.baddbmm': 'https://pytorch.org/docs/stable/generated/torch.baddbmm.html#torch.baddbmm',
                       'torch.bartlett_window': 'https://pytorch.org/docs/stable/generated/torch.bartlett_window.html#torch.bartlett_window',
                       'torch.bernoulli': 'https://pytorch.org/docs/stable/generated/torch.bernoulli.html#torch.bernoulli',
                       'torch.bincount': 'https://pytorch.org/docs/stable/generated/torch.bincount.html#torch.bincount',
                       'torch.bitwise_and': 'https://pytorch.org/docs/stable/generated/torch.bitwise_and.html#torch.bitwise_and',
                       'torch.bitwise_left_shift': 'https://pytorch.org/docs/stable/generated/torch.bitwise_left_shift.html#torch.bitwise_left_shift',
                       'torch.bitwise_not': 'https://pytorch.org/docs/stable/generated/torch.bitwise_not.html#torch.bitwise_not',
                       'torch.bitwise_or': 'https://pytorch.org/docs/stable/generated/torch.bitwise_or.html#torch.bitwise_or',
                       'torch.bitwise_right_shift': 'https://pytorch.org/docs/stable/generated/torch.bitwise_right_shift.html#torch.bitwise_right_shift',
                       'torch.bitwise_xor': 'https://pytorch.org/docs/stable/generated/torch.bitwise_xor.html#torch.bitwise_xor',
                       'torch.blackman_window': 'https://pytorch.org/docs/stable/generated/torch.blackman_window.html#torch.blackman_window',
                       'torch.block_diag': 'https://pytorch.org/docs/stable/generated/torch.block_diag.html#torch.block_diag',
                       'torch.bmm': 'https://pytorch.org/docs/stable/generated/torch.bmm.html#torch.bmm',
                       'torch.broadcast_shapes': 'https://pytorch.org/docs/stable/generated/torch.broadcast_shapes.html#torch.broadcast_shapes',
                       'torch.broadcast_tensors': 'https://pytorch.org/docs/stable/generated/torch.broadcast_tensors.html#torch.broadcast_tensors',
                       'torch.broadcast_to': 'https://pytorch.org/docs/stable/generated/torch.broadcast_to.html#torch.broadcast_to',
                       'torch.bucketize': 'https://pytorch.org/docs/stable/generated/torch.bucketize.html#torch.bucketize',
                       'torch.can_cast': 'https://pytorch.org/docs/stable/generated/torch.can_cast.html#torch.can_cast',
                       'torch.cartesian_prod': 'https://pytorch.org/docs/stable/generated/torch.cartesian_prod.html#torch.cartesian_prod',
                       'torch.cat': 'https://pytorch.org/docs/stable/generated/torch.cat.html#torch.cat',
                       'torch.cdist': 'https://pytorch.org/docs/stable/generated/torch.cdist.html#torch.cdist',
                       'torch.ceil': 'https://pytorch.org/docs/stable/generated/torch.ceil.html#torch.ceil',
                       'torch.chain_matmul': 'https://pytorch.org/docs/stable/generated/torch.chain_matmul.html#torch.chain_matmul',
                       'torch.cholesky': 'https://pytorch.org/docs/stable/generated/torch.cholesky.html#torch.cholesky',
                       'torch.cholesky_inverse': 'https://pytorch.org/docs/stable/generated/torch.cholesky_inverse.html#torch.cholesky_inverse',
                       'torch.cholesky_solve': 'https://pytorch.org/docs/stable/generated/torch.cholesky_solve.html#torch.cholesky_solve',
                       'torch.chunk': 'https://pytorch.org/docs/stable/generated/torch.chunk.html#torch.chunk',
                       'torch.clamp': 'https://pytorch.org/docs/stable/generated/torch.clamp.html#torch.clamp',
                       'torch.clip': 'https://pytorch.org/docs/stable/generated/torch.clip.html#torch.clip',
                       'torch.clone': 'https://pytorch.org/docs/stable/generated/torch.clone.html#torch.clone',
                       'torch.column_stack': 'https://pytorch.org/docs/stable/generated/torch.column_stack.html#torch.column_stack',
                       'torch.combinations': 'https://pytorch.org/docs/stable/generated/torch.combinations.html#torch.combinations',
                       'torch.compiled_with_cxx11_abi': 'https://pytorch.org/docs/stable/generated/torch.compiled_with_cxx11_abi.html#torch.compiled_with_cxx11_abi',
                       'torch.complex': 'https://pytorch.org/docs/stable/generated/torch.complex.html#torch.complex',
                       'torch.concat': 'https://pytorch.org/docs/stable/generated/torch.concat.html#torch.concat',
                       'torch.conj': 'https://pytorch.org/docs/stable/generated/torch.conj.html#torch.conj',
                       'torch.conj_physical': 'https://pytorch.org/docs/stable/generated/torch.conj_physical.html#torch.conj_physical',
                       'torch.copysign': 'https://pytorch.org/docs/stable/generated/torch.copysign.html#torch.copysign',
                       'torch.corrcoef': 'https://pytorch.org/docs/stable/generated/torch.corrcoef.html#torch.corrcoef',
                       'torch.cos': 'https://pytorch.org/docs/stable/generated/torch.cos.html#torch.cos',
                       'torch.cosh': 'https://pytorch.org/docs/stable/generated/torch.cosh.html#torch.cosh',
                       'torch.count_nonzero': 'https://pytorch.org/docs/stable/generated/torch.count_nonzero.html#torch.count_nonzero',
                       'torch.cov': 'https://pytorch.org/docs/stable/generated/torch.cov.html#torch.cov',
                       'torch.cross': 'https://pytorch.org/docs/stable/generated/torch.cross.html#torch.cross',
                       'torch.cummax': 'https://pytorch.org/docs/stable/generated/torch.cummax.html#torch.cummax',
                       'torch.cummin': 'https://pytorch.org/docs/stable/generated/torch.cummin.html#torch.cummin',
                       'torch.cumprod': 'https://pytorch.org/docs/stable/generated/torch.cumprod.html#torch.cumprod',
                       'torch.cumsum': 'https://pytorch.org/docs/stable/generated/torch.cumsum.html#torch.cumsum',
                       'torch.cumulative_trapezoid': 'https://pytorch.org/docs/stable/generated/torch.cumulative_trapezoid.html#torch.cumulative_trapezoid',
                       'torch.deg2rad': 'https://pytorch.org/docs/stable/generated/torch.deg2rad.html#torch.deg2rad',
                       'torch.dequantize': 'https://pytorch.org/docs/stable/generated/torch.dequantize.html#torch.dequantize',
                       'torch.det': 'https://pytorch.org/docs/stable/generated/torch.det.html#torch.det',
                       'torch.diag': 'https://pytorch.org/docs/stable/generated/torch.diag.html#torch.diag',
                       'torch.diag_embed': 'https://pytorch.org/docs/stable/generated/torch.diag_embed.html#torch.diag_embed',
                       'torch.diagflat': 'https://pytorch.org/docs/stable/generated/torch.diagflat.html#torch.diagflat',
                       'torch.diagonal': 'https://pytorch.org/docs/stable/generated/torch.diagonal.html#torch.diagonal',
                       'torch.diagonal_scatter': 'https://pytorch.org/docs/stable/generated/torch.diagonal_scatter.html#torch.diagonal_scatter',
                       'torch.diff': 'https://pytorch.org/docs/stable/generated/torch.diff.html#torch.diff',
                       'torch.digamma': 'https://pytorch.org/docs/stable/generated/torch.digamma.html#torch.digamma',
                       'torch.dist': 'https://pytorch.org/docs/stable/generated/torch.dist.html#torch.dist',
                       'torch.div': 'https://pytorch.org/docs/stable/generated/torch.div.html#torch.div',
                       'torch.divide': 'https://pytorch.org/docs/stable/generated/torch.divide.html#torch.divide',
                       'torch.dot': 'https://pytorch.org/docs/stable/generated/torch.dot.html#torch.dot',
                       'torch.dsplit': 'https://pytorch.org/docs/stable/generated/torch.dsplit.html#torch.dsplit',
                       'torch.dstack': 'https://pytorch.org/docs/stable/generated/torch.dstack.html#torch.dstack',
                       'torch.eig': 'https://pytorch.org/docs/stable/generated/torch.eig.html#torch.eig',
                       'torch.einsum': 'https://pytorch.org/docs/stable/generated/torch.einsum.html#torch.einsum',
                       'torch.empty': 'https://pytorch.org/docs/stable/generated/torch.empty.html#torch.empty',
                       'torch.empty_like': 'https://pytorch.org/docs/stable/generated/torch.empty_like.html#torch.empty_like',
                       'torch.empty_strided': 'https://pytorch.org/docs/stable/generated/torch.empty_strided.html#torch.empty_strided',
                       'torch.eq': 'https://pytorch.org/docs/stable/generated/torch.eq.html#torch.eq',
                       'torch.equal': 'https://pytorch.org/docs/stable/generated/torch.equal.html#torch.equal',
                       'torch.erf': 'https://pytorch.org/docs/stable/generated/torch.erf.html#torch.erf',
                       'torch.erfc': 'https://pytorch.org/docs/stable/generated/torch.erfc.html#torch.erfc',
                       'torch.erfinv': 'https://pytorch.org/docs/stable/generated/torch.erfinv.html#torch.erfinv',
                       'torch.exp': 'https://pytorch.org/docs/stable/generated/torch.exp.html#torch.exp',
                       'torch.exp2': 'https://pytorch.org/docs/stable/generated/torch.exp2.html#torch.exp2',
                       'torch.expm1': 'https://pytorch.org/docs/stable/generated/torch.expm1.html#torch.expm1',
                       'torch.eye': 'https://pytorch.org/docs/stable/generated/torch.eye.html#torch.eye',
                       'torch.fake_quantize_per_channel_affine': 'https://pytorch.org/docs/stable/generated/torch.fake_quantize_per_channel_affine.html#torch.fake_quantize_per_channel_affine',
                       'torch.fake_quantize_per_tensor_affine': 'https://pytorch.org/docs/stable/generated/torch.fake_quantize_per_tensor_affine.html#torch.fake_quantize_per_tensor_affine',
                       'torch.fix': 'https://pytorch.org/docs/stable/generated/torch.fix.html#torch.fix',
                       'torch.flatten': 'https://pytorch.org/docs/stable/generated/torch.flatten.html#torch.flatten',
                       'torch.flip': 'https://pytorch.org/docs/stable/generated/torch.flip.html#torch.flip',
                       'torch.fliplr': 'https://pytorch.org/docs/stable/generated/torch.fliplr.html#torch.fliplr',
                       'torch.flipud': 'https://pytorch.org/docs/stable/generated/torch.flipud.html#torch.flipud',
                       'torch.float_power': 'https://pytorch.org/docs/stable/generated/torch.float_power.html#torch.float_power',
                       'torch.floor': 'https://pytorch.org/docs/stable/generated/torch.floor.html#torch.floor',
                       'torch.floor_divide': 'https://pytorch.org/docs/stable/generated/torch.floor_divide.html#torch.floor_divide',
                       'torch.fmax': 'https://pytorch.org/docs/stable/generated/torch.fmax.html#torch.fmax',
                       'torch.fmin': 'https://pytorch.org/docs/stable/generated/torch.fmin.html#torch.fmin',
                       'torch.fmod': 'https://pytorch.org/docs/stable/generated/torch.fmod.html#torch.fmod',
                       'torch.frac': 'https://pytorch.org/docs/stable/generated/torch.frac.html#torch.frac',
                       'torch.frexp': 'https://pytorch.org/docs/stable/generated/torch.frexp.html#torch.frexp',
                       'torch.from_numpy': 'https://pytorch.org/docs/stable/generated/torch.from_numpy.html#torch.from_numpy',
                       'torch.frombuffer': 'https://pytorch.org/docs/stable/generated/torch.frombuffer.html#torch.frombuffer',
                       'torch.full': 'https://pytorch.org/docs/stable/generated/torch.full.html#torch.full',
                       'torch.full_like': 'https://pytorch.org/docs/stable/generated/torch.full_like.html#torch.full_like',
                       'torch.gather': 'https://pytorch.org/docs/stable/generated/torch.gather.html#torch.gather',
                       'torch.gcd': 'https://pytorch.org/docs/stable/generated/torch.gcd.html#torch.gcd',
                       'torch.ge': 'https://pytorch.org/docs/stable/generated/torch.ge.html#torch.ge',
                       'torch.geqrf': 'https://pytorch.org/docs/stable/generated/torch.geqrf.html#torch.geqrf',
                       'torch.ger': 'https://pytorch.org/docs/stable/generated/torch.ger.html#torch.ger',
                       'torch.get_default_dtype': 'https://pytorch.org/docs/stable/generated/torch.get_default_dtype.html#torch.get_default_dtype',
                       'torch.get_deterministic_debug_mode': 'https://pytorch.org/docs/stable/generated/torch.get_deterministic_debug_mode.html#torch.get_deterministic_debug_mode',
                       'torch.get_num_interop_threads': 'https://pytorch.org/docs/stable/generated/torch.get_num_interop_threads.html#torch.get_num_interop_threads',
                       'torch.get_num_threads': 'https://pytorch.org/docs/stable/generated/torch.get_num_threads.html#torch.get_num_threads',
                       'torch.get_rng_state': 'https://pytorch.org/docs/stable/generated/torch.get_rng_state.html#torch.get_rng_state',
                       'torch.gradient': 'https://pytorch.org/docs/stable/generated/torch.gradient.html#torch.gradient',
                       'torch.greater': 'https://pytorch.org/docs/stable/generated/torch.greater.html#torch.greater',
                       'torch.greater_equal': 'https://pytorch.org/docs/stable/generated/torch.greater_equal.html#torch.greater_equal',
                       'torch.gt': 'https://pytorch.org/docs/stable/generated/torch.gt.html#torch.gt',
                       'torch.hamming_window': 'https://pytorch.org/docs/stable/generated/torch.hamming_window.html#torch.hamming_window',
                       'torch.hann_window': 'https://pytorch.org/docs/stable/generated/torch.hann_window.html#torch.hann_window',
                       'torch.heaviside': 'https://pytorch.org/docs/stable/generated/torch.heaviside.html#torch.heaviside',
                       'torch.histc': 'https://pytorch.org/docs/stable/generated/torch.histc.html#torch.histc',
                       'torch.histogram': 'https://pytorch.org/docs/stable/generated/torch.histogram.html#torch.histogram',
                       'torch.histogramdd': 'https://pytorch.org/docs/stable/generated/torch.histogramdd.html#torch.histogramdd',
                       'torch.hsplit': 'https://pytorch.org/docs/stable/generated/torch.hsplit.html#torch.hsplit',
                       'torch.hspmm': 'https://pytorch.org/docs/stable/generated/torch.hspmm.html#torch.hspmm',
                       'torch.hstack': 'https://pytorch.org/docs/stable/generated/torch.hstack.html#torch.hstack',
                       'torch.hypot': 'https://pytorch.org/docs/stable/generated/torch.hypot.html#torch.hypot',
                       'torch.i0': 'https://pytorch.org/docs/stable/generated/torch.i0.html#torch.i0',
                       'torch.igamma': 'https://pytorch.org/docs/stable/generated/torch.igamma.html#torch.igamma',
                       'torch.igammac': 'https://pytorch.org/docs/stable/generated/torch.igammac.html#torch.igammac',
                       'torch.imag': 'https://pytorch.org/docs/stable/generated/torch.imag.html#torch.imag',
                       'torch.index_add': 'https://pytorch.org/docs/stable/generated/torch.index_add.html#torch.index_add',
                       'torch.index_select': 'https://pytorch.org/docs/stable/generated/torch.index_select.html#torch.index_select',
                       'torch.initial_seed': 'https://pytorch.org/docs/stable/generated/torch.initial_seed.html#torch.initial_seed',
                       'torch.inner': 'https://pytorch.org/docs/stable/generated/torch.inner.html#torch.inner',
                       'torch.inverse': 'https://pytorch.org/docs/stable/generated/torch.inverse.html#torch.inverse',
                       'torch.is_complex': 'https://pytorch.org/docs/stable/generated/torch.is_complex.html#torch.is_complex',
                       'torch.is_conj': 'https://pytorch.org/docs/stable/generated/torch.is_conj.html#torch.is_conj',
                       'torch.is_deterministic_algorithms_warn_only_enabled': 'https://pytorch.org/docs/stable/generated/torch.is_deterministic_algorithms_warn_only_enabled.html#torch.is_deterministic_algorithms_warn_only_enabled',
                       'torch.is_floating_point': 'https://pytorch.org/docs/stable/generated/torch.is_floating_point.html#torch.is_floating_point',
                       'torch.is_grad_enabled': 'https://pytorch.org/docs/stable/generated/torch.is_grad_enabled.html#torch.is_grad_enabled',
                       'torch.is_inference_mode_enabled': 'https://pytorch.org/docs/stable/generated/torch.is_inference_mode_enabled.html#torch.is_inference_mode_enabled',
                       'torch.is_nonzero': 'https://pytorch.org/docs/stable/generated/torch.is_nonzero.html#torch.is_nonzero',
                       'torch.is_storage': 'https://pytorch.org/docs/stable/generated/torch.is_storage.html#torch.is_storage',
                       'torch.is_tensor': 'https://pytorch.org/docs/stable/generated/torch.is_tensor.html#torch.is_tensor',
                       'torch.is_warn_always_enabled': 'https://pytorch.org/docs/stable/generated/torch.is_warn_always_enabled.html#torch.is_warn_always_enabled',
                       'torch.isclose': 'https://pytorch.org/docs/stable/generated/torch.isclose.html#torch.isclose',
                       'torch.isfinite': 'https://pytorch.org/docs/stable/generated/torch.isfinite.html#torch.isfinite',
                       'torch.isin': 'https://pytorch.org/docs/stable/generated/torch.isin.html#torch.isin',
                       'torch.isinf': 'https://pytorch.org/docs/stable/generated/torch.isinf.html#torch.isinf',
                       'torch.isnan': 'https://pytorch.org/docs/stable/generated/torch.isnan.html#torch.isnan',
                       'torch.isneginf': 'https://pytorch.org/docs/stable/generated/torch.isneginf.html#torch.isneginf',
                       'torch.isposinf': 'https://pytorch.org/docs/stable/generated/torch.isposinf.html#torch.isposinf',
                       'torch.isreal': 'https://pytorch.org/docs/stable/generated/torch.isreal.html#torch.isreal',
                       'torch.istft': 'https://pytorch.org/docs/stable/generated/torch.istft.html#torch.istft',
                       'torch.kaiser_window': 'https://pytorch.org/docs/stable/generated/torch.kaiser_window.html#torch.kaiser_window',
                       'torch.kron': 'https://pytorch.org/docs/stable/generated/torch.kron.html#torch.kron',
                       'torch.kthvalue': 'https://pytorch.org/docs/stable/generated/torch.kthvalue.html#torch.kthvalue',
                       'torch.lcm': 'https://pytorch.org/docs/stable/generated/torch.lcm.html#torch.lcm',
                       'torch.ldexp': 'https://pytorch.org/docs/stable/generated/torch.ldexp.html#torch.ldexp',
                       'torch.le': 'https://pytorch.org/docs/stable/generated/torch.le.html#torch.le',
                       'torch.lerp': 'https://pytorch.org/docs/stable/generated/torch.lerp.html#torch.lerp',
                       'torch.less': 'https://pytorch.org/docs/stable/generated/torch.less.html#torch.less',
                       'torch.less_equal': 'https://pytorch.org/docs/stable/generated/torch.less_equal.html#torch.less_equal',
                       'torch.lgamma': 'https://pytorch.org/docs/stable/generated/torch.lgamma.html#torch.lgamma',
                       'torch.linspace': 'https://pytorch.org/docs/stable/generated/torch.linspace.html#torch.linspace',
                       'torch.load': 'https://pytorch.org/docs/stable/generated/torch.load.html#torch.load',
                       'torch.lobpcg': 'https://pytorch.org/docs/stable/generated/torch.lobpcg.html#torch.lobpcg',
                       'torch.log': 'https://pytorch.org/docs/stable/generated/torch.log.html#torch.log',
                       'torch.log10': 'https://pytorch.org/docs/stable/generated/torch.log10.html#torch.log10',
                       'torch.log1p': 'https://pytorch.org/docs/stable/generated/torch.log1p.html#torch.log1p',
                       'torch.log2': 'https://pytorch.org/docs/stable/generated/torch.log2.html#torch.log2',
                       'torch.logaddexp': 'https://pytorch.org/docs/stable/generated/torch.logaddexp.html#torch.logaddexp',
                       'torch.logaddexp2': 'https://pytorch.org/docs/stable/generated/torch.logaddexp2.html#torch.logaddexp2',
                       'torch.logcumsumexp': 'https://pytorch.org/docs/stable/generated/torch.logcumsumexp.html#torch.logcumsumexp',
                       'torch.logdet': 'https://pytorch.org/docs/stable/generated/torch.logdet.html#torch.logdet',
                       'torch.logical_and': 'https://pytorch.org/docs/stable/generated/torch.logical_and.html#torch.logical_and',
                       'torch.logical_not': 'https://pytorch.org/docs/stable/generated/torch.logical_not.html#torch.logical_not',
                       'torch.logical_or': 'https://pytorch.org/docs/stable/generated/torch.logical_or.html#torch.logical_or',
                       'torch.logical_xor': 'https://pytorch.org/docs/stable/generated/torch.logical_xor.html#torch.logical_xor',
                       'torch.logit': 'https://pytorch.org/docs/stable/generated/torch.logit.html#torch.logit',
                       'torch.logspace': 'https://pytorch.org/docs/stable/generated/torch.logspace.html#torch.logspace',
                       'torch.logsumexp': 'https://pytorch.org/docs/stable/generated/torch.logsumexp.html#torch.logsumexp',
                       'torch.lstsq': 'https://pytorch.org/docs/stable/generated/torch.lstsq.html#torch.lstsq',
                       'torch.lt': 'https://pytorch.org/docs/stable/generated/torch.lt.html#torch.lt',
                       'torch.lu': 'https://pytorch.org/docs/stable/generated/torch.lu.html#torch.lu',
                       'torch.lu_solve': 'https://pytorch.org/docs/stable/generated/torch.lu_solve.html#torch.lu_solve',
                       'torch.lu_unpack': 'https://pytorch.org/docs/stable/generated/torch.lu_unpack.html#torch.lu_unpack',
                       'torch.manual_seed': 'https://pytorch.org/docs/stable/generated/torch.manual_seed.html#torch.manual_seed',
                       'torch.masked_select': 'https://pytorch.org/docs/stable/generated/torch.masked_select.html#torch.masked_select',
                       'torch.matmul': 'https://pytorch.org/docs/stable/generated/torch.matmul.html#torch.matmul',
                       'torch.matrix_exp': 'https://pytorch.org/docs/stable/generated/torch.matrix_exp.html#torch.matrix_exp',
                       'torch.matrix_power': 'https://pytorch.org/docs/stable/generated/torch.matrix_power.html#torch.matrix_power',
                       'torch.matrix_rank': 'https://pytorch.org/docs/stable/generated/torch.matrix_rank.html#torch.matrix_rank',
                       'torch.max': 'https://pytorch.org/docs/stable/generated/torch.max.html#torch.max',
                       'torch.maximum': 'https://pytorch.org/docs/stable/generated/torch.maximum.html#torch.maximum',
                       'torch.mean': 'https://pytorch.org/docs/stable/generated/torch.mean.html#torch.mean',
                       'torch.median': 'https://pytorch.org/docs/stable/generated/torch.median.html#torch.median',
                       'torch.meshgrid': 'https://pytorch.org/docs/stable/generated/torch.meshgrid.html#torch.meshgrid',
                       'torch.min': 'https://pytorch.org/docs/stable/generated/torch.min.html#torch.min',
                       'torch.minimum': 'https://pytorch.org/docs/stable/generated/torch.minimum.html#torch.minimum',
                       'torch.mm': 'https://pytorch.org/docs/stable/generated/torch.mm.html#torch.mm',
                       'torch.mode': 'https://pytorch.org/docs/stable/generated/torch.mode.html#torch.mode',
                       'torch.moveaxis': 'https://pytorch.org/docs/stable/generated/torch.moveaxis.html#torch.moveaxis',
                       'torch.movedim': 'https://pytorch.org/docs/stable/generated/torch.movedim.html#torch.movedim',
                       'torch.msort': 'https://pytorch.org/docs/stable/generated/torch.msort.html#torch.msort',
                       'torch.mul': 'https://pytorch.org/docs/stable/generated/torch.mul.html#torch.mul',
                       'torch.multinomial': 'https://pytorch.org/docs/stable/generated/torch.multinomial.html#torch.multinomial',
                       'torch.multiply': 'https://pytorch.org/docs/stable/generated/torch.multiply.html#torch.multiply',
                       'torch.mv': 'https://pytorch.org/docs/stable/generated/torch.mv.html#torch.mv',
                       'torch.mvlgamma': 'https://pytorch.org/docs/stable/generated/torch.mvlgamma.html#torch.mvlgamma',
                       'torch.nan_to_num': 'https://pytorch.org/docs/stable/generated/torch.nan_to_num.html#torch.nan_to_num',
                       'torch.nanmean': 'https://pytorch.org/docs/stable/generated/torch.nanmean.html#torch.nanmean',
                       'torch.nanmedian': 'https://pytorch.org/docs/stable/generated/torch.nanmedian.html#torch.nanmedian',
                       'torch.nanquantile': 'https://pytorch.org/docs/stable/generated/torch.nanquantile.html#torch.nanquantile',
                       'torch.nansum': 'https://pytorch.org/docs/stable/generated/torch.nansum.html#torch.nansum',
                       'torch.narrow': 'https://pytorch.org/docs/stable/generated/torch.narrow.html#torch.narrow',
                       'torch.ne': 'https://pytorch.org/docs/stable/generated/torch.ne.html#torch.ne',
                       'torch.neg': 'https://pytorch.org/docs/stable/generated/torch.neg.html#torch.neg',
                       'torch.negative': 'https://pytorch.org/docs/stable/generated/torch.negative.html#torch.negative',
                       'torch.nextafter': 'https://pytorch.org/docs/stable/generated/torch.nextafter.html#torch.nextafter',
                       'torch.nonzero': 'https://pytorch.org/docs/stable/generated/torch.nonzero.html#torch.nonzero',
                       'torch.norm': 'https://pytorch.org/docs/stable/generated/torch.norm.html#torch.norm',
                       'torch.normal': 'https://pytorch.org/docs/stable/generated/torch.normal.html#torch.normal',
                       'torch.not_equal': 'https://pytorch.org/docs/stable/generated/torch.not_equal.html#torch.not_equal',
                       'torch.numel': 'https://pytorch.org/docs/stable/generated/torch.numel.html#torch.numel',
                       'torch.ones': 'https://pytorch.org/docs/stable/generated/torch.ones.html#torch.ones',
                       'torch.ones_like': 'https://pytorch.org/docs/stable/generated/torch.ones_like.html#torch.ones_like',
                       'torch.orgqr': 'https://pytorch.org/docs/stable/generated/torch.orgqr.html#torch.orgqr',
                       'torch.ormqr': 'https://pytorch.org/docs/stable/generated/torch.ormqr.html#torch.ormqr',
                       'torch.outer': 'https://pytorch.org/docs/stable/generated/torch.outer.html#torch.outer',
                       'torch.pca_lowrank': 'https://pytorch.org/docs/stable/generated/torch.pca_lowrank.html#torch.pca_lowrank',
                       'torch.permute': 'https://pytorch.org/docs/stable/generated/torch.permute.html#torch.permute',
                       'torch.pinverse': 'https://pytorch.org/docs/stable/generated/torch.pinverse.html#torch.pinverse',
                       'torch.poisson': 'https://pytorch.org/docs/stable/generated/torch.poisson.html#torch.poisson',
                       'torch.polar': 'https://pytorch.org/docs/stable/generated/torch.polar.html#torch.polar',
                       'torch.polygamma': 'https://pytorch.org/docs/stable/generated/torch.polygamma.html#torch.polygamma',
                       'torch.positive': 'https://pytorch.org/docs/stable/generated/torch.positive.html#torch.positive',
                       'torch.pow': 'https://pytorch.org/docs/stable/generated/torch.pow.html#torch.pow',
                       'torch.prod': 'https://pytorch.org/docs/stable/generated/torch.prod.html#torch.prod',
                       'torch.promote_types': 'https://pytorch.org/docs/stable/generated/torch.promote_types.html#torch.promote_types',
                       'torch.qr': 'https://pytorch.org/docs/stable/generated/torch.qr.html#torch.qr',
                       'torch.quantile': 'https://pytorch.org/docs/stable/generated/torch.quantile.html#torch.quantile',
                       'torch.quantize_per_channel': 'https://pytorch.org/docs/stable/generated/torch.quantize_per_channel.html#torch.quantize_per_channel',
                       'torch.quantize_per_tensor': 'https://pytorch.org/docs/stable/generated/torch.quantize_per_tensor.html#torch.quantize_per_tensor',
                       'torch.quantized_batch_norm': 'https://pytorch.org/docs/stable/generated/torch.quantized_batch_norm.html#torch.quantized_batch_norm',
                       'torch.quantized_max_pool1d': 'https://pytorch.org/docs/stable/generated/torch.quantized_max_pool1d.html#torch.quantized_max_pool1d',
                       'torch.quantized_max_pool2d': 'https://pytorch.org/docs/stable/generated/torch.quantized_max_pool2d.html#torch.quantized_max_pool2d',
                       'torch.rad2deg': 'https://pytorch.org/docs/stable/generated/torch.rad2deg.html#torch.rad2deg',
                       'torch.rand': 'https://pytorch.org/docs/stable/generated/torch.rand.html#torch.rand',
                       'torch.rand_like': 'https://pytorch.org/docs/stable/generated/torch.rand_like.html#torch.rand_like',
                       'torch.randint': 'https://pytorch.org/docs/stable/generated/torch.randint.html#torch.randint',
                       'torch.randint_like': 'https://pytorch.org/docs/stable/generated/torch.randint_like.html#torch.randint_like',
                       'torch.randn': 'https://pytorch.org/docs/stable/generated/torch.randn.html#torch.randn',
                       'torch.randn_like': 'https://pytorch.org/docs/stable/generated/torch.randn_like.html#torch.randn_like',
                       'torch.randperm': 'https://pytorch.org/docs/stable/generated/torch.randperm.html#torch.randperm',
                       'torch.range': 'https://pytorch.org/docs/stable/generated/torch.range.html#torch.range',
                       'torch.ravel': 'https://pytorch.org/docs/stable/generated/torch.ravel.html#torch.ravel',
                       'torch.real': 'https://pytorch.org/docs/stable/generated/torch.real.html#torch.real',
                       'torch.reciprocal': 'https://pytorch.org/docs/stable/generated/torch.reciprocal.html#torch.reciprocal',
                       'torch.remainder': 'https://pytorch.org/docs/stable/generated/torch.remainder.html#torch.remainder',
                       'torch.renorm': 'https://pytorch.org/docs/stable/generated/torch.renorm.html#torch.renorm',
                       'torch.repeat_interleave': 'https://pytorch.org/docs/stable/generated/torch.repeat_interleave.html#torch.repeat_interleave',
                       'torch.reshape': 'https://pytorch.org/docs/stable/generated/torch.reshape.html#torch.reshape',
                       'torch.resolve_conj': 'https://pytorch.org/docs/stable/generated/torch.resolve_conj.html#torch.resolve_conj',
                       'torch.resolve_neg': 'https://pytorch.org/docs/stable/generated/torch.resolve_neg.html#torch.resolve_neg',
                       'torch.result_type': 'https://pytorch.org/docs/stable/generated/torch.result_type.html#torch.result_type',
                       'torch.roll': 'https://pytorch.org/docs/stable/generated/torch.roll.html#torch.roll',
                       'torch.rot90': 'https://pytorch.org/docs/stable/generated/torch.rot90.html#torch.rot90',
                       'torch.round': 'https://pytorch.org/docs/stable/generated/torch.round.html#torch.round',
                       'torch.row_stack': 'https://pytorch.org/docs/stable/generated/torch.row_stack.html#torch.row_stack',
                       'torch.rsqrt': 'https://pytorch.org/docs/stable/generated/torch.rsqrt.html#torch.rsqrt',
                       'torch.save': 'https://pytorch.org/docs/stable/generated/torch.save.html#torch.save',
                       'torch.scatter': 'https://pytorch.org/docs/stable/generated/torch.scatter.html#torch.scatter',
                       'torch.scatter_add': 'https://pytorch.org/docs/stable/generated/torch.scatter_add.html#torch.scatter_add',
                       'torch.scatter_reduce': 'https://pytorch.org/docs/stable/generated/torch.scatter_reduce.html#torch.scatter_reduce',
                       'torch.searchsorted': 'https://pytorch.org/docs/stable/generated/torch.searchsorted.html#torch.searchsorted',
                       'torch.seed': 'https://pytorch.org/docs/stable/generated/torch.seed.html#torch.seed',
                       'torch.select': 'https://pytorch.org/docs/stable/generated/torch.select.html#torch.select',
                       'torch.select_scatter': 'https://pytorch.org/docs/stable/generated/torch.select_scatter.html#torch.select_scatter',
                       'torch.set_default_dtype': 'https://pytorch.org/docs/stable/generated/torch.set_default_dtype.html#torch.set_default_dtype',
                       'torch.set_default_tensor_type': 'https://pytorch.org/docs/stable/generated/torch.set_default_tensor_type.html#torch.set_default_tensor_type',
                       'torch.set_deterministic_debug_mode': 'https://pytorch.org/docs/stable/generated/torch.set_deterministic_debug_mode.html#torch.set_deterministic_debug_mode',
                       'torch.set_flush_denormal': 'https://pytorch.org/docs/stable/generated/torch.set_flush_denormal.html#torch.set_flush_denormal',
                       'torch.set_num_interop_threads': 'https://pytorch.org/docs/stable/generated/torch.set_num_interop_threads.html#torch.set_num_interop_threads',
                       'torch.set_num_threads': 'https://pytorch.org/docs/stable/generated/torch.set_num_threads.html#torch.set_num_threads',
                       'torch.set_printoptions': 'https://pytorch.org/docs/stable/generated/torch.set_printoptions.html#torch.set_printoptions',
                       'torch.set_rng_state': 'https://pytorch.org/docs/stable/generated/torch.set_rng_state.html#torch.set_rng_state',
                       'torch.set_warn_always': 'https://pytorch.org/docs/stable/generated/torch.set_warn_always.html#torch.set_warn_always',
                       'torch.sgn': 'https://pytorch.org/docs/stable/generated/torch.sgn.html#torch.sgn',
                       'torch.sigmoid': 'https://pytorch.org/docs/stable/generated/torch.sigmoid.html#torch.sigmoid',
                       'torch.sign': 'https://pytorch.org/docs/stable/generated/torch.sign.html#torch.sign',
                       'torch.signbit': 'https://pytorch.org/docs/stable/generated/torch.signbit.html#torch.signbit',
                       'torch.sin': 'https://pytorch.org/docs/stable/generated/torch.sin.html#torch.sin',
                       'torch.sinc': 'https://pytorch.org/docs/stable/generated/torch.sinc.html#torch.sinc',
                       'torch.sinh': 'https://pytorch.org/docs/stable/generated/torch.sinh.html#torch.sinh',
                       'torch.slice_scatter': 'https://pytorch.org/docs/stable/generated/torch.slice_scatter.html#torch.slice_scatter',
                       'torch.slogdet': 'https://pytorch.org/docs/stable/generated/torch.slogdet.html#torch.slogdet',
                       'torch.smm': 'https://pytorch.org/docs/stable/generated/torch.smm.html#torch.smm',
                       'torch.solve': 'https://pytorch.org/docs/stable/generated/torch.solve.html#torch.solve',
                       'torch.sort': 'https://pytorch.org/docs/stable/generated/torch.sort.html#torch.sort',
                       'torch.sparse_coo_tensor': 'https://pytorch.org/docs/stable/generated/torch.sparse_coo_tensor.html#torch.sparse_coo_tensor',
                       'torch.sparse_csr_tensor': 'https://pytorch.org/docs/stable/generated/torch.sparse_csr_tensor.html#torch.sparse_csr_tensor',
                       'torch.split': 'https://pytorch.org/docs/stable/generated/torch.split.html#torch.split',
                       'torch.sqrt': 'https://pytorch.org/docs/stable/generated/torch.sqrt.html#torch.sqrt',
                       'torch.square': 'https://pytorch.org/docs/stable/generated/torch.square.html#torch.square',
                       'torch.squeeze': 'https://pytorch.org/docs/stable/generated/torch.squeeze.html#torch.squeeze',
                       'torch.sspaddmm': 'https://pytorch.org/docs/stable/generated/torch.sspaddmm.html#torch.sspaddmm',
                       'torch.stack': 'https://pytorch.org/docs/stable/generated/torch.stack.html#torch.stack',
                       'torch.std': 'https://pytorch.org/docs/stable/generated/torch.std.html#torch.std',
                       'torch.std_mean': 'https://pytorch.org/docs/stable/generated/torch.std_mean.html#torch.std_mean',
                       'torch.stft': 'https://pytorch.org/docs/stable/generated/torch.stft.html#torch.stft',
                       'torch.sub': 'https://pytorch.org/docs/stable/generated/torch.sub.html#torch.sub',
                       'torch.subtract': 'https://pytorch.org/docs/stable/generated/torch.subtract.html#torch.subtract',
                       'torch.sum': 'https://pytorch.org/docs/stable/generated/torch.sum.html#torch.sum',
                       'torch.svd': 'https://pytorch.org/docs/stable/generated/torch.svd.html#torch.svd',
                       'torch.svd_lowrank': 'https://pytorch.org/docs/stable/generated/torch.svd_lowrank.html#torch.svd_lowrank',
                       'torch.swapaxes': 'https://pytorch.org/docs/stable/generated/torch.swapaxes.html#torch.swapaxes',
                       'torch.swapdims': 'https://pytorch.org/docs/stable/generated/torch.swapdims.html#torch.swapdims',
                       'torch.symeig': 'https://pytorch.org/docs/stable/generated/torch.symeig.html#torch.symeig',
                       'torch.t': 'https://pytorch.org/docs/stable/generated/torch.t.html#torch.t',
                       'torch.take': 'https://pytorch.org/docs/stable/generated/torch.take.html#torch.take',
                       'torch.take_along_dim': 'https://pytorch.org/docs/stable/generated/torch.take_along_dim.html#torch.take_along_dim',
                       'torch.tan': 'https://pytorch.org/docs/stable/generated/torch.tan.html#torch.tan',
                       'torch.tanh': 'https://pytorch.org/docs/stable/generated/torch.tanh.html#torch.tanh',
                       'torch.tensor': 'https://pytorch.org/docs/stable/generated/torch.tensor.html#torch.tensor',
                       'torch.tensor_split': 'https://pytorch.org/docs/stable/generated/torch.tensor_split.html#torch.tensor_split',
                       'torch.tensordot': 'https://pytorch.org/docs/stable/generated/torch.tensordot.html#torch.tensordot',
                       'torch.tile': 'https://pytorch.org/docs/stable/generated/torch.tile.html#torch.tile',
                       'torch.topk': 'https://pytorch.org/docs/stable/generated/torch.topk.html#torch.topk',
                       'torch.trace': 'https://pytorch.org/docs/stable/generated/torch.trace.html#torch.trace',
                       'torch.transpose': 'https://pytorch.org/docs/stable/generated/torch.transpose.html#torch.transpose',
                       'torch.trapezoid': 'https://pytorch.org/docs/stable/generated/torch.trapezoid.html#torch.trapezoid',
                       'torch.trapz': 'https://pytorch.org/docs/stable/generated/torch.trapz.html#torch.trapz',
                       'torch.triangular_solve': 'https://pytorch.org/docs/stable/generated/torch.triangular_solve.html#torch.triangular_solve',
                       'torch.tril': 'https://pytorch.org/docs/stable/generated/torch.tril.html#torch.tril',
                       'torch.tril_indices': 'https://pytorch.org/docs/stable/generated/torch.tril_indices.html#torch.tril_indices',
                       'torch.triu': 'https://pytorch.org/docs/stable/generated/torch.triu.html#torch.triu',
                       'torch.triu_indices': 'https://pytorch.org/docs/stable/generated/torch.triu_indices.html#torch.triu_indices',
                       'torch.true_divide': 'https://pytorch.org/docs/stable/generated/torch.true_divide.html#torch.true_divide',
                       'torch.trunc': 'https://pytorch.org/docs/stable/generated/torch.trunc.html#torch.trunc',
                       'torch.unbind': 'https://pytorch.org/docs/stable/generated/torch.unbind.html#torch.unbind',
                       'torch.unique': 'https://pytorch.org/docs/stable/generated/torch.unique.html#torch.unique',
                       'torch.unique_consecutive': 'https://pytorch.org/docs/stable/generated/torch.unique_consecutive.html#torch.unique_consecutive',
                       'torch.unsqueeze': 'https://pytorch.org/docs/stable/generated/torch.unsqueeze.html#torch.unsqueeze',
                       'torch.use_deterministic_algorithms': 'https://pytorch.org/docs/stable/generated/torch.use_deterministic_algorithms.html#torch.use_deterministic_algorithms',
                       'torch.vander': 'https://pytorch.org/docs/stable/generated/torch.vander.html#torch.vander',
                       'torch.var': 'https://pytorch.org/docs/stable/generated/torch.var.html#torch.var',
                       'torch.var_mean': 'https://pytorch.org/docs/stable/generated/torch.var_mean.html#torch.var_mean',
                       'torch.vdot': 'https://pytorch.org/docs/stable/generated/torch.vdot.html#torch.vdot',
                       'torch.view_as_complex': 'https://pytorch.org/docs/stable/generated/torch.view_as_complex.html#torch.view_as_complex',
                       'torch.view_as_real': 'https://pytorch.org/docs/stable/generated/torch.view_as_real.html#torch.view_as_real',
                       'torch.vsplit': 'https://pytorch.org/docs/stable/generated/torch.vsplit.html#torch.vsplit',
                       'torch.vstack': 'https://pytorch.org/docs/stable/generated/torch.vstack.html#torch.vstack',
                       'torch.where': 'https://pytorch.org/docs/stable/generated/torch.where.html#torch.where',
                       'torch.xlogy': 'https://pytorch.org/docs/stable/generated/torch.xlogy.html#torch.xlogy',
                       'torch.zeros': 'https://pytorch.org/docs/stable/generated/torch.zeros.html#torch.zeros',
                       'torch.zeros_like': 'https://pytorch.org/docs/stable/generated/torch.zeros_like.html#torch.zeros_like'},
            'torch.ao.ns': { 'torch.ao.ns._numeric_suite': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#module-torch.ao.ns._numeric_suite',
                             'torch.ao.ns._numeric_suite_fx': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#module-torch.ao.ns._numeric_suite_fx'},
            'torch.cuda': { 'torch.cuda.amp': 'https://pytorch.org/docs/stable/amp.html#module-torch.cuda.amp',
                            'torch.cuda.CUDAGraph': 'https://pytorch.org/docs/stable/generated/torch.cuda.CUDAGraph.html#torch.cuda.CUDAGraph',
                            'torch.cuda.Event': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event',
                            'torch.cuda.ExternalStream': 'https://pytorch.org/docs/stable/generated/torch.cuda.ExternalStream.html#torch.cuda.ExternalStream',
                            'torch.cuda.Stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.Stream.html#torch.cuda.Stream',
                            'torch.cuda.StreamContext': 'https://pytorch.org/docs/stable/generated/torch.cuda.StreamContext.html#torch.cuda.StreamContext',
                            'torch.cuda.device': 'https://pytorch.org/docs/stable/generated/torch.cuda.device.html#torch.cuda.device',
                            'torch.cuda.device_of': 'https://pytorch.org/docs/stable/generated/torch.cuda.device_of.html#torch.cuda.device_of',
                            'torch.cuda.graph': 'https://pytorch.org/docs/stable/generated/torch.cuda.graph.html#torch.cuda.graph',
                            'torch.cuda.CUDAGraph.capture_begin': 'https://pytorch.org/docs/stable/generated/torch.cuda.CUDAGraph.html#torch.cuda.CUDAGraph.capture_begin',
                            'torch.cuda.CUDAGraph.capture_end': 'https://pytorch.org/docs/stable/generated/torch.cuda.CUDAGraph.html#torch.cuda.CUDAGraph.capture_end',
                            'torch.cuda.CUDAGraph.pool': 'https://pytorch.org/docs/stable/generated/torch.cuda.CUDAGraph.html#torch.cuda.CUDAGraph.pool',
                            'torch.cuda.CUDAGraph.replay': 'https://pytorch.org/docs/stable/generated/torch.cuda.CUDAGraph.html#torch.cuda.CUDAGraph.replay',
                            'torch.cuda.CUDAGraph.reset': 'https://pytorch.org/docs/stable/generated/torch.cuda.CUDAGraph.html#torch.cuda.CUDAGraph.reset',
                            'torch.cuda.Event.elapsed_time': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.elapsed_time',
                            'torch.cuda.Event.from_ipc_handle': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.from_ipc_handle',
                            'torch.cuda.Event.ipc_handle': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.ipc_handle',
                            'torch.cuda.Event.query': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.query',
                            'torch.cuda.Event.record': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.record',
                            'torch.cuda.Event.synchronize': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.synchronize',
                            'torch.cuda.Event.wait': 'https://pytorch.org/docs/stable/generated/torch.cuda.Event.html#torch.cuda.Event.wait',
                            'torch.cuda.ExternalStream.query': 'https://pytorch.org/docs/stable/generated/torch.cuda.ExternalStream.html#torch.cuda.ExternalStream.query',
                            'torch.cuda.ExternalStream.record_event': 'https://pytorch.org/docs/stable/generated/torch.cuda.ExternalStream.html#torch.cuda.ExternalStream.record_event',
                            'torch.cuda.ExternalStream.synchronize': 'https://pytorch.org/docs/stable/generated/torch.cuda.ExternalStream.html#torch.cuda.ExternalStream.synchronize',
                            'torch.cuda.ExternalStream.wait_event': 'https://pytorch.org/docs/stable/generated/torch.cuda.ExternalStream.html#torch.cuda.ExternalStream.wait_event',
                            'torch.cuda.ExternalStream.wait_stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.ExternalStream.html#torch.cuda.ExternalStream.wait_stream',
                            'torch.cuda.Stream.query': 'https://pytorch.org/docs/stable/generated/torch.cuda.Stream.html#torch.cuda.Stream.query',
                            'torch.cuda.Stream.record_event': 'https://pytorch.org/docs/stable/generated/torch.cuda.Stream.html#torch.cuda.Stream.record_event',
                            'torch.cuda.Stream.synchronize': 'https://pytorch.org/docs/stable/generated/torch.cuda.Stream.html#torch.cuda.Stream.synchronize',
                            'torch.cuda.Stream.wait_event': 'https://pytorch.org/docs/stable/generated/torch.cuda.Stream.html#torch.cuda.Stream.wait_event',
                            'torch.cuda.Stream.wait_stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.Stream.html#torch.cuda.Stream.wait_stream',
                            'torch.cuda.caching_allocator_alloc': 'https://pytorch.org/docs/stable/generated/torch.cuda.caching_allocator_alloc.html#torch.cuda.caching_allocator_alloc',
                            'torch.cuda.caching_allocator_delete': 'https://pytorch.org/docs/stable/generated/torch.cuda.caching_allocator_delete.html#torch.cuda.caching_allocator_delete',
                            'torch.cuda.can_device_access_peer': 'https://pytorch.org/docs/stable/generated/torch.cuda.can_device_access_peer.html#torch.cuda.can_device_access_peer',
                            'torch.cuda.current_blas_handle': 'https://pytorch.org/docs/stable/generated/torch.cuda.current_blas_handle.html#torch.cuda.current_blas_handle',
                            'torch.cuda.current_device': 'https://pytorch.org/docs/stable/generated/torch.cuda.current_device.html#torch.cuda.current_device',
                            'torch.cuda.current_stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.current_stream.html#torch.cuda.current_stream',
                            'torch.cuda.default_stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.default_stream.html#torch.cuda.default_stream',
                            'torch.cuda.device_count': 'https://pytorch.org/docs/stable/generated/torch.cuda.device_count.html#torch.cuda.device_count',
                            'torch.cuda.empty_cache': 'https://pytorch.org/docs/stable/generated/torch.cuda.empty_cache.html#torch.cuda.empty_cache',
                            'torch.cuda.get_arch_list': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_arch_list.html#torch.cuda.get_arch_list',
                            'torch.cuda.get_device_capability': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_device_capability.html#torch.cuda.get_device_capability',
                            'torch.cuda.get_device_name': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_device_name.html#torch.cuda.get_device_name',
                            'torch.cuda.get_device_properties': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_device_properties.html#torch.cuda.get_device_properties',
                            'torch.cuda.get_gencode_flags': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_gencode_flags.html#torch.cuda.get_gencode_flags',
                            'torch.cuda.get_rng_state': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_rng_state.html#torch.cuda.get_rng_state',
                            'torch.cuda.get_rng_state_all': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_rng_state_all.html#torch.cuda.get_rng_state_all',
                            'torch.cuda.get_sync_debug_mode': 'https://pytorch.org/docs/stable/generated/torch.cuda.get_sync_debug_mode.html#torch.cuda.get_sync_debug_mode',
                            'torch.cuda.graph_pool_handle': 'https://pytorch.org/docs/stable/generated/torch.cuda.graph_pool_handle.html#torch.cuda.graph_pool_handle',
                            'torch.cuda.init': 'https://pytorch.org/docs/stable/generated/torch.cuda.init.html#torch.cuda.init',
                            'torch.cuda.initial_seed': 'https://pytorch.org/docs/stable/generated/torch.cuda.initial_seed.html#torch.cuda.initial_seed',
                            'torch.cuda.ipc_collect': 'https://pytorch.org/docs/stable/generated/torch.cuda.ipc_collect.html#torch.cuda.ipc_collect',
                            'torch.cuda.is_available': 'https://pytorch.org/docs/stable/generated/torch.cuda.is_available.html#torch.cuda.is_available',
                            'torch.cuda.is_initialized': 'https://pytorch.org/docs/stable/generated/torch.cuda.is_initialized.html#torch.cuda.is_initialized',
                            'torch.cuda.list_gpu_processes': 'https://pytorch.org/docs/stable/generated/torch.cuda.list_gpu_processes.html#torch.cuda.list_gpu_processes',
                            'torch.cuda.make_graphed_callables': 'https://pytorch.org/docs/stable/generated/torch.cuda.make_graphed_callables.html#torch.cuda.make_graphed_callables',
                            'torch.cuda.manual_seed': 'https://pytorch.org/docs/stable/generated/torch.cuda.manual_seed.html#torch.cuda.manual_seed',
                            'torch.cuda.manual_seed_all': 'https://pytorch.org/docs/stable/generated/torch.cuda.manual_seed_all.html#torch.cuda.manual_seed_all',
                            'torch.cuda.max_memory_allocated': 'https://pytorch.org/docs/stable/generated/torch.cuda.max_memory_allocated.html#torch.cuda.max_memory_allocated',
                            'torch.cuda.max_memory_cached': 'https://pytorch.org/docs/stable/generated/torch.cuda.max_memory_cached.html#torch.cuda.max_memory_cached',
                            'torch.cuda.max_memory_reserved': 'https://pytorch.org/docs/stable/generated/torch.cuda.max_memory_reserved.html#torch.cuda.max_memory_reserved',
                            'torch.cuda.mem_get_info': 'https://pytorch.org/docs/stable/generated/torch.cuda.mem_get_info.html#torch.cuda.mem_get_info',
                            'torch.cuda.memory_allocated': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_allocated.html#torch.cuda.memory_allocated',
                            'torch.cuda.memory_cached': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_cached.html#torch.cuda.memory_cached',
                            'torch.cuda.memory_reserved': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_reserved.html#torch.cuda.memory_reserved',
                            'torch.cuda.memory_snapshot': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_snapshot.html#torch.cuda.memory_snapshot',
                            'torch.cuda.memory_stats': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_stats.html#torch.cuda.memory_stats',
                            'torch.cuda.memory_summary': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_summary.html#torch.cuda.memory_summary',
                            'torch.cuda.memory_usage': 'https://pytorch.org/docs/stable/generated/torch.cuda.memory_usage.html#torch.cuda.memory_usage',
                            'torch.cuda.reset_max_memory_allocated': 'https://pytorch.org/docs/stable/generated/torch.cuda.reset_max_memory_allocated.html#torch.cuda.reset_max_memory_allocated',
                            'torch.cuda.reset_max_memory_cached': 'https://pytorch.org/docs/stable/generated/torch.cuda.reset_max_memory_cached.html#torch.cuda.reset_max_memory_cached',
                            'torch.cuda.reset_peak_memory_stats': 'https://pytorch.org/docs/stable/generated/torch.cuda.reset_peak_memory_stats.html#torch.cuda.reset_peak_memory_stats',
                            'torch.cuda.seed': 'https://pytorch.org/docs/stable/generated/torch.cuda.seed.html#torch.cuda.seed',
                            'torch.cuda.seed_all': 'https://pytorch.org/docs/stable/generated/torch.cuda.seed_all.html#torch.cuda.seed_all',
                            'torch.cuda.set_device': 'https://pytorch.org/docs/stable/generated/torch.cuda.set_device.html#torch.cuda.set_device',
                            'torch.cuda.set_per_process_memory_fraction': 'https://pytorch.org/docs/stable/generated/torch.cuda.set_per_process_memory_fraction.html#torch.cuda.set_per_process_memory_fraction',
                            'torch.cuda.set_rng_state': 'https://pytorch.org/docs/stable/generated/torch.cuda.set_rng_state.html#torch.cuda.set_rng_state',
                            'torch.cuda.set_rng_state_all': 'https://pytorch.org/docs/stable/generated/torch.cuda.set_rng_state_all.html#torch.cuda.set_rng_state_all',
                            'torch.cuda.set_stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.set_stream.html#torch.cuda.set_stream',
                            'torch.cuda.set_sync_debug_mode': 'https://pytorch.org/docs/stable/generated/torch.cuda.set_sync_debug_mode.html#torch.cuda.set_sync_debug_mode',
                            'torch.cuda.stream': 'https://pytorch.org/docs/stable/generated/torch.cuda.stream.html#torch.cuda.stream',
                            'torch.cuda.synchronize': 'https://pytorch.org/docs/stable/generated/torch.cuda.synchronize.html#torch.cuda.synchronize',
                            'torch.cuda.utilization': 'https://pytorch.org/docs/stable/generated/torch.cuda.utilization.html#torch.cuda.utilization'},
            'torch.distributed': { 'torch.distributed.autograd': 'https://pytorch.org/docs/stable/rpc.html#module-torch.distributed.autograd',
                                   'torch.distributed.fsdp': 'https://pytorch.org/docs/stable/fsdp.html#module-torch.distributed.fsdp',
                                   'torch.distributed.launch': 'https://pytorch.org/docs/stable/distributed.html#module-torch.distributed.launch',
                                   'torch.distributed.optim': 'https://pytorch.org/docs/stable/distributed.optim.html#module-torch.distributed.optim',
                                   'torch.distributed.rpc': 'https://pytorch.org/docs/stable/rpc.html#module-torch.distributed.rpc',
                                   'torch.distributed.run': 'https://pytorch.org/docs/stable/elastic/run.html#module-torch.distributed.run',
                                   'torch.distributed.Backend': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Backend',
                                   'torch.distributed.FileStore': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.FileStore',
                                   'torch.distributed.GradBucket': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket',
                                   'torch.distributed.HashStore': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.HashStore',
                                   'torch.distributed.PrefixStore': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.PrefixStore',
                                   'torch.distributed.ReduceOp': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.ReduceOp',
                                   'torch.distributed.Store': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store',
                                   'torch.distributed.TCPStore': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.TCPStore',
                                   'torch.distributed.reduce_op': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.reduce_op',
                                   'torch.distributed.Backend.register_backend': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Backend.register_backend',
                                   'torch.distributed.all_gather': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.all_gather',
                                   'torch.distributed.all_gather_multigpu': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.all_gather_multigpu',
                                   'torch.distributed.all_gather_object': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.all_gather_object',
                                   'torch.distributed.all_reduce': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.all_reduce',
                                   'torch.distributed.all_reduce_multigpu': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.all_reduce_multigpu',
                                   'torch.distributed.all_to_all': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.all_to_all',
                                   'torch.distributed.barrier': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.barrier',
                                   'torch.distributed.broadcast': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.broadcast',
                                   'torch.distributed.broadcast_multigpu': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.broadcast_multigpu',
                                   'torch.distributed.broadcast_object_list': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.broadcast_object_list',
                                   'torch.distributed.gather': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.gather',
                                   'torch.distributed.gather_object': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.gather_object',
                                   'torch.distributed.get_backend': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.get_backend',
                                   'torch.distributed.get_rank': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.get_rank',
                                   'torch.distributed.get_world_size': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.get_world_size',
                                   'torch.distributed.init_process_group': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.init_process_group',
                                   'torch.distributed.irecv': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.irecv',
                                   'torch.distributed.is_available': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.is_available',
                                   'torch.distributed.is_initialized': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.is_initialized',
                                   'torch.distributed.is_mpi_available': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.is_mpi_available',
                                   'torch.distributed.is_nccl_available': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.is_nccl_available',
                                   'torch.distributed.is_torchelastic_launched': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.is_torchelastic_launched',
                                   'torch.distributed.isend': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.isend',
                                   'torch.distributed.monitored_barrier': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.monitored_barrier',
                                   'torch.distributed.new_group': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.new_group',
                                   'torch.distributed.recv': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.recv',
                                   'torch.distributed.reduce': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.reduce',
                                   'torch.distributed.reduce_multigpu': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.reduce_multigpu',
                                   'torch.distributed.reduce_scatter': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.reduce_scatter',
                                   'torch.distributed.reduce_scatter_multigpu': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.reduce_scatter_multigpu',
                                   'torch.distributed.scatter': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.scatter',
                                   'torch.distributed.scatter_object_list': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.scatter_object_list',
                                   'torch.distributed.send': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.send'},
            'torch.distributed.elastic': { 'torch.distributed.elastic.agent': 'https://pytorch.org/docs/stable/elastic/agent.html#module-torch.distributed.elastic.agent',
                                           'torch.distributed.elastic.events': 'https://pytorch.org/docs/stable/elastic/events.html#module-torch.distributed.elastic.events',
                                           'torch.distributed.elastic.metrics': 'https://pytorch.org/docs/stable/elastic/metrics.html#module-torch.distributed.elastic.metrics',
                                           'torch.distributed.elastic.multiprocessing': 'https://pytorch.org/docs/stable/elastic/multiprocessing.html#module-torch.distributed.elastic.multiprocessing',
                                           'torch.distributed.elastic.rendezvous': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#module-torch.distributed.elastic.rendezvous',
                                           'torch.distributed.elastic.timer': 'https://pytorch.org/docs/stable/elastic/timer.html#module-torch.distributed.elastic.timer'},
            'torch.distributed.elastic.agent': { 'torch.distributed.elastic.agent.server': 'https://pytorch.org/docs/stable/elastic/agent.html#module-torch.distributed.elastic.agent.server'},
            'torch.distributed.elastic.multiprocessing': { 'torch.distributed.elastic.multiprocessing.errors': 'https://pytorch.org/docs/stable/elastic/errors.html#module-torch.distributed.elastic.multiprocessing.errors',
                                                           'torch.distributed.elastic.multiprocessing.start_processes': 'https://pytorch.org/docs/stable/elastic/multiprocessing.html#torch.distributed.elastic.multiprocessing.start_processes'},
            'torch.distributed.elastic.rendezvous': { 'torch.distributed.elastic.rendezvous.registry': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#module-torch.distributed.elastic.rendezvous.registry',
                                                      'torch.distributed.elastic.rendezvous.RendezvousClosedError': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousClosedError',
                                                      'torch.distributed.elastic.rendezvous.RendezvousConnectionError': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousConnectionError',
                                                      'torch.distributed.elastic.rendezvous.RendezvousError': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousError',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandlerRegistry': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandlerRegistry',
                                                      'torch.distributed.elastic.rendezvous.RendezvousParameters': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousParameters',
                                                      'torch.distributed.elastic.rendezvous.RendezvousStateError': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousStateError',
                                                      'torch.distributed.elastic.rendezvous.RendezvousTimeoutError': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousTimeoutError',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.get_backend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.get_backend',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.get_run_id': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.get_run_id',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.is_closed': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.is_closed',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.next_rendezvous': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.next_rendezvous',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.num_nodes_waiting': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.num_nodes_waiting',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.set_closed': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.set_closed',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandler.shutdown': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandler.shutdown',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandlerRegistry.create_handler': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandlerRegistry.create_handler',
                                                      'torch.distributed.elastic.rendezvous.RendezvousHandlerRegistry.register': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousHandlerRegistry.register',
                                                      'torch.distributed.elastic.rendezvous.RendezvousParameters.get': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousParameters.get',
                                                      'torch.distributed.elastic.rendezvous.RendezvousParameters.get_as_bool': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousParameters.get_as_bool',
                                                      'torch.distributed.elastic.rendezvous.RendezvousParameters.get_as_int': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.RendezvousParameters.get_as_int'},
            'torch.distributions': { 'torch.distributions.constraint_registry': 'https://pytorch.org/docs/stable/distributions.html#module-torch.distributions.constraint_registry',
                                     'torch.distributions.constraints': 'https://pytorch.org/docs/stable/distributions.html#module-torch.distributions.constraints',
                                     'torch.distributions.kl': 'https://pytorch.org/docs/stable/distributions.html#module-torch.distributions.kl',
                                     'torch.distributions.transforms': 'https://pytorch.org/docs/stable/distributions.html#module-torch.distributions.transforms'},
            'torch.jit': { 'torch.jit.supported_ops': 'https://pytorch.org/docs/stable/jit_builtin_functions.html#module-torch.jit.supported_ops',
                           'torch.jit.unsupported_tensor_ops': 'https://pytorch.org/docs/stable/jit_unsupported.html#module-torch.jit.unsupported_tensor_ops',
                           'torch.jit.Attribute': 'https://pytorch.org/docs/stable/generated/torch.jit.Attribute.html#torch.jit.Attribute',
                           'torch.jit.ScriptFunction': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptFunction.html#torch.jit.ScriptFunction',
                           'torch.jit.ScriptModule': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule',
                           'torch.jit.Attribute.count': 'https://pytorch.org/docs/stable/generated/torch.jit.Attribute.html#torch.jit.Attribute.count',
                           'torch.jit.Attribute.index': 'https://pytorch.org/docs/stable/generated/torch.jit.Attribute.html#torch.jit.Attribute.index',
                           'torch.jit.Attribute.type': 'https://pytorch.org/docs/stable/generated/torch.jit.Attribute.html#torch.jit.Attribute.type',
                           'torch.jit.Attribute.value': 'https://pytorch.org/docs/stable/generated/torch.jit.Attribute.html#torch.jit.Attribute.value',
                           'torch.jit.ScriptFunction.get_debug_state': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptFunction.html#torch.jit.ScriptFunction.get_debug_state',
                           'torch.jit.ScriptFunction.save': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptFunction.html#torch.jit.ScriptFunction.save',
                           'torch.jit.ScriptFunction.save_to_buffer': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptFunction.html#torch.jit.ScriptFunction.save_to_buffer',
                           'torch.jit.ScriptModule.add_module': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.add_module',
                           'torch.jit.ScriptModule.apply': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.apply',
                           'torch.jit.ScriptModule.bfloat16': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.bfloat16',
                           'torch.jit.ScriptModule.buffers': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.buffers',
                           'torch.jit.ScriptModule.children': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.children',
                           'torch.jit.ScriptModule.code': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.code',
                           'torch.jit.ScriptModule.code_with_constants': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.code_with_constants',
                           'torch.jit.ScriptModule.cpu': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.cpu',
                           'torch.jit.ScriptModule.cuda': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.cuda',
                           'torch.jit.ScriptModule.double': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.double',
                           'torch.jit.ScriptModule.eval': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.eval',
                           'torch.jit.ScriptModule.extra_repr': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.extra_repr',
                           'torch.jit.ScriptModule.float': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.float',
                           'torch.jit.ScriptModule.get_buffer': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.get_buffer',
                           'torch.jit.ScriptModule.get_extra_state': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.get_extra_state',
                           'torch.jit.ScriptModule.get_parameter': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.get_parameter',
                           'torch.jit.ScriptModule.get_submodule': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.get_submodule',
                           'torch.jit.ScriptModule.graph': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.graph',
                           'torch.jit.ScriptModule.half': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.half',
                           'torch.jit.ScriptModule.inlined_graph': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.inlined_graph',
                           'torch.jit.ScriptModule.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.load_state_dict',
                           'torch.jit.ScriptModule.modules': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.modules',
                           'torch.jit.ScriptModule.named_buffers': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.named_buffers',
                           'torch.jit.ScriptModule.named_children': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.named_children',
                           'torch.jit.ScriptModule.named_modules': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.named_modules',
                           'torch.jit.ScriptModule.named_parameters': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.named_parameters',
                           'torch.jit.ScriptModule.parameters': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.parameters',
                           'torch.jit.ScriptModule.register_backward_hook': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_backward_hook',
                           'torch.jit.ScriptModule.register_buffer': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_buffer',
                           'torch.jit.ScriptModule.register_forward_hook': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_forward_hook',
                           'torch.jit.ScriptModule.register_forward_pre_hook': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_forward_pre_hook',
                           'torch.jit.ScriptModule.register_full_backward_hook': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_full_backward_hook',
                           'torch.jit.ScriptModule.register_module': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_module',
                           'torch.jit.ScriptModule.register_parameter': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.register_parameter',
                           'torch.jit.ScriptModule.requires_grad_': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.requires_grad_',
                           'torch.jit.ScriptModule.save': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.save',
                           'torch.jit.ScriptModule.set_extra_state': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.set_extra_state',
                           'torch.jit.ScriptModule.share_memory': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.share_memory',
                           'torch.jit.ScriptModule.state_dict': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.state_dict',
                           'torch.jit.ScriptModule.to': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.to',
                           'torch.jit.ScriptModule.to_empty': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.to_empty',
                           'torch.jit.ScriptModule.train': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.train',
                           'torch.jit.ScriptModule.type': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.type',
                           'torch.jit.ScriptModule.xpu': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.xpu',
                           'torch.jit.ScriptModule.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.jit.ScriptModule.html#torch.jit.ScriptModule.zero_grad',
                           'torch.jit.annotate': 'https://pytorch.org/docs/stable/generated/torch.jit.annotate.html#torch.jit.annotate',
                           'torch.jit.export': 'https://pytorch.org/docs/stable/jit.html#torch.jit.export',
                           'torch.jit.fork': 'https://pytorch.org/docs/stable/generated/torch.jit.fork.html#torch.jit.fork',
                           'torch.jit.freeze': 'https://pytorch.org/docs/stable/generated/torch.jit.freeze.html#torch.jit.freeze',
                           'torch.jit.ignore': 'https://pytorch.org/docs/stable/generated/torch.jit.ignore.html#torch.jit.ignore',
                           'torch.jit.is_scripting': 'https://pytorch.org/docs/stable/jit_language_reference.html#torch.jit.is_scripting',
                           'torch.jit.is_tracing': 'https://pytorch.org/docs/stable/jit_language_reference.html#torch.jit.is_tracing',
                           'torch.jit.isinstance': 'https://pytorch.org/docs/stable/generated/torch.jit.isinstance.html#torch.jit.isinstance',
                           'torch.jit.load': 'https://pytorch.org/docs/stable/generated/torch.jit.load.html#torch.jit.load',
                           'torch.jit.optimize_for_inference': 'https://pytorch.org/docs/stable/generated/torch.jit.optimize_for_inference.html#torch.jit.optimize_for_inference',
                           'torch.jit.save': 'https://pytorch.org/docs/stable/generated/torch.jit.save.html#torch.jit.save',
                           'torch.jit.script': 'https://pytorch.org/docs/stable/generated/torch.jit.script.html#torch.jit.script',
                           'torch.jit.script_if_tracing': 'https://pytorch.org/docs/stable/generated/torch.jit.script_if_tracing.html#torch.jit.script_if_tracing',
                           'torch.jit.set_fusion_strategy': 'https://pytorch.org/docs/stable/generated/torch.jit.set_fusion_strategy.html#torch.jit.set_fusion_strategy',
                           'torch.jit.trace': 'https://pytorch.org/docs/stable/generated/torch.jit.trace.html#torch.jit.trace',
                           'torch.jit.trace_module': 'https://pytorch.org/docs/stable/generated/torch.jit.trace_module.html#torch.jit.trace_module',
                           'torch.jit.unused': 'https://pytorch.org/docs/stable/generated/torch.jit.unused.html#torch.jit.unused',
                           'torch.jit.wait': 'https://pytorch.org/docs/stable/generated/torch.jit.wait.html#torch.jit.wait'},
            'torch.utils': { 'torch.utils.benchmark': 'https://pytorch.org/docs/stable/benchmark_utils.html#module-torch.utils.benchmark',
                             'torch.utils.data': 'https://pytorch.org/docs/stable/data.html#module-torch.utils.data',
                             'torch.utils.model_zoo': 'https://pytorch.org/docs/stable/model_zoo.html#module-torch.utils.model_zoo'},
            'torch.ao.ns._numeric_suite': { 'torch.ao.ns._numeric_suite.Logger': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Logger',
                                            'torch.ao.ns._numeric_suite.OutputLogger': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.OutputLogger',
                                            'torch.ao.ns._numeric_suite.Shadow': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow',
                                            'torch.ao.ns._numeric_suite.ShadowLogger': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.ShadowLogger',
                                            'torch.ao.ns._numeric_suite.Logger.forward': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Logger.forward',
                                            'torch.ao.ns._numeric_suite.OutputLogger.forward': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.OutputLogger.forward',
                                            'torch.ao.ns._numeric_suite.Shadow.add': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.add',
                                            'torch.ao.ns._numeric_suite.Shadow.add_relu': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.add_relu',
                                            'torch.ao.ns._numeric_suite.Shadow.add_scalar': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.add_scalar',
                                            'torch.ao.ns._numeric_suite.Shadow.cat': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.cat',
                                            'torch.ao.ns._numeric_suite.Shadow.forward': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.forward',
                                            'torch.ao.ns._numeric_suite.Shadow.mul': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.mul',
                                            'torch.ao.ns._numeric_suite.Shadow.mul_scalar': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.Shadow.mul_scalar',
                                            'torch.ao.ns._numeric_suite.ShadowLogger.forward': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.ShadowLogger.forward',
                                            'torch.ao.ns._numeric_suite.compare_model_outputs': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.compare_model_outputs',
                                            'torch.ao.ns._numeric_suite.compare_model_stub': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.compare_model_stub',
                                            'torch.ao.ns._numeric_suite.compare_weights': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.compare_weights',
                                            'torch.ao.ns._numeric_suite.get_logger_dict': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.get_logger_dict',
                                            'torch.ao.ns._numeric_suite.get_matching_activations': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.get_matching_activations',
                                            'torch.ao.ns._numeric_suite.prepare_model_outputs': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.prepare_model_outputs',
                                            'torch.ao.ns._numeric_suite.prepare_model_with_stubs': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite.html#torch.ao.ns._numeric_suite.prepare_model_with_stubs'},
            'torch.ao.ns._numeric_suite_fx': { 'torch.ao.ns._numeric_suite_fx.NSTracer': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.NSTracer',
                                               'torch.ao.ns._numeric_suite_fx.OutputLogger': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.OutputLogger',
                                               'torch.ao.ns._numeric_suite_fx.NSTracer.is_leaf_module': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.NSTracer.is_leaf_module',
                                               'torch.ao.ns._numeric_suite_fx.OutputLogger.forward': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.OutputLogger.forward',
                                               'torch.ao.ns._numeric_suite_fx.add_loggers': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.add_loggers',
                                               'torch.ao.ns._numeric_suite_fx.add_shadow_loggers': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.add_shadow_loggers',
                                               'torch.ao.ns._numeric_suite_fx.extend_logger_results_with_comparison': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.extend_logger_results_with_comparison',
                                               'torch.ao.ns._numeric_suite_fx.extract_logger_info': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.extract_logger_info',
                                               'torch.ao.ns._numeric_suite_fx.extract_shadow_logger_info': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.extract_shadow_logger_info',
                                               'torch.ao.ns._numeric_suite_fx.extract_weights': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns._numeric_suite_fx.extract_weights'},
            'torch.autograd': { 'torch.autograd.Function': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.Function',
                                'torch.autograd.detect_anomaly': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.detect_anomaly',
                                'torch.autograd.enable_grad': 'https://pytorch.org/docs/stable/generated/torch.autograd.enable_grad.html#torch.autograd.enable_grad',
                                'torch.autograd.inference_mode': 'https://pytorch.org/docs/stable/generated/torch.autograd.inference_mode.html#torch.autograd.inference_mode',
                                'torch.autograd.no_grad': 'https://pytorch.org/docs/stable/generated/torch.autograd.no_grad.html#torch.autograd.no_grad',
                                'torch.autograd.set_detect_anomaly': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.set_detect_anomaly',
                                'torch.autograd.set_grad_enabled': 'https://pytorch.org/docs/stable/generated/torch.autograd.set_grad_enabled.html#torch.autograd.set_grad_enabled',
                                'torch.autograd.Function.backward': 'https://pytorch.org/docs/stable/generated/torch.autograd.Function.backward.html#torch.autograd.Function.backward',
                                'torch.autograd.Function.forward': 'https://pytorch.org/docs/stable/generated/torch.autograd.Function.forward.html#torch.autograd.Function.forward',
                                'torch.autograd.Function.jvp': 'https://pytorch.org/docs/stable/generated/torch.autograd.Function.jvp.html#torch.autograd.Function.jvp',
                                'torch.autograd.backward': 'https://pytorch.org/docs/stable/generated/torch.autograd.backward.html#torch.autograd.backward',
                                'torch.autograd.grad': 'https://pytorch.org/docs/stable/generated/torch.autograd.grad.html#torch.autograd.grad',
                                'torch.autograd.gradcheck': 'https://pytorch.org/docs/stable/generated/torch.autograd.gradcheck.html#torch.autograd.gradcheck',
                                'torch.autograd.gradgradcheck': 'https://pytorch.org/docs/stable/generated/torch.autograd.gradgradcheck.html#torch.autograd.gradgradcheck'},
            'torch.autograd.forward_ad': { 'torch.autograd.forward_ad.dual_level': 'https://pytorch.org/docs/stable/generated/torch.autograd.forward_ad.dual_level.html#torch.autograd.forward_ad.dual_level',
                                           'torch.autograd.forward_ad.make_dual': 'https://pytorch.org/docs/stable/generated/torch.autograd.forward_ad.make_dual.html#torch.autograd.forward_ad.make_dual',
                                           'torch.autograd.forward_ad.unpack_dual': 'https://pytorch.org/docs/stable/generated/torch.autograd.forward_ad.unpack_dual.html#torch.autograd.forward_ad.unpack_dual'},
            'torch.autograd.graph': { 'torch.autograd.graph.save_on_cpu': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.graph.save_on_cpu',
                                      'torch.autograd.graph.saved_tensors_hooks': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.graph.saved_tensors_hooks'},
            'torch.autograd.profiler': { 'torch.autograd.profiler.emit_nvtx': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.profiler.emit_nvtx',
                                         'torch.autograd.profiler.profile': 'https://pytorch.org/docs/stable/autograd.html#torch.autograd.profiler.profile',
                                         'torch.autograd.profiler.profile.export_chrome_trace': 'https://pytorch.org/docs/stable/generated/torch.autograd.profiler.profile.export_chrome_trace.html#torch.autograd.profiler.profile.export_chrome_trace',
                                         'torch.autograd.profiler.profile.key_averages': 'https://pytorch.org/docs/stable/generated/torch.autograd.profiler.profile.key_averages.html#torch.autograd.profiler.profile.key_averages',
                                         'torch.autograd.profiler.profile.self_cpu_time_total': 'https://pytorch.org/docs/stable/generated/torch.autograd.profiler.profile.self_cpu_time_total.html#torch.autograd.profiler.profile.self_cpu_time_total',
                                         'torch.autograd.profiler.profile.total_average': 'https://pytorch.org/docs/stable/generated/torch.autograd.profiler.profile.total_average.html#torch.autograd.profiler.profile.total_average',
                                         'torch.autograd.profiler.load_nvprof': 'https://pytorch.org/docs/stable/generated/torch.autograd.profiler.load_nvprof.html#torch.autograd.profiler.load_nvprof'},
            'torch.cuda.amp': { 'torch.cuda.amp.GradScaler': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler',
                                'torch.cuda.amp.autocast': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.autocast',
                                'torch.cuda.amp.GradScaler.get_backoff_factor': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.get_backoff_factor',
                                'torch.cuda.amp.GradScaler.get_growth_factor': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.get_growth_factor',
                                'torch.cuda.amp.GradScaler.get_growth_interval': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.get_growth_interval',
                                'torch.cuda.amp.GradScaler.get_scale': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.get_scale',
                                'torch.cuda.amp.GradScaler.is_enabled': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.is_enabled',
                                'torch.cuda.amp.GradScaler.load_state_dict': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.load_state_dict',
                                'torch.cuda.amp.GradScaler.scale': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.scale',
                                'torch.cuda.amp.GradScaler.set_backoff_factor': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.set_backoff_factor',
                                'torch.cuda.amp.GradScaler.set_growth_factor': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.set_growth_factor',
                                'torch.cuda.amp.GradScaler.set_growth_interval': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.set_growth_interval',
                                'torch.cuda.amp.GradScaler.state_dict': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.state_dict',
                                'torch.cuda.amp.GradScaler.step': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.step',
                                'torch.cuda.amp.GradScaler.unscale_': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.unscale_',
                                'torch.cuda.amp.GradScaler.update': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.GradScaler.update',
                                'torch.cuda.amp.custom_bwd': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.custom_bwd',
                                'torch.cuda.amp.custom_fwd': 'https://pytorch.org/docs/stable/amp.html#torch.cuda.amp.custom_fwd'},
            'torch.distributed.algorithms': { 'torch.distributed.algorithms.Join': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.Join',
                                              'torch.distributed.algorithms.JoinHook': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.JoinHook',
                                              'torch.distributed.algorithms.Joinable': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.Joinable',
                                              'torch.distributed.algorithms.Join.notify_join_context': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.Join.notify_join_context',
                                              'torch.distributed.algorithms.JoinHook.main_hook': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.JoinHook.main_hook',
                                              'torch.distributed.algorithms.JoinHook.post_hook': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.JoinHook.post_hook',
                                              'torch.distributed.algorithms.Joinable.join_device': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.Joinable.join_device',
                                              'torch.distributed.algorithms.Joinable.join_hook': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.Joinable.join_hook',
                                              'torch.distributed.algorithms.Joinable.join_process_group': 'https://pytorch.org/docs/stable/distributed.algorithms.join.html#torch.distributed.algorithms.Joinable.join_process_group'},
            'torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook': { 'torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook.PowerSGDState': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook.PowerSGDState',
                                                                           'torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook.batched_powerSGD_hook': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook.batched_powerSGD_hook',
                                                                           'torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook.powerSGD_hook': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.powerSGD_hook.powerSGD_hook'},
            'torch.distributed.autograd': { 'torch.distributed.autograd.context': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.autograd.context',
                                            'torch.distributed.autograd.backward': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.autograd.backward',
                                            'torch.distributed.autograd.get_gradients': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.autograd.get_gradients'},
            'torch.distributed.elastic.agent.server': { 'torch.distributed.elastic.agent.server.ElasticAgent': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.ElasticAgent',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent',
                                                        'torch.distributed.elastic.agent.server.Worker': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.Worker',
                                                        'torch.distributed.elastic.agent.server.WorkerGroup': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.WorkerGroup',
                                                        'torch.distributed.elastic.agent.server.WorkerSpec': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.WorkerSpec',
                                                        'torch.distributed.elastic.agent.server.WorkerState': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.WorkerState',
                                                        'torch.distributed.elastic.agent.server.ElasticAgent.get_worker_group': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.ElasticAgent.get_worker_group',
                                                        'torch.distributed.elastic.agent.server.ElasticAgent.run': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.ElasticAgent.run',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._assign_worker_ranks': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._assign_worker_ranks',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._exit_barrier': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._exit_barrier',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._initialize_workers': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._initialize_workers',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._monitor_workers': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._monitor_workers',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._rendezvous': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._rendezvous',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._restart_workers': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._restart_workers',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._shutdown': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._shutdown',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._start_workers': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._start_workers',
                                                        'torch.distributed.elastic.agent.server.SimpleElasticAgent._stop_workers': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.SimpleElasticAgent._stop_workers',
                                                        'torch.distributed.elastic.agent.server.WorkerSpec.get_entrypoint_name': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.WorkerSpec.get_entrypoint_name',
                                                        'torch.distributed.elastic.agent.server.WorkerState.is_running': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.WorkerState.is_running'},
            'torch.distributed.elastic.agent.server.api': { 'torch.distributed.elastic.agent.server.api.RunResult': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.api.RunResult'},
            'torch.distributed.elastic.agent.server.local_elastic_agent': { 'torch.distributed.elastic.agent.server.local_elastic_agent.LocalElasticAgent': 'https://pytorch.org/docs/stable/elastic/agent.html#torch.distributed.elastic.agent.server.local_elastic_agent.LocalElasticAgent'},
            'torch.distributed.elastic.events.api': { 'torch.distributed.elastic.events.api.Event': 'https://pytorch.org/docs/stable/elastic/events.html#torch.distributed.elastic.events.api.Event',
                                                      'torch.distributed.elastic.events.api.EventSource': 'https://pytorch.org/docs/stable/elastic/events.html#torch.distributed.elastic.events.api.EventSource'},
            'torch.distributed.elastic.metrics.api': { 'torch.distributed.elastic.metrics.api.ConsoleMetricHandler': 'https://pytorch.org/docs/stable/elastic/metrics.html#torch.distributed.elastic.metrics.api.ConsoleMetricHandler',
                                                       'torch.distributed.elastic.metrics.api.MetricHandler': 'https://pytorch.org/docs/stable/elastic/metrics.html#torch.distributed.elastic.metrics.api.MetricHandler',
                                                       'torch.distributed.elastic.metrics.api.NullMetricHandler': 'https://pytorch.org/docs/stable/elastic/metrics.html#torch.distributed.elastic.metrics.api.NullMetricHandler'},
            'torch.distributed.elastic.multiprocessing.api': { 'torch.distributed.elastic.multiprocessing.api.MultiprocessContext': 'https://pytorch.org/docs/stable/elastic/multiprocessing.html#torch.distributed.elastic.multiprocessing.api.MultiprocessContext',
                                                               'torch.distributed.elastic.multiprocessing.api.PContext': 'https://pytorch.org/docs/stable/elastic/multiprocessing.html#torch.distributed.elastic.multiprocessing.api.PContext',
                                                               'torch.distributed.elastic.multiprocessing.api.RunProcsResult': 'https://pytorch.org/docs/stable/elastic/multiprocessing.html#torch.distributed.elastic.multiprocessing.api.RunProcsResult',
                                                               'torch.distributed.elastic.multiprocessing.api.SubprocessContext': 'https://pytorch.org/docs/stable/elastic/multiprocessing.html#torch.distributed.elastic.multiprocessing.api.SubprocessContext'},
            'torch.distributed.elastic.multiprocessing.errors': { 'torch.distributed.elastic.multiprocessing.errors.ChildFailedError': 'https://pytorch.org/docs/stable/elastic/errors.html#torch.distributed.elastic.multiprocessing.errors.ChildFailedError',
                                                                  'torch.distributed.elastic.multiprocessing.errors.ErrorHandler': 'https://pytorch.org/docs/stable/elastic/errors.html#torch.distributed.elastic.multiprocessing.errors.ErrorHandler',
                                                                  'torch.distributed.elastic.multiprocessing.errors.ProcessFailure': 'https://pytorch.org/docs/stable/elastic/errors.html#torch.distributed.elastic.multiprocessing.errors.ProcessFailure',
                                                                  'torch.distributed.elastic.multiprocessing.errors.record': 'https://pytorch.org/docs/stable/elastic/errors.html#torch.distributed.elastic.multiprocessing.errors.record'},
            'torch.distributed.elastic.rendezvous.c10d_rendezvous_backend': { 'torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend',
                                                                              'torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend.get_state': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend.get_state',
                                                                              'torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend.name': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend.name',
                                                                              'torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend.set_state': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.C10dRendezvousBackend.set_state',
                                                                              'torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.create_backend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.c10d_rendezvous_backend.create_backend'},
            'torch.distributed.elastic.rendezvous.dynamic_rendezvous': { 'torch.distributed.elastic.rendezvous.dynamic_rendezvous.DynamicRendezvousHandler': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.DynamicRendezvousHandler',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.DynamicRendezvousHandler.from_backend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.DynamicRendezvousHandler.from_backend',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend.get_state': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend.get_state',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend.name': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend.name',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend.set_state': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousBackend.set_state',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.close': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.close',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.heartbeat': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.heartbeat',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.join': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.join',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.last_call': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.RendezvousTimeout.last_call',
                                                                         'torch.distributed.elastic.rendezvous.dynamic_rendezvous.create_handler': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.dynamic_rendezvous.create_handler'},
            'torch.distributed.elastic.rendezvous.etcd_rendezvous': { 'torch.distributed.elastic.rendezvous.etcd_rendezvous.EtcdRendezvousHandler': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_rendezvous.EtcdRendezvousHandler'},
            'torch.distributed.elastic.rendezvous.etcd_rendezvous_backend': { 'torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend',
                                                                              'torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend.get_state': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend.get_state',
                                                                              'torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend.name': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend.name',
                                                                              'torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend.set_state': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.EtcdRendezvousBackend.set_state',
                                                                              'torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.create_backend': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_rendezvous_backend.create_backend'},
            'torch.distributed.elastic.rendezvous.etcd_server': { 'torch.distributed.elastic.rendezvous.etcd_server.EtcdServer': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_server.EtcdServer'},
            'torch.distributed.elastic.rendezvous.etcd_store': { 'torch.distributed.elastic.rendezvous.etcd_store.EtcdStore': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_store.EtcdStore',
                                                                 'torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.add': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.add',
                                                                 'torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.check': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.check',
                                                                 'torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.get': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.get',
                                                                 'torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.set': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.set',
                                                                 'torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.wait': 'https://pytorch.org/docs/stable/elastic/rendezvous.html#torch.distributed.elastic.rendezvous.etcd_store.EtcdStore.wait'},
            'torch.distributed.elastic.timer': { 'torch.distributed.elastic.timer.LocalTimerClient': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.LocalTimerClient',
                                                 'torch.distributed.elastic.timer.LocalTimerServer': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.LocalTimerServer',
                                                 'torch.distributed.elastic.timer.TimerClient': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerClient',
                                                 'torch.distributed.elastic.timer.TimerRequest': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerRequest',
                                                 'torch.distributed.elastic.timer.TimerServer': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerServer',
                                                 'torch.distributed.elastic.timer.TimerClient.acquire': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerClient.acquire',
                                                 'torch.distributed.elastic.timer.TimerClient.release': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerClient.release',
                                                 'torch.distributed.elastic.timer.TimerServer.clear_timers': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerServer.clear_timers',
                                                 'torch.distributed.elastic.timer.TimerServer.get_expired_timers': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerServer.get_expired_timers',
                                                 'torch.distributed.elastic.timer.TimerServer.register_timers': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.TimerServer.register_timers',
                                                 'torch.distributed.elastic.timer.configure': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.configure',
                                                 'torch.distributed.elastic.timer.expires': 'https://pytorch.org/docs/stable/elastic/timer.html#torch.distributed.elastic.timer.expires'},
            'torch.distributed.fsdp': { 'torch.distributed.fsdp.FullyShardedDataParallel': 'https://pytorch.org/docs/stable/fsdp.html#torch.distributed.fsdp.FullyShardedDataParallel',
                                        'torch.distributed.fsdp.FullyShardedDataParallel.module': 'https://pytorch.org/docs/stable/fsdp.html#torch.distributed.fsdp.FullyShardedDataParallel.module'},
            'torch.distributed.nn.api.remote_module': { 'torch.distributed.nn.api.remote_module.RemoteModule': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.nn.api.remote_module.RemoteModule',
                                                        'torch.distributed.nn.api.remote_module.RemoteModule.get_module_rref': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.nn.api.remote_module.RemoteModule.get_module_rref',
                                                        'torch.distributed.nn.api.remote_module.RemoteModule.remote_parameters': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.nn.api.remote_module.RemoteModule.remote_parameters'},
            'torch.distributed.optim': { 'torch.distributed.optim.DistributedOptimizer': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.DistributedOptimizer',
                                         'torch.distributed.optim.PostLocalSGDOptimizer': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.PostLocalSGDOptimizer',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer',
                                         'torch.distributed.optim.DistributedOptimizer.step': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.DistributedOptimizer.step',
                                         'torch.distributed.optim.PostLocalSGDOptimizer.step': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.PostLocalSGDOptimizer.step',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer.add_param_group': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer.add_param_group',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer.consolidate_state_dict': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer.consolidate_state_dict',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer.join_hook': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer.join_hook',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer.load_state_dict': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer.load_state_dict',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer.state_dict': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer.state_dict',
                                         'torch.distributed.optim.ZeroRedundancyOptimizer.step': 'https://pytorch.org/docs/stable/distributed.optim.html#torch.distributed.optim.ZeroRedundancyOptimizer.step'},
            'torch.distributed.pipeline.sync': { 'torch.distributed.pipeline.sync.Pipe': 'https://pytorch.org/docs/stable/pipeline.html#torch.distributed.pipeline.sync.Pipe',
                                                 'torch.distributed.pipeline.sync.Pipe.forward': 'https://pytorch.org/docs/stable/pipeline.html#torch.distributed.pipeline.sync.Pipe.forward'},
            'torch.distributed.pipeline.sync.skip.skippable': { 'torch.distributed.pipeline.sync.skip.skippable.pop': 'https://pytorch.org/docs/stable/pipeline.html#torch.distributed.pipeline.sync.skip.skippable.pop',
                                                                'torch.distributed.pipeline.sync.skip.skippable.stash': 'https://pytorch.org/docs/stable/pipeline.html#torch.distributed.pipeline.sync.skip.skippable.stash',
                                                                'torch.distributed.pipeline.sync.skip.skippable.skippable': 'https://pytorch.org/docs/stable/pipeline.html#torch.distributed.pipeline.sync.skip.skippable.skippable',
                                                                'torch.distributed.pipeline.sync.skip.skippable.verify_skippables': 'https://pytorch.org/docs/stable/pipeline.html#torch.distributed.pipeline.sync.skip.skippable.verify_skippables'},
            'torch.distributed.rpc': { 'torch.distributed.rpc.BackendType': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.BackendType',
                                       'torch.distributed.rpc.RRef': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef',
                                       'torch.distributed.rpc.RpcBackendOptions': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RpcBackendOptions',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions',
                                       'torch.distributed.rpc.WorkerInfo': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.WorkerInfo',
                                       'torch.distributed.rpc.RRef.backward': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.backward',
                                       'torch.distributed.rpc.RRef.confirmed_by_owner': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.confirmed_by_owner',
                                       'torch.distributed.rpc.RRef.is_owner': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.is_owner',
                                       'torch.distributed.rpc.RRef.local_value': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.local_value',
                                       'torch.distributed.rpc.RRef.owner': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.owner',
                                       'torch.distributed.rpc.RRef.owner_name': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.owner_name',
                                       'torch.distributed.rpc.RRef.remote': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.remote',
                                       'torch.distributed.rpc.RRef.rpc_async': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.rpc_async',
                                       'torch.distributed.rpc.RRef.rpc_sync': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.rpc_sync',
                                       'torch.distributed.rpc.RRef.to_here': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RRef.to_here',
                                       'torch.distributed.rpc.RpcBackendOptions.init_method': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RpcBackendOptions.init_method',
                                       'torch.distributed.rpc.RpcBackendOptions.rpc_timeout': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.RpcBackendOptions.rpc_timeout',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.device_maps': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.device_maps',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.devices': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.devices',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.init_method': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.init_method',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.num_worker_threads': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.num_worker_threads',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.rpc_timeout': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.rpc_timeout',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.set_device_map': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.set_device_map',
                                       'torch.distributed.rpc.TensorPipeRpcBackendOptions.set_devices': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.TensorPipeRpcBackendOptions.set_devices',
                                       'torch.distributed.rpc.WorkerInfo.id': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.WorkerInfo.id',
                                       'torch.distributed.rpc.WorkerInfo.name': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.WorkerInfo.name',
                                       'torch.distributed.rpc.get_worker_info': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.get_worker_info',
                                       'torch.distributed.rpc.init_rpc': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.init_rpc',
                                       'torch.distributed.rpc.remote': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.remote',
                                       'torch.distributed.rpc.rpc_async': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.rpc_async',
                                       'torch.distributed.rpc.rpc_sync': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.rpc_sync',
                                       'torch.distributed.rpc.shutdown': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.shutdown'},
            'torch.distributions.bernoulli': { 'torch.distributions.bernoulli.Bernoulli': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli',
                                               'torch.distributions.bernoulli.Bernoulli.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.entropy',
                                               'torch.distributions.bernoulli.Bernoulli.enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.enumerate_support',
                                               'torch.distributions.bernoulli.Bernoulli.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.expand',
                                               'torch.distributions.bernoulli.Bernoulli.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.log_prob',
                                               'torch.distributions.bernoulli.Bernoulli.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.logits',
                                               'torch.distributions.bernoulli.Bernoulli.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.mean',
                                               'torch.distributions.bernoulli.Bernoulli.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.param_shape',
                                               'torch.distributions.bernoulli.Bernoulli.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.probs',
                                               'torch.distributions.bernoulli.Bernoulli.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.sample',
                                               'torch.distributions.bernoulli.Bernoulli.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.bernoulli.Bernoulli.variance'},
            'torch.distributions.beta': { 'torch.distributions.beta.Beta': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta',
                                          'torch.distributions.beta.Beta.concentration0': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.concentration0',
                                          'torch.distributions.beta.Beta.concentration1': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.concentration1',
                                          'torch.distributions.beta.Beta.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.entropy',
                                          'torch.distributions.beta.Beta.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.expand',
                                          'torch.distributions.beta.Beta.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.log_prob',
                                          'torch.distributions.beta.Beta.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.mean',
                                          'torch.distributions.beta.Beta.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.rsample',
                                          'torch.distributions.beta.Beta.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.beta.Beta.variance'},
            'torch.distributions.binomial': { 'torch.distributions.binomial.Binomial': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial',
                                              'torch.distributions.binomial.Binomial.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.entropy',
                                              'torch.distributions.binomial.Binomial.enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.enumerate_support',
                                              'torch.distributions.binomial.Binomial.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.expand',
                                              'torch.distributions.binomial.Binomial.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.log_prob',
                                              'torch.distributions.binomial.Binomial.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.logits',
                                              'torch.distributions.binomial.Binomial.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.mean',
                                              'torch.distributions.binomial.Binomial.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.param_shape',
                                              'torch.distributions.binomial.Binomial.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.probs',
                                              'torch.distributions.binomial.Binomial.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.sample',
                                              'torch.distributions.binomial.Binomial.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.support',
                                              'torch.distributions.binomial.Binomial.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.binomial.Binomial.variance'},
            'torch.distributions.categorical': { 'torch.distributions.categorical.Categorical': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical',
                                                 'torch.distributions.categorical.Categorical.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.entropy',
                                                 'torch.distributions.categorical.Categorical.enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.enumerate_support',
                                                 'torch.distributions.categorical.Categorical.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.expand',
                                                 'torch.distributions.categorical.Categorical.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.log_prob',
                                                 'torch.distributions.categorical.Categorical.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.logits',
                                                 'torch.distributions.categorical.Categorical.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.mean',
                                                 'torch.distributions.categorical.Categorical.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.param_shape',
                                                 'torch.distributions.categorical.Categorical.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.probs',
                                                 'torch.distributions.categorical.Categorical.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.sample',
                                                 'torch.distributions.categorical.Categorical.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.support',
                                                 'torch.distributions.categorical.Categorical.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.categorical.Categorical.variance'},
            'torch.distributions.cauchy': { 'torch.distributions.cauchy.Cauchy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy',
                                            'torch.distributions.cauchy.Cauchy.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.cdf',
                                            'torch.distributions.cauchy.Cauchy.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.entropy',
                                            'torch.distributions.cauchy.Cauchy.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.expand',
                                            'torch.distributions.cauchy.Cauchy.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.icdf',
                                            'torch.distributions.cauchy.Cauchy.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.log_prob',
                                            'torch.distributions.cauchy.Cauchy.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.mean',
                                            'torch.distributions.cauchy.Cauchy.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.rsample',
                                            'torch.distributions.cauchy.Cauchy.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.cauchy.Cauchy.variance'},
            'torch.distributions.chi2': { 'torch.distributions.chi2.Chi2': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.chi2.Chi2',
                                          'torch.distributions.chi2.Chi2.df': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.chi2.Chi2.df',
                                          'torch.distributions.chi2.Chi2.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.chi2.Chi2.expand'},
            'torch.distributions.constraint_registry': { 'torch.distributions.constraint_registry.ConstraintRegistry': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.constraint_registry.ConstraintRegistry',
                                                         'torch.distributions.constraint_registry.ConstraintRegistry.register': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.constraint_registry.ConstraintRegistry.register'},
            'torch.distributions.constraints': { 'torch.distributions.constraints.Constraint': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.constraints.Constraint',
                                                 'torch.distributions.constraints.Constraint.check': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.constraints.Constraint.check'},
            'torch.distributions.continuous_bernoulli': { 'torch.distributions.continuous_bernoulli.ContinuousBernoulli': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.cdf',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.entropy',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.expand',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.icdf',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.log_prob',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.logits',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.mean',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.param_shape',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.probs',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.rsample',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.sample',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.stddev',
                                                          'torch.distributions.continuous_bernoulli.ContinuousBernoulli.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.continuous_bernoulli.ContinuousBernoulli.variance'},
            'torch.distributions.dirichlet': { 'torch.distributions.dirichlet.Dirichlet': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet',
                                               'torch.distributions.dirichlet.Dirichlet.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet.entropy',
                                               'torch.distributions.dirichlet.Dirichlet.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet.expand',
                                               'torch.distributions.dirichlet.Dirichlet.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet.log_prob',
                                               'torch.distributions.dirichlet.Dirichlet.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet.mean',
                                               'torch.distributions.dirichlet.Dirichlet.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet.rsample',
                                               'torch.distributions.dirichlet.Dirichlet.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.dirichlet.Dirichlet.variance'},
            'torch.distributions.distribution': { 'torch.distributions.distribution.Distribution': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution',
                                                  'torch.distributions.distribution.Distribution.arg_constraints': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.arg_constraints',
                                                  'torch.distributions.distribution.Distribution.batch_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.batch_shape',
                                                  'torch.distributions.distribution.Distribution.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.cdf',
                                                  'torch.distributions.distribution.Distribution.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.entropy',
                                                  'torch.distributions.distribution.Distribution.enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.enumerate_support',
                                                  'torch.distributions.distribution.Distribution.event_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.event_shape',
                                                  'torch.distributions.distribution.Distribution.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.expand',
                                                  'torch.distributions.distribution.Distribution.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.icdf',
                                                  'torch.distributions.distribution.Distribution.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.log_prob',
                                                  'torch.distributions.distribution.Distribution.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.mean',
                                                  'torch.distributions.distribution.Distribution.perplexity': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.perplexity',
                                                  'torch.distributions.distribution.Distribution.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.rsample',
                                                  'torch.distributions.distribution.Distribution.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.sample',
                                                  'torch.distributions.distribution.Distribution.sample_n': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.sample_n',
                                                  'torch.distributions.distribution.Distribution.set_default_validate_args': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.set_default_validate_args',
                                                  'torch.distributions.distribution.Distribution.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.stddev',
                                                  'torch.distributions.distribution.Distribution.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.support',
                                                  'torch.distributions.distribution.Distribution.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.distribution.Distribution.variance'},
            'torch.distributions.exp_family': { 'torch.distributions.exp_family.ExponentialFamily': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exp_family.ExponentialFamily',
                                                'torch.distributions.exp_family.ExponentialFamily.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exp_family.ExponentialFamily.entropy'},
            'torch.distributions.exponential': { 'torch.distributions.exponential.Exponential': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential',
                                                 'torch.distributions.exponential.Exponential.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.cdf',
                                                 'torch.distributions.exponential.Exponential.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.entropy',
                                                 'torch.distributions.exponential.Exponential.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.expand',
                                                 'torch.distributions.exponential.Exponential.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.icdf',
                                                 'torch.distributions.exponential.Exponential.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.log_prob',
                                                 'torch.distributions.exponential.Exponential.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.mean',
                                                 'torch.distributions.exponential.Exponential.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.rsample',
                                                 'torch.distributions.exponential.Exponential.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.stddev',
                                                 'torch.distributions.exponential.Exponential.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.exponential.Exponential.variance'},
            'torch.distributions.fishersnedecor': { 'torch.distributions.fishersnedecor.FisherSnedecor': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.fishersnedecor.FisherSnedecor',
                                                    'torch.distributions.fishersnedecor.FisherSnedecor.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.fishersnedecor.FisherSnedecor.expand',
                                                    'torch.distributions.fishersnedecor.FisherSnedecor.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.fishersnedecor.FisherSnedecor.log_prob',
                                                    'torch.distributions.fishersnedecor.FisherSnedecor.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.fishersnedecor.FisherSnedecor.mean',
                                                    'torch.distributions.fishersnedecor.FisherSnedecor.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.fishersnedecor.FisherSnedecor.rsample',
                                                    'torch.distributions.fishersnedecor.FisherSnedecor.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.fishersnedecor.FisherSnedecor.variance'},
            'torch.distributions.gamma': { 'torch.distributions.gamma.Gamma': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma',
                                           'torch.distributions.gamma.Gamma.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma.entropy',
                                           'torch.distributions.gamma.Gamma.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma.expand',
                                           'torch.distributions.gamma.Gamma.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma.log_prob',
                                           'torch.distributions.gamma.Gamma.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma.mean',
                                           'torch.distributions.gamma.Gamma.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma.rsample',
                                           'torch.distributions.gamma.Gamma.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gamma.Gamma.variance'},
            'torch.distributions.geometric': { 'torch.distributions.geometric.Geometric': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric',
                                               'torch.distributions.geometric.Geometric.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.entropy',
                                               'torch.distributions.geometric.Geometric.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.expand',
                                               'torch.distributions.geometric.Geometric.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.log_prob',
                                               'torch.distributions.geometric.Geometric.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.logits',
                                               'torch.distributions.geometric.Geometric.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.mean',
                                               'torch.distributions.geometric.Geometric.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.probs',
                                               'torch.distributions.geometric.Geometric.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.sample',
                                               'torch.distributions.geometric.Geometric.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.geometric.Geometric.variance'},
            'torch.distributions.gumbel': { 'torch.distributions.gumbel.Gumbel': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel',
                                            'torch.distributions.gumbel.Gumbel.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel.entropy',
                                            'torch.distributions.gumbel.Gumbel.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel.expand',
                                            'torch.distributions.gumbel.Gumbel.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel.log_prob',
                                            'torch.distributions.gumbel.Gumbel.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel.mean',
                                            'torch.distributions.gumbel.Gumbel.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel.stddev',
                                            'torch.distributions.gumbel.Gumbel.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.gumbel.Gumbel.variance'},
            'torch.distributions.half_cauchy': { 'torch.distributions.half_cauchy.HalfCauchy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy',
                                                 'torch.distributions.half_cauchy.HalfCauchy.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.cdf',
                                                 'torch.distributions.half_cauchy.HalfCauchy.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.entropy',
                                                 'torch.distributions.half_cauchy.HalfCauchy.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.expand',
                                                 'torch.distributions.half_cauchy.HalfCauchy.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.icdf',
                                                 'torch.distributions.half_cauchy.HalfCauchy.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.log_prob',
                                                 'torch.distributions.half_cauchy.HalfCauchy.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.mean',
                                                 'torch.distributions.half_cauchy.HalfCauchy.scale': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.scale',
                                                 'torch.distributions.half_cauchy.HalfCauchy.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_cauchy.HalfCauchy.variance'},
            'torch.distributions.half_normal': { 'torch.distributions.half_normal.HalfNormal': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal',
                                                 'torch.distributions.half_normal.HalfNormal.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.cdf',
                                                 'torch.distributions.half_normal.HalfNormal.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.entropy',
                                                 'torch.distributions.half_normal.HalfNormal.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.expand',
                                                 'torch.distributions.half_normal.HalfNormal.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.icdf',
                                                 'torch.distributions.half_normal.HalfNormal.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.log_prob',
                                                 'torch.distributions.half_normal.HalfNormal.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.mean',
                                                 'torch.distributions.half_normal.HalfNormal.scale': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.scale',
                                                 'torch.distributions.half_normal.HalfNormal.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.half_normal.HalfNormal.variance'},
            'torch.distributions.independent': { 'torch.distributions.independent.Independent': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent',
                                                 'torch.distributions.independent.Independent.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.entropy',
                                                 'torch.distributions.independent.Independent.enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.enumerate_support',
                                                 'torch.distributions.independent.Independent.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.expand',
                                                 'torch.distributions.independent.Independent.has_enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.has_enumerate_support',
                                                 'torch.distributions.independent.Independent.has_rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.has_rsample',
                                                 'torch.distributions.independent.Independent.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.log_prob',
                                                 'torch.distributions.independent.Independent.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.mean',
                                                 'torch.distributions.independent.Independent.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.rsample',
                                                 'torch.distributions.independent.Independent.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.sample',
                                                 'torch.distributions.independent.Independent.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.support',
                                                 'torch.distributions.independent.Independent.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.independent.Independent.variance'},
            'torch.distributions.kumaraswamy': { 'torch.distributions.kumaraswamy.Kumaraswamy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kumaraswamy.Kumaraswamy',
                                                 'torch.distributions.kumaraswamy.Kumaraswamy.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kumaraswamy.Kumaraswamy.entropy',
                                                 'torch.distributions.kumaraswamy.Kumaraswamy.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kumaraswamy.Kumaraswamy.expand',
                                                 'torch.distributions.kumaraswamy.Kumaraswamy.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kumaraswamy.Kumaraswamy.mean',
                                                 'torch.distributions.kumaraswamy.Kumaraswamy.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kumaraswamy.Kumaraswamy.variance'},
            'torch.distributions.laplace': { 'torch.distributions.laplace.Laplace': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace',
                                             'torch.distributions.laplace.Laplace.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.cdf',
                                             'torch.distributions.laplace.Laplace.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.entropy',
                                             'torch.distributions.laplace.Laplace.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.expand',
                                             'torch.distributions.laplace.Laplace.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.icdf',
                                             'torch.distributions.laplace.Laplace.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.log_prob',
                                             'torch.distributions.laplace.Laplace.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.mean',
                                             'torch.distributions.laplace.Laplace.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.rsample',
                                             'torch.distributions.laplace.Laplace.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.stddev',
                                             'torch.distributions.laplace.Laplace.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.laplace.Laplace.variance'},
            'torch.distributions.lkj_cholesky': { 'torch.distributions.lkj_cholesky.LKJCholesky': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lkj_cholesky.LKJCholesky',
                                                  'torch.distributions.lkj_cholesky.LKJCholesky.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lkj_cholesky.LKJCholesky.expand',
                                                  'torch.distributions.lkj_cholesky.LKJCholesky.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lkj_cholesky.LKJCholesky.log_prob',
                                                  'torch.distributions.lkj_cholesky.LKJCholesky.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lkj_cholesky.LKJCholesky.sample'},
            'torch.distributions.log_normal': { 'torch.distributions.log_normal.LogNormal': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal',
                                                'torch.distributions.log_normal.LogNormal.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal.entropy',
                                                'torch.distributions.log_normal.LogNormal.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal.expand',
                                                'torch.distributions.log_normal.LogNormal.loc': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal.loc',
                                                'torch.distributions.log_normal.LogNormal.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal.mean',
                                                'torch.distributions.log_normal.LogNormal.scale': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal.scale',
                                                'torch.distributions.log_normal.LogNormal.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.log_normal.LogNormal.variance'},
            'torch.distributions.lowrank_multivariate_normal': { 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.covariance_matrix': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.covariance_matrix',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.entropy',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.expand',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.log_prob',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.mean',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.precision_matrix': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.precision_matrix',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.rsample',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.scale_tril': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.scale_tril',
                                                                 'torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.lowrank_multivariate_normal.LowRankMultivariateNormal.variance'},
            'torch.distributions.mixture_same_family': { 'torch.distributions.mixture_same_family.MixtureSameFamily': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.cdf',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.component_distribution': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.component_distribution',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.expand',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.log_prob',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.mean',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.mixture_distribution': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.mixture_distribution',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.sample',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.support',
                                                         'torch.distributions.mixture_same_family.MixtureSameFamily.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.mixture_same_family.MixtureSameFamily.variance'},
            'torch.distributions.multinomial': { 'torch.distributions.multinomial.Multinomial': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial',
                                                 'torch.distributions.multinomial.Multinomial.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.entropy',
                                                 'torch.distributions.multinomial.Multinomial.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.expand',
                                                 'torch.distributions.multinomial.Multinomial.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.log_prob',
                                                 'torch.distributions.multinomial.Multinomial.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.logits',
                                                 'torch.distributions.multinomial.Multinomial.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.mean',
                                                 'torch.distributions.multinomial.Multinomial.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.param_shape',
                                                 'torch.distributions.multinomial.Multinomial.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.probs',
                                                 'torch.distributions.multinomial.Multinomial.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.sample',
                                                 'torch.distributions.multinomial.Multinomial.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.support',
                                                 'torch.distributions.multinomial.Multinomial.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multinomial.Multinomial.variance'},
            'torch.distributions.multivariate_normal': { 'torch.distributions.multivariate_normal.MultivariateNormal': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.covariance_matrix': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.covariance_matrix',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.entropy',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.expand',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.log_prob',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.mean',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.precision_matrix': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.precision_matrix',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.rsample',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.scale_tril': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.scale_tril',
                                                         'torch.distributions.multivariate_normal.MultivariateNormal.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.multivariate_normal.MultivariateNormal.variance'},
            'torch.distributions.negative_binomial': { 'torch.distributions.negative_binomial.NegativeBinomial': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.expand',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.log_prob',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.logits',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.mean',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.param_shape',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.probs',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.sample',
                                                       'torch.distributions.negative_binomial.NegativeBinomial.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.negative_binomial.NegativeBinomial.variance'},
            'torch.distributions.normal': { 'torch.distributions.normal.Normal': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal',
                                            'torch.distributions.normal.Normal.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.cdf',
                                            'torch.distributions.normal.Normal.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.entropy',
                                            'torch.distributions.normal.Normal.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.expand',
                                            'torch.distributions.normal.Normal.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.icdf',
                                            'torch.distributions.normal.Normal.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.log_prob',
                                            'torch.distributions.normal.Normal.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.mean',
                                            'torch.distributions.normal.Normal.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.rsample',
                                            'torch.distributions.normal.Normal.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.sample',
                                            'torch.distributions.normal.Normal.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.stddev',
                                            'torch.distributions.normal.Normal.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.normal.Normal.variance'},
            'torch.distributions.one_hot_categorical': { 'torch.distributions.one_hot_categorical.OneHotCategorical': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.entropy',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.enumerate_support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.enumerate_support',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.expand',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.log_prob',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.logits',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.mean',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.param_shape',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.probs',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.sample',
                                                         'torch.distributions.one_hot_categorical.OneHotCategorical.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.one_hot_categorical.OneHotCategorical.variance'},
            'torch.distributions.pareto': { 'torch.distributions.pareto.Pareto': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.pareto.Pareto',
                                            'torch.distributions.pareto.Pareto.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.pareto.Pareto.entropy',
                                            'torch.distributions.pareto.Pareto.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.pareto.Pareto.expand',
                                            'torch.distributions.pareto.Pareto.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.pareto.Pareto.mean',
                                            'torch.distributions.pareto.Pareto.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.pareto.Pareto.support',
                                            'torch.distributions.pareto.Pareto.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.pareto.Pareto.variance'},
            'torch.distributions.poisson': { 'torch.distributions.poisson.Poisson': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.poisson.Poisson',
                                             'torch.distributions.poisson.Poisson.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.poisson.Poisson.expand',
                                             'torch.distributions.poisson.Poisson.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.poisson.Poisson.log_prob',
                                             'torch.distributions.poisson.Poisson.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.poisson.Poisson.mean',
                                             'torch.distributions.poisson.Poisson.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.poisson.Poisson.sample',
                                             'torch.distributions.poisson.Poisson.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.poisson.Poisson.variance'},
            'torch.distributions.relaxed_bernoulli': { 'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli',
                                                       'torch.distributions.relaxed_bernoulli.RelaxedBernoulli': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.RelaxedBernoulli',
                                                       'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.expand',
                                                       'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.log_prob',
                                                       'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.logits',
                                                       'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.param_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.param_shape',
                                                       'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.probs',
                                                       'torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.LogitRelaxedBernoulli.rsample',
                                                       'torch.distributions.relaxed_bernoulli.RelaxedBernoulli.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.RelaxedBernoulli.expand',
                                                       'torch.distributions.relaxed_bernoulli.RelaxedBernoulli.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.RelaxedBernoulli.logits',
                                                       'torch.distributions.relaxed_bernoulli.RelaxedBernoulli.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.RelaxedBernoulli.probs',
                                                       'torch.distributions.relaxed_bernoulli.RelaxedBernoulli.temperature': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_bernoulli.RelaxedBernoulli.temperature'},
            'torch.distributions.relaxed_categorical': { 'torch.distributions.relaxed_categorical.RelaxedOneHotCategorical': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_categorical.RelaxedOneHotCategorical',
                                                         'torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.expand',
                                                         'torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.logits': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.logits',
                                                         'torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.probs': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.probs',
                                                         'torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.temperature': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.relaxed_categorical.RelaxedOneHotCategorical.temperature'},
            'torch.distributions.studentT': { 'torch.distributions.studentT.StudentT': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT',
                                              'torch.distributions.studentT.StudentT.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT.entropy',
                                              'torch.distributions.studentT.StudentT.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT.expand',
                                              'torch.distributions.studentT.StudentT.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT.log_prob',
                                              'torch.distributions.studentT.StudentT.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT.mean',
                                              'torch.distributions.studentT.StudentT.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT.rsample',
                                              'torch.distributions.studentT.StudentT.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.studentT.StudentT.variance'},
            'torch.distributions.transformed_distribution': { 'torch.distributions.transformed_distribution.TransformedDistribution': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.cdf',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.expand',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.has_rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.has_rsample',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.icdf',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.log_prob',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.rsample',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.sample',
                                                              'torch.distributions.transformed_distribution.TransformedDistribution.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transformed_distribution.TransformedDistribution.support'},
            'torch.distributions.transforms': { 'torch.distributions.transforms.AbsTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.AbsTransform',
                                                'torch.distributions.transforms.AffineTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.AffineTransform',
                                                'torch.distributions.transforms.ComposeTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.ComposeTransform',
                                                'torch.distributions.transforms.CorrCholeskyTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.CorrCholeskyTransform',
                                                'torch.distributions.transforms.ExpTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.ExpTransform',
                                                'torch.distributions.transforms.IndependentTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.IndependentTransform',
                                                'torch.distributions.transforms.LowerCholeskyTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.LowerCholeskyTransform',
                                                'torch.distributions.transforms.PowerTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.PowerTransform',
                                                'torch.distributions.transforms.ReshapeTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.ReshapeTransform',
                                                'torch.distributions.transforms.SigmoidTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.SigmoidTransform',
                                                'torch.distributions.transforms.SoftmaxTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.SoftmaxTransform',
                                                'torch.distributions.transforms.StackTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.StackTransform',
                                                'torch.distributions.transforms.StickBreakingTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.StickBreakingTransform',
                                                'torch.distributions.transforms.TanhTransform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.TanhTransform',
                                                'torch.distributions.transforms.Transform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.Transform',
                                                'torch.distributions.transforms.Transform.forward_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.Transform.forward_shape',
                                                'torch.distributions.transforms.Transform.inv': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.Transform.inv',
                                                'torch.distributions.transforms.Transform.inverse_shape': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.Transform.inverse_shape',
                                                'torch.distributions.transforms.Transform.log_abs_det_jacobian': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.Transform.log_abs_det_jacobian',
                                                'torch.distributions.transforms.Transform.sign': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.transforms.Transform.sign'},
            'torch.distributions.uniform': { 'torch.distributions.uniform.Uniform': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform',
                                             'torch.distributions.uniform.Uniform.cdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.cdf',
                                             'torch.distributions.uniform.Uniform.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.entropy',
                                             'torch.distributions.uniform.Uniform.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.expand',
                                             'torch.distributions.uniform.Uniform.icdf': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.icdf',
                                             'torch.distributions.uniform.Uniform.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.log_prob',
                                             'torch.distributions.uniform.Uniform.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.mean',
                                             'torch.distributions.uniform.Uniform.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.rsample',
                                             'torch.distributions.uniform.Uniform.stddev': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.stddev',
                                             'torch.distributions.uniform.Uniform.support': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.support',
                                             'torch.distributions.uniform.Uniform.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.uniform.Uniform.variance'},
            'torch.distributions.von_mises': { 'torch.distributions.von_mises.VonMises': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.von_mises.VonMises',
                                               'torch.distributions.von_mises.VonMises.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.von_mises.VonMises.expand',
                                               'torch.distributions.von_mises.VonMises.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.von_mises.VonMises.log_prob',
                                               'torch.distributions.von_mises.VonMises.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.von_mises.VonMises.mean',
                                               'torch.distributions.von_mises.VonMises.sample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.von_mises.VonMises.sample',
                                               'torch.distributions.von_mises.VonMises.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.von_mises.VonMises.variance'},
            'torch.distributions.weibull': { 'torch.distributions.weibull.Weibull': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.weibull.Weibull',
                                             'torch.distributions.weibull.Weibull.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.weibull.Weibull.entropy',
                                             'torch.distributions.weibull.Weibull.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.weibull.Weibull.expand',
                                             'torch.distributions.weibull.Weibull.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.weibull.Weibull.mean',
                                             'torch.distributions.weibull.Weibull.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.weibull.Weibull.variance'},
            'torch.distributions.wishart': { 'torch.distributions.wishart.Wishart': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart',
                                             'torch.distributions.wishart.Wishart.covariance_matrix': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.covariance_matrix',
                                             'torch.distributions.wishart.Wishart.entropy': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.entropy',
                                             'torch.distributions.wishart.Wishart.expand': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.expand',
                                             'torch.distributions.wishart.Wishart.log_prob': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.log_prob',
                                             'torch.distributions.wishart.Wishart.mean': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.mean',
                                             'torch.distributions.wishart.Wishart.precision_matrix': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.precision_matrix',
                                             'torch.distributions.wishart.Wishart.rsample': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.rsample',
                                             'torch.distributions.wishart.Wishart.scale_tril': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.scale_tril',
                                             'torch.distributions.wishart.Wishart.variance': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.wishart.Wishart.variance'},
            'torch.futures': { 'torch.futures.Future': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future',
                               'torch.futures.Future.add_done_callback': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.add_done_callback',
                               'torch.futures.Future.done': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.done',
                               'torch.futures.Future.set_exception': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.set_exception',
                               'torch.futures.Future.set_result': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.set_result',
                               'torch.futures.Future.then': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.then',
                               'torch.futures.Future.value': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.value',
                               'torch.futures.Future.wait': 'https://pytorch.org/docs/stable/futures.html#torch.futures.Future.wait',
                               'torch.futures.collect_all': 'https://pytorch.org/docs/stable/futures.html#torch.futures.collect_all',
                               'torch.futures.wait_all': 'https://pytorch.org/docs/stable/futures.html#torch.futures.wait_all'},
            'torch.fx': { 'torch.fx.Graph': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph',
                          'torch.fx.GraphModule': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule',
                          'torch.fx.Interpreter': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter',
                          'torch.fx.Node': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node',
                          'torch.fx.Proxy': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Proxy',
                          'torch.fx.Tracer': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer',
                          'torch.fx.Transformer': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Transformer',
                          'torch.fx.Graph.__init__': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.__init__',
                          'torch.fx.Graph.call_function': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.call_function',
                          'torch.fx.Graph.call_method': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.call_method',
                          'torch.fx.Graph.call_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.call_module',
                          'torch.fx.Graph.create_node': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.create_node',
                          'torch.fx.Graph.eliminate_dead_code': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.eliminate_dead_code',
                          'torch.fx.Graph.erase_node': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.erase_node',
                          'torch.fx.Graph.flatten_inps': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.flatten_inps',
                          'torch.fx.Graph.get_attr': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.get_attr',
                          'torch.fx.Graph.graph_copy': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.graph_copy',
                          'torch.fx.Graph.inserting_after': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.inserting_after',
                          'torch.fx.Graph.inserting_before': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.inserting_before',
                          'torch.fx.Graph.lint': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.lint',
                          'torch.fx.Graph.node_copy': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.node_copy',
                          'torch.fx.Graph.nodes': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.nodes',
                          'torch.fx.Graph.on_generate_code': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.on_generate_code',
                          'torch.fx.Graph.output': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.output',
                          'torch.fx.Graph.owning_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.owning_module',
                          'torch.fx.Graph.placeholder': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.placeholder',
                          'torch.fx.Graph.print_tabular': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.print_tabular',
                          'torch.fx.Graph.python_code': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.python_code',
                          'torch.fx.Graph.unflatten_outs': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Graph.unflatten_outs',
                          'torch.fx.GraphModule.__init__': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.__init__',
                          'torch.fx.GraphModule.add_submodule': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.add_submodule',
                          'torch.fx.GraphModule.code': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.code',
                          'torch.fx.GraphModule.delete_all_unused_submodules': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.delete_all_unused_submodules',
                          'torch.fx.GraphModule.delete_submodule': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.delete_submodule',
                          'torch.fx.GraphModule.graph': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.graph',
                          'torch.fx.GraphModule.recompile': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.recompile',
                          'torch.fx.GraphModule.to_folder': 'https://pytorch.org/docs/stable/fx.html#torch.fx.GraphModule.to_folder',
                          'torch.fx.Interpreter.call_function': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.call_function',
                          'torch.fx.Interpreter.call_method': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.call_method',
                          'torch.fx.Interpreter.call_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.call_module',
                          'torch.fx.Interpreter.fetch_args_kwargs_from_env': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.fetch_args_kwargs_from_env',
                          'torch.fx.Interpreter.fetch_attr': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.fetch_attr',
                          'torch.fx.Interpreter.get_attr': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.get_attr',
                          'torch.fx.Interpreter.map_nodes_to_values': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.map_nodes_to_values',
                          'torch.fx.Interpreter.output': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.output',
                          'torch.fx.Interpreter.placeholder': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.placeholder',
                          'torch.fx.Interpreter.run': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.run',
                          'torch.fx.Interpreter.run_node': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Interpreter.run_node',
                          'torch.fx.Node.all_input_nodes': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.all_input_nodes',
                          'torch.fx.Node.append': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.append',
                          'torch.fx.Node.args': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.args',
                          'torch.fx.Node.format_node': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.format_node',
                          'torch.fx.Node.is_impure': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.is_impure',
                          'torch.fx.Node.kwargs': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.kwargs',
                          'torch.fx.Node.next': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.next',
                          'torch.fx.Node.normalized_arguments': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.normalized_arguments',
                          'torch.fx.Node.prepend': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.prepend',
                          'torch.fx.Node.prev': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.prev',
                          'torch.fx.Node.replace_all_uses_with': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.replace_all_uses_with',
                          'torch.fx.Node.replace_input_with': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.replace_input_with',
                          'torch.fx.Node.stack_trace': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.stack_trace',
                          'torch.fx.Node.update_arg': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.update_arg',
                          'torch.fx.Node.update_kwarg': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Node.update_kwarg',
                          'torch.fx.Tracer.call_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.call_module',
                          'torch.fx.Tracer.create_arg': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.create_arg',
                          'torch.fx.Tracer.create_args_for_root': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.create_args_for_root',
                          'torch.fx.Tracer.create_node': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.create_node',
                          'torch.fx.Tracer.create_proxy': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.create_proxy',
                          'torch.fx.Tracer.is_leaf_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.is_leaf_module',
                          'torch.fx.Tracer.iter': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.iter',
                          'torch.fx.Tracer.keys': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.keys',
                          'torch.fx.Tracer.path_of_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.path_of_module',
                          'torch.fx.Tracer.proxy': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.proxy',
                          'torch.fx.Tracer.to_bool': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.to_bool',
                          'torch.fx.Tracer.trace': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Tracer.trace',
                          'torch.fx.Transformer.call_function': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Transformer.call_function',
                          'torch.fx.Transformer.call_module': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Transformer.call_module',
                          'torch.fx.Transformer.get_attr': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Transformer.get_attr',
                          'torch.fx.Transformer.placeholder': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Transformer.placeholder',
                          'torch.fx.Transformer.transform': 'https://pytorch.org/docs/stable/fx.html#torch.fx.Transformer.transform',
                          'torch.fx.replace_pattern': 'https://pytorch.org/docs/stable/fx.html#torch.fx.replace_pattern',
                          'torch.fx.symbolic_trace': 'https://pytorch.org/docs/stable/fx.html#torch.fx.symbolic_trace',
                          'torch.fx.wrap': 'https://pytorch.org/docs/stable/fx.html#torch.fx.wrap'},
            'torch.monitor': { 'torch.monitor.Aggregation': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Aggregation',
                               'torch.monitor.Event': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Event',
                               'torch.monitor.EventHandlerHandle': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.EventHandlerHandle',
                               'torch.monitor.Stat': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Stat',
                               'torch.monitor.TensorboardEventHandler': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.TensorboardEventHandler',
                               'torch.monitor.data_value_t': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.data_value_t',
                               'torch.monitor.Aggregation.name': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Aggregation.name',
                               'torch.monitor.Event.__init__': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Event.__init__',
                               'torch.monitor.Event.data': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Event.data',
                               'torch.monitor.Event.name': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Event.name',
                               'torch.monitor.Event.timestamp': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Event.timestamp',
                               'torch.monitor.Stat.__init__': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Stat.__init__',
                               'torch.monitor.Stat.add': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Stat.add',
                               'torch.monitor.Stat.count': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Stat.count',
                               'torch.monitor.Stat.get': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Stat.get',
                               'torch.monitor.Stat.name': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.Stat.name',
                               'torch.monitor.TensorboardEventHandler.__init__': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.TensorboardEventHandler.__init__',
                               'torch.monitor.log_event': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.log_event',
                               'torch.monitor.register_event_handler': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.register_event_handler',
                               'torch.monitor.unregister_event_handler': 'https://pytorch.org/docs/stable/monitor.html#torch.monitor.unregister_event_handler'},
            'torch.multiprocessing': { 'torch.multiprocessing.SpawnContext': 'https://pytorch.org/docs/stable/multiprocessing.html#torch.multiprocessing.SpawnContext',
                                       'torch.multiprocessing.SpawnContext.join': 'https://pytorch.org/docs/stable/multiprocessing.html#torch.multiprocessing.SpawnContext.join',
                                       'torch.multiprocessing.get_all_sharing_strategies': 'https://pytorch.org/docs/stable/multiprocessing.html#torch.multiprocessing.get_all_sharing_strategies',
                                       'torch.multiprocessing.get_sharing_strategy': 'https://pytorch.org/docs/stable/multiprocessing.html#torch.multiprocessing.get_sharing_strategy',
                                       'torch.multiprocessing.set_sharing_strategy': 'https://pytorch.org/docs/stable/multiprocessing.html#torch.multiprocessing.set_sharing_strategy',
                                       'torch.multiprocessing.spawn': 'https://pytorch.org/docs/stable/multiprocessing.html#torch.multiprocessing.spawn'},
            'torch.nn': { 'torch.nn.AdaptiveAvgPool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveAvgPool1d.html#torch.nn.AdaptiveAvgPool1d',
                          'torch.nn.AdaptiveAvgPool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveAvgPool2d.html#torch.nn.AdaptiveAvgPool2d',
                          'torch.nn.AdaptiveAvgPool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveAvgPool3d.html#torch.nn.AdaptiveAvgPool3d',
                          'torch.nn.AdaptiveLogSoftmaxWithLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveLogSoftmaxWithLoss.html#torch.nn.AdaptiveLogSoftmaxWithLoss',
                          'torch.nn.AdaptiveMaxPool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveMaxPool1d.html#torch.nn.AdaptiveMaxPool1d',
                          'torch.nn.AdaptiveMaxPool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveMaxPool2d.html#torch.nn.AdaptiveMaxPool2d',
                          'torch.nn.AdaptiveMaxPool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveMaxPool3d.html#torch.nn.AdaptiveMaxPool3d',
                          'torch.nn.AlphaDropout': 'https://pytorch.org/docs/stable/generated/torch.nn.AlphaDropout.html#torch.nn.AlphaDropout',
                          'torch.nn.AvgPool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.AvgPool1d.html#torch.nn.AvgPool1d',
                          'torch.nn.AvgPool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.AvgPool2d.html#torch.nn.AvgPool2d',
                          'torch.nn.AvgPool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.AvgPool3d.html#torch.nn.AvgPool3d',
                          'torch.nn.BCELoss': 'https://pytorch.org/docs/stable/generated/torch.nn.BCELoss.html#torch.nn.BCELoss',
                          'torch.nn.BCEWithLogitsLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.BCEWithLogitsLoss.html#torch.nn.BCEWithLogitsLoss',
                          'torch.nn.BatchNorm1d': 'https://pytorch.org/docs/stable/generated/torch.nn.BatchNorm1d.html#torch.nn.BatchNorm1d',
                          'torch.nn.BatchNorm2d': 'https://pytorch.org/docs/stable/generated/torch.nn.BatchNorm2d.html#torch.nn.BatchNorm2d',
                          'torch.nn.BatchNorm3d': 'https://pytorch.org/docs/stable/generated/torch.nn.BatchNorm3d.html#torch.nn.BatchNorm3d',
                          'torch.nn.Bilinear': 'https://pytorch.org/docs/stable/generated/torch.nn.Bilinear.html#torch.nn.Bilinear',
                          'torch.nn.CELU': 'https://pytorch.org/docs/stable/generated/torch.nn.CELU.html#torch.nn.CELU',
                          'torch.nn.CTCLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.CTCLoss.html#torch.nn.CTCLoss',
                          'torch.nn.ChannelShuffle': 'https://pytorch.org/docs/stable/generated/torch.nn.ChannelShuffle.html#torch.nn.ChannelShuffle',
                          'torch.nn.ConstantPad1d': 'https://pytorch.org/docs/stable/generated/torch.nn.ConstantPad1d.html#torch.nn.ConstantPad1d',
                          'torch.nn.ConstantPad2d': 'https://pytorch.org/docs/stable/generated/torch.nn.ConstantPad2d.html#torch.nn.ConstantPad2d',
                          'torch.nn.ConstantPad3d': 'https://pytorch.org/docs/stable/generated/torch.nn.ConstantPad3d.html#torch.nn.ConstantPad3d',
                          'torch.nn.Conv1d': 'https://pytorch.org/docs/stable/generated/torch.nn.Conv1d.html#torch.nn.Conv1d',
                          'torch.nn.Conv2d': 'https://pytorch.org/docs/stable/generated/torch.nn.Conv2d.html#torch.nn.Conv2d',
                          'torch.nn.Conv3d': 'https://pytorch.org/docs/stable/generated/torch.nn.Conv3d.html#torch.nn.Conv3d',
                          'torch.nn.ConvTranspose1d': 'https://pytorch.org/docs/stable/generated/torch.nn.ConvTranspose1d.html#torch.nn.ConvTranspose1d',
                          'torch.nn.ConvTranspose2d': 'https://pytorch.org/docs/stable/generated/torch.nn.ConvTranspose2d.html#torch.nn.ConvTranspose2d',
                          'torch.nn.ConvTranspose3d': 'https://pytorch.org/docs/stable/generated/torch.nn.ConvTranspose3d.html#torch.nn.ConvTranspose3d',
                          'torch.nn.CosineEmbeddingLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.CosineEmbeddingLoss.html#torch.nn.CosineEmbeddingLoss',
                          'torch.nn.CosineSimilarity': 'https://pytorch.org/docs/stable/generated/torch.nn.CosineSimilarity.html#torch.nn.CosineSimilarity',
                          'torch.nn.CrossEntropyLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.CrossEntropyLoss.html#torch.nn.CrossEntropyLoss',
                          'torch.nn.DataParallel': 'https://pytorch.org/docs/stable/generated/torch.nn.DataParallel.html#torch.nn.DataParallel',
                          'torch.nn.Dropout': 'https://pytorch.org/docs/stable/generated/torch.nn.Dropout.html#torch.nn.Dropout',
                          'torch.nn.Dropout2d': 'https://pytorch.org/docs/stable/generated/torch.nn.Dropout2d.html#torch.nn.Dropout2d',
                          'torch.nn.Dropout3d': 'https://pytorch.org/docs/stable/generated/torch.nn.Dropout3d.html#torch.nn.Dropout3d',
                          'torch.nn.ELU': 'https://pytorch.org/docs/stable/generated/torch.nn.ELU.html#torch.nn.ELU',
                          'torch.nn.Embedding': 'https://pytorch.org/docs/stable/generated/torch.nn.Embedding.html#torch.nn.Embedding',
                          'torch.nn.EmbeddingBag': 'https://pytorch.org/docs/stable/generated/torch.nn.EmbeddingBag.html#torch.nn.EmbeddingBag',
                          'torch.nn.FeatureAlphaDropout': 'https://pytorch.org/docs/stable/generated/torch.nn.FeatureAlphaDropout.html#torch.nn.FeatureAlphaDropout',
                          'torch.nn.Flatten': 'https://pytorch.org/docs/stable/generated/torch.nn.Flatten.html#torch.nn.Flatten',
                          'torch.nn.Fold': 'https://pytorch.org/docs/stable/generated/torch.nn.Fold.html#torch.nn.Fold',
                          'torch.nn.FractionalMaxPool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.FractionalMaxPool2d.html#torch.nn.FractionalMaxPool2d',
                          'torch.nn.FractionalMaxPool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.FractionalMaxPool3d.html#torch.nn.FractionalMaxPool3d',
                          'torch.nn.GELU': 'https://pytorch.org/docs/stable/generated/torch.nn.GELU.html#torch.nn.GELU',
                          'torch.nn.GLU': 'https://pytorch.org/docs/stable/generated/torch.nn.GLU.html#torch.nn.GLU',
                          'torch.nn.GRU': 'https://pytorch.org/docs/stable/generated/torch.nn.GRU.html#torch.nn.GRU',
                          'torch.nn.GRUCell': 'https://pytorch.org/docs/stable/generated/torch.nn.GRUCell.html#torch.nn.GRUCell',
                          'torch.nn.GaussianNLLLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.GaussianNLLLoss.html#torch.nn.GaussianNLLLoss',
                          'torch.nn.GroupNorm': 'https://pytorch.org/docs/stable/generated/torch.nn.GroupNorm.html#torch.nn.GroupNorm',
                          'torch.nn.Hardshrink': 'https://pytorch.org/docs/stable/generated/torch.nn.Hardshrink.html#torch.nn.Hardshrink',
                          'torch.nn.Hardsigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.Hardsigmoid.html#torch.nn.Hardsigmoid',
                          'torch.nn.Hardswish': 'https://pytorch.org/docs/stable/generated/torch.nn.Hardswish.html#torch.nn.Hardswish',
                          'torch.nn.Hardtanh': 'https://pytorch.org/docs/stable/generated/torch.nn.Hardtanh.html#torch.nn.Hardtanh',
                          'torch.nn.HingeEmbeddingLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.HingeEmbeddingLoss.html#torch.nn.HingeEmbeddingLoss',
                          'torch.nn.HuberLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.HuberLoss.html#torch.nn.HuberLoss',
                          'torch.nn.Identity': 'https://pytorch.org/docs/stable/generated/torch.nn.Identity.html#torch.nn.Identity',
                          'torch.nn.InstanceNorm1d': 'https://pytorch.org/docs/stable/generated/torch.nn.InstanceNorm1d.html#torch.nn.InstanceNorm1d',
                          'torch.nn.InstanceNorm2d': 'https://pytorch.org/docs/stable/generated/torch.nn.InstanceNorm2d.html#torch.nn.InstanceNorm2d',
                          'torch.nn.InstanceNorm3d': 'https://pytorch.org/docs/stable/generated/torch.nn.InstanceNorm3d.html#torch.nn.InstanceNorm3d',
                          'torch.nn.KLDivLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.KLDivLoss.html#torch.nn.KLDivLoss',
                          'torch.nn.L1Loss': 'https://pytorch.org/docs/stable/generated/torch.nn.L1Loss.html#torch.nn.L1Loss',
                          'torch.nn.LPPool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.LPPool1d.html#torch.nn.LPPool1d',
                          'torch.nn.LPPool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.LPPool2d.html#torch.nn.LPPool2d',
                          'torch.nn.LSTM': 'https://pytorch.org/docs/stable/generated/torch.nn.LSTM.html#torch.nn.LSTM',
                          'torch.nn.LSTMCell': 'https://pytorch.org/docs/stable/generated/torch.nn.LSTMCell.html#torch.nn.LSTMCell',
                          'torch.nn.LayerNorm': 'https://pytorch.org/docs/stable/generated/torch.nn.LayerNorm.html#torch.nn.LayerNorm',
                          'torch.nn.LazyBatchNorm1d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyBatchNorm1d.html#torch.nn.LazyBatchNorm1d',
                          'torch.nn.LazyBatchNorm2d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyBatchNorm2d.html#torch.nn.LazyBatchNorm2d',
                          'torch.nn.LazyBatchNorm3d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyBatchNorm3d.html#torch.nn.LazyBatchNorm3d',
                          'torch.nn.LazyConv1d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyConv1d.html#torch.nn.LazyConv1d',
                          'torch.nn.LazyConv2d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyConv2d.html#torch.nn.LazyConv2d',
                          'torch.nn.LazyConv3d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyConv3d.html#torch.nn.LazyConv3d',
                          'torch.nn.LazyConvTranspose1d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyConvTranspose1d.html#torch.nn.LazyConvTranspose1d',
                          'torch.nn.LazyConvTranspose2d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyConvTranspose2d.html#torch.nn.LazyConvTranspose2d',
                          'torch.nn.LazyConvTranspose3d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyConvTranspose3d.html#torch.nn.LazyConvTranspose3d',
                          'torch.nn.LazyInstanceNorm1d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyInstanceNorm1d.html#torch.nn.LazyInstanceNorm1d',
                          'torch.nn.LazyInstanceNorm2d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyInstanceNorm2d.html#torch.nn.LazyInstanceNorm2d',
                          'torch.nn.LazyInstanceNorm3d': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyInstanceNorm3d.html#torch.nn.LazyInstanceNorm3d',
                          'torch.nn.LazyLinear': 'https://pytorch.org/docs/stable/generated/torch.nn.LazyLinear.html#torch.nn.LazyLinear',
                          'torch.nn.LeakyReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.LeakyReLU.html#torch.nn.LeakyReLU',
                          'torch.nn.Linear': 'https://pytorch.org/docs/stable/generated/torch.nn.Linear.html#torch.nn.Linear',
                          'torch.nn.LocalResponseNorm': 'https://pytorch.org/docs/stable/generated/torch.nn.LocalResponseNorm.html#torch.nn.LocalResponseNorm',
                          'torch.nn.LogSigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.LogSigmoid.html#torch.nn.LogSigmoid',
                          'torch.nn.LogSoftmax': 'https://pytorch.org/docs/stable/generated/torch.nn.LogSoftmax.html#torch.nn.LogSoftmax',
                          'torch.nn.MSELoss': 'https://pytorch.org/docs/stable/generated/torch.nn.MSELoss.html#torch.nn.MSELoss',
                          'torch.nn.MarginRankingLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.MarginRankingLoss.html#torch.nn.MarginRankingLoss',
                          'torch.nn.MaxPool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.MaxPool1d.html#torch.nn.MaxPool1d',
                          'torch.nn.MaxPool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.MaxPool2d.html#torch.nn.MaxPool2d',
                          'torch.nn.MaxPool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.MaxPool3d.html#torch.nn.MaxPool3d',
                          'torch.nn.MaxUnpool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.MaxUnpool1d.html#torch.nn.MaxUnpool1d',
                          'torch.nn.MaxUnpool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.MaxUnpool2d.html#torch.nn.MaxUnpool2d',
                          'torch.nn.MaxUnpool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.MaxUnpool3d.html#torch.nn.MaxUnpool3d',
                          'torch.nn.Mish': 'https://pytorch.org/docs/stable/generated/torch.nn.Mish.html#torch.nn.Mish',
                          'torch.nn.Module': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module',
                          'torch.nn.ModuleDict': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict',
                          'torch.nn.ModuleList': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleList.html#torch.nn.ModuleList',
                          'torch.nn.MultiLabelMarginLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.MultiLabelMarginLoss.html#torch.nn.MultiLabelMarginLoss',
                          'torch.nn.MultiLabelSoftMarginLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.MultiLabelSoftMarginLoss.html#torch.nn.MultiLabelSoftMarginLoss',
                          'torch.nn.MultiMarginLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.MultiMarginLoss.html#torch.nn.MultiMarginLoss',
                          'torch.nn.MultiheadAttention': 'https://pytorch.org/docs/stable/generated/torch.nn.MultiheadAttention.html#torch.nn.MultiheadAttention',
                          'torch.nn.NLLLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.NLLLoss.html#torch.nn.NLLLoss',
                          'torch.nn.PReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.PReLU.html#torch.nn.PReLU',
                          'torch.nn.PairwiseDistance': 'https://pytorch.org/docs/stable/generated/torch.nn.PairwiseDistance.html#torch.nn.PairwiseDistance',
                          'torch.nn.ParameterDict': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict',
                          'torch.nn.ParameterList': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterList.html#torch.nn.ParameterList',
                          'torch.nn.PixelShuffle': 'https://pytorch.org/docs/stable/generated/torch.nn.PixelShuffle.html#torch.nn.PixelShuffle',
                          'torch.nn.PixelUnshuffle': 'https://pytorch.org/docs/stable/generated/torch.nn.PixelUnshuffle.html#torch.nn.PixelUnshuffle',
                          'torch.nn.PoissonNLLLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.PoissonNLLLoss.html#torch.nn.PoissonNLLLoss',
                          'torch.nn.RNN': 'https://pytorch.org/docs/stable/generated/torch.nn.RNN.html#torch.nn.RNN',
                          'torch.nn.RNNBase': 'https://pytorch.org/docs/stable/generated/torch.nn.RNNBase.html#torch.nn.RNNBase',
                          'torch.nn.RNNCell': 'https://pytorch.org/docs/stable/generated/torch.nn.RNNCell.html#torch.nn.RNNCell',
                          'torch.nn.RReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.RReLU.html#torch.nn.RReLU',
                          'torch.nn.ReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.ReLU.html#torch.nn.ReLU',
                          'torch.nn.ReLU6': 'https://pytorch.org/docs/stable/generated/torch.nn.ReLU6.html#torch.nn.ReLU6',
                          'torch.nn.ReflectionPad1d': 'https://pytorch.org/docs/stable/generated/torch.nn.ReflectionPad1d.html#torch.nn.ReflectionPad1d',
                          'torch.nn.ReflectionPad2d': 'https://pytorch.org/docs/stable/generated/torch.nn.ReflectionPad2d.html#torch.nn.ReflectionPad2d',
                          'torch.nn.ReflectionPad3d': 'https://pytorch.org/docs/stable/generated/torch.nn.ReflectionPad3d.html#torch.nn.ReflectionPad3d',
                          'torch.nn.ReplicationPad1d': 'https://pytorch.org/docs/stable/generated/torch.nn.ReplicationPad1d.html#torch.nn.ReplicationPad1d',
                          'torch.nn.ReplicationPad2d': 'https://pytorch.org/docs/stable/generated/torch.nn.ReplicationPad2d.html#torch.nn.ReplicationPad2d',
                          'torch.nn.ReplicationPad3d': 'https://pytorch.org/docs/stable/generated/torch.nn.ReplicationPad3d.html#torch.nn.ReplicationPad3d',
                          'torch.nn.SELU': 'https://pytorch.org/docs/stable/generated/torch.nn.SELU.html#torch.nn.SELU',
                          'torch.nn.Sequential': 'https://pytorch.org/docs/stable/generated/torch.nn.Sequential.html#torch.nn.Sequential',
                          'torch.nn.SiLU': 'https://pytorch.org/docs/stable/generated/torch.nn.SiLU.html#torch.nn.SiLU',
                          'torch.nn.Sigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.Sigmoid.html#torch.nn.Sigmoid',
                          'torch.nn.SmoothL1Loss': 'https://pytorch.org/docs/stable/generated/torch.nn.SmoothL1Loss.html#torch.nn.SmoothL1Loss',
                          'torch.nn.SoftMarginLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.SoftMarginLoss.html#torch.nn.SoftMarginLoss',
                          'torch.nn.Softmax': 'https://pytorch.org/docs/stable/generated/torch.nn.Softmax.html#torch.nn.Softmax',
                          'torch.nn.Softmax2d': 'https://pytorch.org/docs/stable/generated/torch.nn.Softmax2d.html#torch.nn.Softmax2d',
                          'torch.nn.Softmin': 'https://pytorch.org/docs/stable/generated/torch.nn.Softmin.html#torch.nn.Softmin',
                          'torch.nn.Softplus': 'https://pytorch.org/docs/stable/generated/torch.nn.Softplus.html#torch.nn.Softplus',
                          'torch.nn.Softshrink': 'https://pytorch.org/docs/stable/generated/torch.nn.Softshrink.html#torch.nn.Softshrink',
                          'torch.nn.Softsign': 'https://pytorch.org/docs/stable/generated/torch.nn.Softsign.html#torch.nn.Softsign',
                          'torch.nn.SyncBatchNorm': 'https://pytorch.org/docs/stable/generated/torch.nn.SyncBatchNorm.html#torch.nn.SyncBatchNorm',
                          'torch.nn.Tanh': 'https://pytorch.org/docs/stable/generated/torch.nn.Tanh.html#torch.nn.Tanh',
                          'torch.nn.Tanhshrink': 'https://pytorch.org/docs/stable/generated/torch.nn.Tanhshrink.html#torch.nn.Tanhshrink',
                          'torch.nn.Threshold': 'https://pytorch.org/docs/stable/generated/torch.nn.Threshold.html#torch.nn.Threshold',
                          'torch.nn.Transformer': 'https://pytorch.org/docs/stable/generated/torch.nn.Transformer.html#torch.nn.Transformer',
                          'torch.nn.TransformerDecoder': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerDecoder.html#torch.nn.TransformerDecoder',
                          'torch.nn.TransformerDecoderLayer': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerDecoderLayer.html#torch.nn.TransformerDecoderLayer',
                          'torch.nn.TransformerEncoder': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerEncoder.html#torch.nn.TransformerEncoder',
                          'torch.nn.TransformerEncoderLayer': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerEncoderLayer.html#torch.nn.TransformerEncoderLayer',
                          'torch.nn.TripletMarginLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.TripletMarginLoss.html#torch.nn.TripletMarginLoss',
                          'torch.nn.TripletMarginWithDistanceLoss': 'https://pytorch.org/docs/stable/generated/torch.nn.TripletMarginWithDistanceLoss.html#torch.nn.TripletMarginWithDistanceLoss',
                          'torch.nn.Unflatten': 'https://pytorch.org/docs/stable/generated/torch.nn.Unflatten.html#torch.nn.Unflatten',
                          'torch.nn.Unfold': 'https://pytorch.org/docs/stable/generated/torch.nn.Unfold.html#torch.nn.Unfold',
                          'torch.nn.Upsample': 'https://pytorch.org/docs/stable/generated/torch.nn.Upsample.html#torch.nn.Upsample',
                          'torch.nn.UpsamplingBilinear2d': 'https://pytorch.org/docs/stable/generated/torch.nn.UpsamplingBilinear2d.html#torch.nn.UpsamplingBilinear2d',
                          'torch.nn.UpsamplingNearest2d': 'https://pytorch.org/docs/stable/generated/torch.nn.UpsamplingNearest2d.html#torch.nn.UpsamplingNearest2d',
                          'torch.nn.ZeroPad2d': 'https://pytorch.org/docs/stable/generated/torch.nn.ZeroPad2d.html#torch.nn.ZeroPad2d',
                          'torch.nn.AdaptiveLogSoftmaxWithLoss.log_prob': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveLogSoftmaxWithLoss.html#torch.nn.AdaptiveLogSoftmaxWithLoss.log_prob',
                          'torch.nn.AdaptiveLogSoftmaxWithLoss.predict': 'https://pytorch.org/docs/stable/generated/torch.nn.AdaptiveLogSoftmaxWithLoss.html#torch.nn.AdaptiveLogSoftmaxWithLoss.predict',
                          'torch.nn.Embedding.from_pretrained': 'https://pytorch.org/docs/stable/generated/torch.nn.Embedding.html#torch.nn.Embedding.from_pretrained',
                          'torch.nn.EmbeddingBag.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.EmbeddingBag.html#torch.nn.EmbeddingBag.forward',
                          'torch.nn.EmbeddingBag.from_pretrained': 'https://pytorch.org/docs/stable/generated/torch.nn.EmbeddingBag.html#torch.nn.EmbeddingBag.from_pretrained',
                          'torch.nn.Module.add_module': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.add_module',
                          'torch.nn.Module.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.apply',
                          'torch.nn.Module.bfloat16': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.bfloat16',
                          'torch.nn.Module.buffers': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.buffers',
                          'torch.nn.Module.children': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.children',
                          'torch.nn.Module.cpu': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.cpu',
                          'torch.nn.Module.cuda': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.cuda',
                          'torch.nn.Module.double': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.double',
                          'torch.nn.Module.eval': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.eval',
                          'torch.nn.Module.extra_repr': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.extra_repr',
                          'torch.nn.Module.float': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.float',
                          'torch.nn.Module.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.forward',
                          'torch.nn.Module.get_buffer': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.get_buffer',
                          'torch.nn.Module.get_extra_state': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.get_extra_state',
                          'torch.nn.Module.get_parameter': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.get_parameter',
                          'torch.nn.Module.get_submodule': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.get_submodule',
                          'torch.nn.Module.half': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.half',
                          'torch.nn.Module.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.load_state_dict',
                          'torch.nn.Module.modules': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.modules',
                          'torch.nn.Module.named_buffers': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.named_buffers',
                          'torch.nn.Module.named_children': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.named_children',
                          'torch.nn.Module.named_modules': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.named_modules',
                          'torch.nn.Module.named_parameters': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.named_parameters',
                          'torch.nn.Module.parameters': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.parameters',
                          'torch.nn.Module.register_backward_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_backward_hook',
                          'torch.nn.Module.register_buffer': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_buffer',
                          'torch.nn.Module.register_forward_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_forward_hook',
                          'torch.nn.Module.register_forward_pre_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_forward_pre_hook',
                          'torch.nn.Module.register_full_backward_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_full_backward_hook',
                          'torch.nn.Module.register_module': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_module',
                          'torch.nn.Module.register_parameter': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.register_parameter',
                          'torch.nn.Module.requires_grad_': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.requires_grad_',
                          'torch.nn.Module.set_extra_state': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.set_extra_state',
                          'torch.nn.Module.share_memory': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.share_memory',
                          'torch.nn.Module.state_dict': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.state_dict',
                          'torch.nn.Module.to': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.to',
                          'torch.nn.Module.to_empty': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.to_empty',
                          'torch.nn.Module.train': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.train',
                          'torch.nn.Module.type': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.type',
                          'torch.nn.Module.xpu': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.xpu',
                          'torch.nn.Module.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.nn.Module.html#torch.nn.Module.zero_grad',
                          'torch.nn.ModuleDict.clear': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict.clear',
                          'torch.nn.ModuleDict.items': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict.items',
                          'torch.nn.ModuleDict.keys': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict.keys',
                          'torch.nn.ModuleDict.pop': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict.pop',
                          'torch.nn.ModuleDict.update': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict.update',
                          'torch.nn.ModuleDict.values': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleDict.html#torch.nn.ModuleDict.values',
                          'torch.nn.ModuleList.append': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleList.html#torch.nn.ModuleList.append',
                          'torch.nn.ModuleList.extend': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleList.html#torch.nn.ModuleList.extend',
                          'torch.nn.ModuleList.insert': 'https://pytorch.org/docs/stable/generated/torch.nn.ModuleList.html#torch.nn.ModuleList.insert',
                          'torch.nn.MultiheadAttention.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.MultiheadAttention.html#torch.nn.MultiheadAttention.forward',
                          'torch.nn.ParameterDict.clear': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.clear',
                          'torch.nn.ParameterDict.copy': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.copy',
                          'torch.nn.ParameterDict.fromkeys': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.fromkeys',
                          'torch.nn.ParameterDict.get': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.get',
                          'torch.nn.ParameterDict.items': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.items',
                          'torch.nn.ParameterDict.keys': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.keys',
                          'torch.nn.ParameterDict.pop': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.pop',
                          'torch.nn.ParameterDict.popitem': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.popitem',
                          'torch.nn.ParameterDict.setdefault': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.setdefault',
                          'torch.nn.ParameterDict.update': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.update',
                          'torch.nn.ParameterDict.values': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterDict.html#torch.nn.ParameterDict.values',
                          'torch.nn.ParameterList.append': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterList.html#torch.nn.ParameterList.append',
                          'torch.nn.ParameterList.extend': 'https://pytorch.org/docs/stable/generated/torch.nn.ParameterList.html#torch.nn.ParameterList.extend',
                          'torch.nn.RNNBase.flatten_parameters': 'https://pytorch.org/docs/stable/generated/torch.nn.RNNBase.html#torch.nn.RNNBase.flatten_parameters',
                          'torch.nn.Sequential.append': 'https://pytorch.org/docs/stable/generated/torch.nn.Sequential.html#torch.nn.Sequential.append',
                          'torch.nn.SyncBatchNorm.convert_sync_batchnorm': 'https://pytorch.org/docs/stable/generated/torch.nn.SyncBatchNorm.html#torch.nn.SyncBatchNorm.convert_sync_batchnorm',
                          'torch.nn.Transformer.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.Transformer.html#torch.nn.Transformer.forward',
                          'torch.nn.Transformer.generate_square_subsequent_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.Transformer.html#torch.nn.Transformer.generate_square_subsequent_mask',
                          'torch.nn.TransformerDecoder.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerDecoder.html#torch.nn.TransformerDecoder.forward',
                          'torch.nn.TransformerDecoderLayer.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerDecoderLayer.html#torch.nn.TransformerDecoderLayer.forward',
                          'torch.nn.TransformerEncoder.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerEncoder.html#torch.nn.TransformerEncoder.forward',
                          'torch.nn.TransformerEncoderLayer.forward': 'https://pytorch.org/docs/stable/generated/torch.nn.TransformerEncoderLayer.html#torch.nn.TransformerEncoderLayer.forward'},
            'torch.nn.intrinsic': { 'torch.nn.intrinsic.BNReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.BNReLU2d.html#torch.nn.intrinsic.BNReLU2d',
                                    'torch.nn.intrinsic.BNReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.BNReLU3d.html#torch.nn.intrinsic.BNReLU3d',
                                    'torch.nn.intrinsic.ConvBn1d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvBn1d.html#torch.nn.intrinsic.ConvBn1d',
                                    'torch.nn.intrinsic.ConvBn2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvBn2d.html#torch.nn.intrinsic.ConvBn2d',
                                    'torch.nn.intrinsic.ConvBn3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvBn3d.html#torch.nn.intrinsic.ConvBn3d',
                                    'torch.nn.intrinsic.ConvBnReLU1d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvBnReLU1d.html#torch.nn.intrinsic.ConvBnReLU1d',
                                    'torch.nn.intrinsic.ConvBnReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvBnReLU2d.html#torch.nn.intrinsic.ConvBnReLU2d',
                                    'torch.nn.intrinsic.ConvBnReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvBnReLU3d.html#torch.nn.intrinsic.ConvBnReLU3d',
                                    'torch.nn.intrinsic.ConvReLU1d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvReLU1d.html#torch.nn.intrinsic.ConvReLU1d',
                                    'torch.nn.intrinsic.ConvReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvReLU2d.html#torch.nn.intrinsic.ConvReLU2d',
                                    'torch.nn.intrinsic.ConvReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.ConvReLU3d.html#torch.nn.intrinsic.ConvReLU3d',
                                    'torch.nn.intrinsic.LinearReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.LinearReLU.html#torch.nn.intrinsic.LinearReLU'},
            'torch.nn.intrinsic.qat': { 'torch.nn.intrinsic.qat.ConvBn1d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvBn1d.html#torch.nn.intrinsic.qat.ConvBn1d',
                                        'torch.nn.intrinsic.qat.ConvBn2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvBn2d.html#torch.nn.intrinsic.qat.ConvBn2d',
                                        'torch.nn.intrinsic.qat.ConvBn3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvBn3d.html#torch.nn.intrinsic.qat.ConvBn3d',
                                        'torch.nn.intrinsic.qat.ConvBnReLU1d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvBnReLU1d.html#torch.nn.intrinsic.qat.ConvBnReLU1d',
                                        'torch.nn.intrinsic.qat.ConvBnReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvBnReLU2d.html#torch.nn.intrinsic.qat.ConvBnReLU2d',
                                        'torch.nn.intrinsic.qat.ConvBnReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvBnReLU3d.html#torch.nn.intrinsic.qat.ConvBnReLU3d',
                                        'torch.nn.intrinsic.qat.ConvReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvReLU2d.html#torch.nn.intrinsic.qat.ConvReLU2d',
                                        'torch.nn.intrinsic.qat.ConvReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.ConvReLU3d.html#torch.nn.intrinsic.qat.ConvReLU3d',
                                        'torch.nn.intrinsic.qat.LinearReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.LinearReLU.html#torch.nn.intrinsic.qat.LinearReLU',
                                        'torch.nn.intrinsic.qat.freeze_bn_stats': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.freeze_bn_stats.html#torch.nn.intrinsic.qat.freeze_bn_stats',
                                        'torch.nn.intrinsic.qat.update_bn_stats': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.qat.update_bn_stats.html#torch.nn.intrinsic.qat.update_bn_stats'},
            'torch.nn.intrinsic.quantized': { 'torch.nn.intrinsic.quantized.BNReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.BNReLU2d.html#torch.nn.intrinsic.quantized.BNReLU2d',
                                              'torch.nn.intrinsic.quantized.BNReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.BNReLU3d.html#torch.nn.intrinsic.quantized.BNReLU3d',
                                              'torch.nn.intrinsic.quantized.ConvReLU1d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.ConvReLU1d.html#torch.nn.intrinsic.quantized.ConvReLU1d',
                                              'torch.nn.intrinsic.quantized.ConvReLU2d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.ConvReLU2d.html#torch.nn.intrinsic.quantized.ConvReLU2d',
                                              'torch.nn.intrinsic.quantized.ConvReLU3d': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.ConvReLU3d.html#torch.nn.intrinsic.quantized.ConvReLU3d',
                                              'torch.nn.intrinsic.quantized.LinearReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.LinearReLU.html#torch.nn.intrinsic.quantized.LinearReLU'},
            'torch.nn.intrinsic.quantized.dynamic': { 'torch.nn.intrinsic.quantized.dynamic.LinearReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.intrinsic.quantized.dynamic.LinearReLU.html#torch.nn.intrinsic.quantized.dynamic.LinearReLU'},
            'torch.nn.modules.lazy': { 'torch.nn.modules.lazy.LazyModuleMixin': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.lazy.LazyModuleMixin.html#torch.nn.modules.lazy.LazyModuleMixin',
                                       'torch.nn.modules.lazy.LazyModuleMixin.has_uninitialized_params': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.lazy.LazyModuleMixin.html#torch.nn.modules.lazy.LazyModuleMixin.has_uninitialized_params',
                                       'torch.nn.modules.lazy.LazyModuleMixin.initialize_parameters': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.lazy.LazyModuleMixin.html#torch.nn.modules.lazy.LazyModuleMixin.initialize_parameters'},
            'torch.nn.parallel': { 'torch.nn.parallel.DistributedDataParallel': 'https://pytorch.org/docs/stable/generated/torch.nn.parallel.DistributedDataParallel.html#torch.nn.parallel.DistributedDataParallel',
                                   'torch.nn.parallel.DistributedDataParallel.join': 'https://pytorch.org/docs/stable/generated/torch.nn.parallel.DistributedDataParallel.html#torch.nn.parallel.DistributedDataParallel.join',
                                   'torch.nn.parallel.DistributedDataParallel.join_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.parallel.DistributedDataParallel.html#torch.nn.parallel.DistributedDataParallel.join_hook',
                                   'torch.nn.parallel.DistributedDataParallel.no_sync': 'https://pytorch.org/docs/stable/generated/torch.nn.parallel.DistributedDataParallel.html#torch.nn.parallel.DistributedDataParallel.no_sync',
                                   'torch.nn.parallel.DistributedDataParallel.register_comm_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.parallel.DistributedDataParallel.html#torch.nn.parallel.DistributedDataParallel.register_comm_hook',
                                   'torch.nn.parallel.data_parallel': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.torch.nn.parallel.data_parallel.html#torch.nn.parallel.data_parallel'},
            'torch.nn.parameter': { 'torch.nn.parameter.Parameter': 'https://pytorch.org/docs/stable/generated/torch.nn.parameter.Parameter.html#torch.nn.parameter.Parameter',
                                    'torch.nn.parameter.UninitializedBuffer': 'https://pytorch.org/docs/stable/generated/torch.nn.parameter.UninitializedBuffer.html#torch.nn.parameter.UninitializedBuffer',
                                    'torch.nn.parameter.UninitializedParameter': 'https://pytorch.org/docs/stable/generated/torch.nn.parameter.UninitializedParameter.html#torch.nn.parameter.UninitializedParameter'},
            'torch.nn.qat': { 'torch.nn.qat.Conv2d': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.Conv2d.html#torch.nn.qat.Conv2d',
                              'torch.nn.qat.Conv3d': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.Conv3d.html#torch.nn.qat.Conv3d',
                              'torch.nn.qat.Linear': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.Linear.html#torch.nn.qat.Linear',
                              'torch.nn.qat.Conv2d.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.Conv2d.html#torch.nn.qat.Conv2d.from_float',
                              'torch.nn.qat.Conv3d.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.Conv3d.html#torch.nn.qat.Conv3d.from_float',
                              'torch.nn.qat.Linear.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.Linear.html#torch.nn.qat.Linear.from_float'},
            'torch.nn.qat.dynamic': { 'torch.nn.qat.dynamic.Linear': 'https://pytorch.org/docs/stable/generated/torch.nn.qat.dynamic.Linear.html#torch.nn.qat.dynamic.Linear'},
            'torch.nn.quantized': { 'torch.nn.quantized.BatchNorm2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.BatchNorm2d.html#torch.nn.quantized.BatchNorm2d',
                                    'torch.nn.quantized.BatchNorm3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.BatchNorm3d.html#torch.nn.quantized.BatchNorm3d',
                                    'torch.nn.quantized.Conv1d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Conv1d.html#torch.nn.quantized.Conv1d',
                                    'torch.nn.quantized.Conv2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Conv2d.html#torch.nn.quantized.Conv2d',
                                    'torch.nn.quantized.Conv3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Conv3d.html#torch.nn.quantized.Conv3d',
                                    'torch.nn.quantized.ConvTranspose1d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.ConvTranspose1d.html#torch.nn.quantized.ConvTranspose1d',
                                    'torch.nn.quantized.ConvTranspose2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.ConvTranspose2d.html#torch.nn.quantized.ConvTranspose2d',
                                    'torch.nn.quantized.ConvTranspose3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.ConvTranspose3d.html#torch.nn.quantized.ConvTranspose3d',
                                    'torch.nn.quantized.ELU': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.ELU.html#torch.nn.quantized.ELU',
                                    'torch.nn.quantized.Embedding': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Embedding.html#torch.nn.quantized.Embedding',
                                    'torch.nn.quantized.EmbeddingBag': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.EmbeddingBag.html#torch.nn.quantized.EmbeddingBag',
                                    'torch.nn.quantized.FXFloatFunctional': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.FXFloatFunctional.html#torch.nn.quantized.FXFloatFunctional',
                                    'torch.nn.quantized.FloatFunctional': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.FloatFunctional.html#torch.nn.quantized.FloatFunctional',
                                    'torch.nn.quantized.GroupNorm': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.GroupNorm.html#torch.nn.quantized.GroupNorm',
                                    'torch.nn.quantized.Hardswish': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Hardswish.html#torch.nn.quantized.Hardswish',
                                    'torch.nn.quantized.InstanceNorm1d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.InstanceNorm1d.html#torch.nn.quantized.InstanceNorm1d',
                                    'torch.nn.quantized.InstanceNorm2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.InstanceNorm2d.html#torch.nn.quantized.InstanceNorm2d',
                                    'torch.nn.quantized.InstanceNorm3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.InstanceNorm3d.html#torch.nn.quantized.InstanceNorm3d',
                                    'torch.nn.quantized.LayerNorm': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.LayerNorm.html#torch.nn.quantized.LayerNorm',
                                    'torch.nn.quantized.LeakyReLU': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.LeakyReLU.html#torch.nn.quantized.LeakyReLU',
                                    'torch.nn.quantized.Linear': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Linear.html#torch.nn.quantized.Linear',
                                    'torch.nn.quantized.QFunctional': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.QFunctional.html#torch.nn.quantized.QFunctional',
                                    'torch.nn.quantized.ReLU6': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.ReLU6.html#torch.nn.quantized.ReLU6',
                                    'torch.nn.quantized.Sigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Sigmoid.html#torch.nn.quantized.Sigmoid',
                                    'torch.nn.quantized.Conv1d.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Conv1d.html#torch.nn.quantized.Conv1d.from_float',
                                    'torch.nn.quantized.Conv2d.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Conv2d.html#torch.nn.quantized.Conv2d.from_float',
                                    'torch.nn.quantized.Conv3d.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Conv3d.html#torch.nn.quantized.Conv3d.from_float',
                                    'torch.nn.quantized.Embedding.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Embedding.html#torch.nn.quantized.Embedding.from_float',
                                    'torch.nn.quantized.EmbeddingBag.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.EmbeddingBag.html#torch.nn.quantized.EmbeddingBag.from_float',
                                    'torch.nn.quantized.Linear.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Linear.html#torch.nn.quantized.Linear.from_float',
                                    'torch.nn.quantized.Linear.from_reference': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.Linear.html#torch.nn.quantized.Linear.from_reference'},
            'torch.nn.quantized.dynamic': { 'torch.nn.quantized.dynamic.GRU': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.GRU.html#torch.nn.quantized.dynamic.GRU',
                                            'torch.nn.quantized.dynamic.GRUCell': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.GRUCell.html#torch.nn.quantized.dynamic.GRUCell',
                                            'torch.nn.quantized.dynamic.LSTM': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.LSTM.html#torch.nn.quantized.dynamic.LSTM',
                                            'torch.nn.quantized.dynamic.LSTMCell': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.LSTMCell.html#torch.nn.quantized.dynamic.LSTMCell',
                                            'torch.nn.quantized.dynamic.Linear': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.Linear.html#torch.nn.quantized.dynamic.Linear',
                                            'torch.nn.quantized.dynamic.RNNCell': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.RNNCell.html#torch.nn.quantized.dynamic.RNNCell',
                                            'torch.nn.quantized.dynamic.Linear.from_float': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.dynamic.Linear.html#torch.nn.quantized.dynamic.Linear.from_float'},
            'torch.nn.quantized.functional': { 'torch.nn.quantized.functional.adaptive_avg_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.adaptive_avg_pool2d.html#torch.nn.quantized.functional.adaptive_avg_pool2d',
                                               'torch.nn.quantized.functional.adaptive_avg_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.adaptive_avg_pool3d.html#torch.nn.quantized.functional.adaptive_avg_pool3d',
                                               'torch.nn.quantized.functional.avg_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.avg_pool2d.html#torch.nn.quantized.functional.avg_pool2d',
                                               'torch.nn.quantized.functional.avg_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.avg_pool3d.html#torch.nn.quantized.functional.avg_pool3d',
                                               'torch.nn.quantized.functional.celu': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.celu.html#torch.nn.quantized.functional.celu',
                                               'torch.nn.quantized.functional.clamp': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.clamp.html#torch.nn.quantized.functional.clamp',
                                               'torch.nn.quantized.functional.conv1d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.conv1d.html#torch.nn.quantized.functional.conv1d',
                                               'torch.nn.quantized.functional.conv2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.conv2d.html#torch.nn.quantized.functional.conv2d',
                                               'torch.nn.quantized.functional.conv3d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.conv3d.html#torch.nn.quantized.functional.conv3d',
                                               'torch.nn.quantized.functional.elu': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.elu.html#torch.nn.quantized.functional.elu',
                                               'torch.nn.quantized.functional.hardsigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.hardsigmoid.html#torch.nn.quantized.functional.hardsigmoid',
                                               'torch.nn.quantized.functional.hardswish': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.hardswish.html#torch.nn.quantized.functional.hardswish',
                                               'torch.nn.quantized.functional.hardtanh': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.hardtanh.html#torch.nn.quantized.functional.hardtanh',
                                               'torch.nn.quantized.functional.interpolate': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.interpolate.html#torch.nn.quantized.functional.interpolate',
                                               'torch.nn.quantized.functional.leaky_relu': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.leaky_relu.html#torch.nn.quantized.functional.leaky_relu',
                                               'torch.nn.quantized.functional.linear': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.linear.html#torch.nn.quantized.functional.linear',
                                               'torch.nn.quantized.functional.max_pool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.max_pool1d.html#torch.nn.quantized.functional.max_pool1d',
                                               'torch.nn.quantized.functional.max_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.max_pool2d.html#torch.nn.quantized.functional.max_pool2d',
                                               'torch.nn.quantized.functional.threshold': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.threshold.html#torch.nn.quantized.functional.threshold',
                                               'torch.nn.quantized.functional.upsample': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.upsample.html#torch.nn.quantized.functional.upsample',
                                               'torch.nn.quantized.functional.upsample_bilinear': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.upsample_bilinear.html#torch.nn.quantized.functional.upsample_bilinear',
                                               'torch.nn.quantized.functional.upsample_nearest': 'https://pytorch.org/docs/stable/generated/torch.nn.quantized.functional.upsample_nearest.html#torch.nn.quantized.functional.upsample_nearest'},
            'torch.nn.utils.parametrize': { 'torch.nn.utils.parametrize.ParametrizationList': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrize.ParametrizationList.html#torch.nn.utils.parametrize.ParametrizationList',
                                            'torch.nn.utils.parametrize.ParametrizationList.right_inverse': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrize.ParametrizationList.html#torch.nn.utils.parametrize.ParametrizationList.right_inverse',
                                            'torch.nn.utils.parametrize.cached': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrize.cached.html#torch.nn.utils.parametrize.cached',
                                            'torch.nn.utils.parametrize.is_parametrized': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrize.is_parametrized.html#torch.nn.utils.parametrize.is_parametrized',
                                            'torch.nn.utils.parametrize.register_parametrization': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrize.register_parametrization.html#torch.nn.utils.parametrize.register_parametrization',
                                            'torch.nn.utils.parametrize.remove_parametrizations': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrize.remove_parametrizations.html#torch.nn.utils.parametrize.remove_parametrizations'},
            'torch.nn.utils.prune': { 'torch.nn.utils.prune.BasePruningMethod': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.BasePruningMethod.html#torch.nn.utils.prune.BasePruningMethod',
                                      'torch.nn.utils.prune.CustomFromMask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.CustomFromMask.html#torch.nn.utils.prune.CustomFromMask',
                                      'torch.nn.utils.prune.Identity': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.Identity.html#torch.nn.utils.prune.Identity',
                                      'torch.nn.utils.prune.L1Unstructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.L1Unstructured.html#torch.nn.utils.prune.L1Unstructured',
                                      'torch.nn.utils.prune.LnStructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.LnStructured.html#torch.nn.utils.prune.LnStructured',
                                      'torch.nn.utils.prune.PruningContainer': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer',
                                      'torch.nn.utils.prune.RandomStructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomStructured.html#torch.nn.utils.prune.RandomStructured',
                                      'torch.nn.utils.prune.RandomUnstructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomUnstructured.html#torch.nn.utils.prune.RandomUnstructured',
                                      'torch.nn.utils.prune.BasePruningMethod.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.BasePruningMethod.html#torch.nn.utils.prune.BasePruningMethod.apply',
                                      'torch.nn.utils.prune.BasePruningMethod.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.BasePruningMethod.html#torch.nn.utils.prune.BasePruningMethod.apply_mask',
                                      'torch.nn.utils.prune.BasePruningMethod.compute_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.BasePruningMethod.html#torch.nn.utils.prune.BasePruningMethod.compute_mask',
                                      'torch.nn.utils.prune.BasePruningMethod.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.BasePruningMethod.html#torch.nn.utils.prune.BasePruningMethod.prune',
                                      'torch.nn.utils.prune.BasePruningMethod.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.BasePruningMethod.html#torch.nn.utils.prune.BasePruningMethod.remove',
                                      'torch.nn.utils.prune.CustomFromMask.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.CustomFromMask.html#torch.nn.utils.prune.CustomFromMask.apply',
                                      'torch.nn.utils.prune.CustomFromMask.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.CustomFromMask.html#torch.nn.utils.prune.CustomFromMask.apply_mask',
                                      'torch.nn.utils.prune.CustomFromMask.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.CustomFromMask.html#torch.nn.utils.prune.CustomFromMask.prune',
                                      'torch.nn.utils.prune.CustomFromMask.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.CustomFromMask.html#torch.nn.utils.prune.CustomFromMask.remove',
                                      'torch.nn.utils.prune.Identity.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.Identity.html#torch.nn.utils.prune.Identity.apply',
                                      'torch.nn.utils.prune.Identity.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.Identity.html#torch.nn.utils.prune.Identity.apply_mask',
                                      'torch.nn.utils.prune.Identity.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.Identity.html#torch.nn.utils.prune.Identity.prune',
                                      'torch.nn.utils.prune.Identity.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.Identity.html#torch.nn.utils.prune.Identity.remove',
                                      'torch.nn.utils.prune.L1Unstructured.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.L1Unstructured.html#torch.nn.utils.prune.L1Unstructured.apply',
                                      'torch.nn.utils.prune.L1Unstructured.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.L1Unstructured.html#torch.nn.utils.prune.L1Unstructured.apply_mask',
                                      'torch.nn.utils.prune.L1Unstructured.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.L1Unstructured.html#torch.nn.utils.prune.L1Unstructured.prune',
                                      'torch.nn.utils.prune.L1Unstructured.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.L1Unstructured.html#torch.nn.utils.prune.L1Unstructured.remove',
                                      'torch.nn.utils.prune.LnStructured.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.LnStructured.html#torch.nn.utils.prune.LnStructured.apply',
                                      'torch.nn.utils.prune.LnStructured.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.LnStructured.html#torch.nn.utils.prune.LnStructured.apply_mask',
                                      'torch.nn.utils.prune.LnStructured.compute_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.LnStructured.html#torch.nn.utils.prune.LnStructured.compute_mask',
                                      'torch.nn.utils.prune.LnStructured.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.LnStructured.html#torch.nn.utils.prune.LnStructured.prune',
                                      'torch.nn.utils.prune.LnStructured.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.LnStructured.html#torch.nn.utils.prune.LnStructured.remove',
                                      'torch.nn.utils.prune.PruningContainer.add_pruning_method': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer.add_pruning_method',
                                      'torch.nn.utils.prune.PruningContainer.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer.apply',
                                      'torch.nn.utils.prune.PruningContainer.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer.apply_mask',
                                      'torch.nn.utils.prune.PruningContainer.compute_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer.compute_mask',
                                      'torch.nn.utils.prune.PruningContainer.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer.prune',
                                      'torch.nn.utils.prune.PruningContainer.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.PruningContainer.html#torch.nn.utils.prune.PruningContainer.remove',
                                      'torch.nn.utils.prune.RandomStructured.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomStructured.html#torch.nn.utils.prune.RandomStructured.apply',
                                      'torch.nn.utils.prune.RandomStructured.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomStructured.html#torch.nn.utils.prune.RandomStructured.apply_mask',
                                      'torch.nn.utils.prune.RandomStructured.compute_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomStructured.html#torch.nn.utils.prune.RandomStructured.compute_mask',
                                      'torch.nn.utils.prune.RandomStructured.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomStructured.html#torch.nn.utils.prune.RandomStructured.prune',
                                      'torch.nn.utils.prune.RandomStructured.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomStructured.html#torch.nn.utils.prune.RandomStructured.remove',
                                      'torch.nn.utils.prune.RandomUnstructured.apply': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomUnstructured.html#torch.nn.utils.prune.RandomUnstructured.apply',
                                      'torch.nn.utils.prune.RandomUnstructured.apply_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomUnstructured.html#torch.nn.utils.prune.RandomUnstructured.apply_mask',
                                      'torch.nn.utils.prune.RandomUnstructured.prune': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomUnstructured.html#torch.nn.utils.prune.RandomUnstructured.prune',
                                      'torch.nn.utils.prune.RandomUnstructured.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.RandomUnstructured.html#torch.nn.utils.prune.RandomUnstructured.remove',
                                      'torch.nn.utils.prune.custom_from_mask': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.custom_from_mask.html#torch.nn.utils.prune.custom_from_mask',
                                      'torch.nn.utils.prune.global_unstructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.global_unstructured.html#torch.nn.utils.prune.global_unstructured',
                                      'torch.nn.utils.prune.identity': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.identity.html#torch.nn.utils.prune.identity',
                                      'torch.nn.utils.prune.is_pruned': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.is_pruned.html#torch.nn.utils.prune.is_pruned',
                                      'torch.nn.utils.prune.l1_unstructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.l1_unstructured.html#torch.nn.utils.prune.l1_unstructured',
                                      'torch.nn.utils.prune.ln_structured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.ln_structured.html#torch.nn.utils.prune.ln_structured',
                                      'torch.nn.utils.prune.random_structured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.random_structured.html#torch.nn.utils.prune.random_structured',
                                      'torch.nn.utils.prune.random_unstructured': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.random_unstructured.html#torch.nn.utils.prune.random_unstructured',
                                      'torch.nn.utils.prune.remove': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.prune.remove.html#torch.nn.utils.prune.remove'},
            'torch.nn.utils.rnn': { 'torch.nn.utils.rnn.PackedSequence': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence',
                                    'torch.nn.utils.rnn.PackedSequence.batch_sizes': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.batch_sizes',
                                    'torch.nn.utils.rnn.PackedSequence.count': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.count',
                                    'torch.nn.utils.rnn.PackedSequence.data': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.data',
                                    'torch.nn.utils.rnn.PackedSequence.index': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.index',
                                    'torch.nn.utils.rnn.PackedSequence.is_cuda': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.is_cuda',
                                    'torch.nn.utils.rnn.PackedSequence.is_pinned': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.is_pinned',
                                    'torch.nn.utils.rnn.PackedSequence.sorted_indices': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.sorted_indices',
                                    'torch.nn.utils.rnn.PackedSequence.to': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.to',
                                    'torch.nn.utils.rnn.PackedSequence.unsorted_indices': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.PackedSequence.html#torch.nn.utils.rnn.PackedSequence.unsorted_indices',
                                    'torch.nn.utils.rnn.pack_padded_sequence': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.pack_padded_sequence.html#torch.nn.utils.rnn.pack_padded_sequence',
                                    'torch.nn.utils.rnn.pack_sequence': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.pack_sequence.html#torch.nn.utils.rnn.pack_sequence',
                                    'torch.nn.utils.rnn.pad_packed_sequence': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.pad_packed_sequence.html#torch.nn.utils.rnn.pad_packed_sequence',
                                    'torch.nn.utils.rnn.pad_sequence': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.rnn.pad_sequence.html#torch.nn.utils.rnn.pad_sequence'},
            'torch.optim': { 'torch.optim.ASGD': 'https://pytorch.org/docs/stable/generated/torch.optim.ASGD.html#torch.optim.ASGD',
                             'torch.optim.Adadelta': 'https://pytorch.org/docs/stable/generated/torch.optim.Adadelta.html#torch.optim.Adadelta',
                             'torch.optim.Adagrad': 'https://pytorch.org/docs/stable/generated/torch.optim.Adagrad.html#torch.optim.Adagrad',
                             'torch.optim.Adam': 'https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam',
                             'torch.optim.AdamW': 'https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW',
                             'torch.optim.Adamax': 'https://pytorch.org/docs/stable/generated/torch.optim.Adamax.html#torch.optim.Adamax',
                             'torch.optim.LBFGS': 'https://pytorch.org/docs/stable/generated/torch.optim.LBFGS.html#torch.optim.LBFGS',
                             'torch.optim.NAdam': 'https://pytorch.org/docs/stable/generated/torch.optim.NAdam.html#torch.optim.NAdam',
                             'torch.optim.Optimizer': 'https://pytorch.org/docs/stable/optim.html#torch.optim.Optimizer',
                             'torch.optim.RAdam': 'https://pytorch.org/docs/stable/generated/torch.optim.RAdam.html#torch.optim.RAdam',
                             'torch.optim.RMSprop': 'https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop',
                             'torch.optim.Rprop': 'https://pytorch.org/docs/stable/generated/torch.optim.Rprop.html#torch.optim.Rprop',
                             'torch.optim.SGD': 'https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD',
                             'torch.optim.SparseAdam': 'https://pytorch.org/docs/stable/generated/torch.optim.SparseAdam.html#torch.optim.SparseAdam',
                             'torch.optim.ASGD.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.ASGD.html#torch.optim.ASGD.add_param_group',
                             'torch.optim.ASGD.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.ASGD.html#torch.optim.ASGD.load_state_dict',
                             'torch.optim.ASGD.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.ASGD.html#torch.optim.ASGD.state_dict',
                             'torch.optim.ASGD.step': 'https://pytorch.org/docs/stable/generated/torch.optim.ASGD.html#torch.optim.ASGD.step',
                             'torch.optim.ASGD.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.ASGD.html#torch.optim.ASGD.zero_grad',
                             'torch.optim.Adadelta.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.Adadelta.html#torch.optim.Adadelta.add_param_group',
                             'torch.optim.Adadelta.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adadelta.html#torch.optim.Adadelta.load_state_dict',
                             'torch.optim.Adadelta.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adadelta.html#torch.optim.Adadelta.state_dict',
                             'torch.optim.Adadelta.step': 'https://pytorch.org/docs/stable/generated/torch.optim.Adadelta.html#torch.optim.Adadelta.step',
                             'torch.optim.Adadelta.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.Adadelta.html#torch.optim.Adadelta.zero_grad',
                             'torch.optim.Adagrad.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.Adagrad.html#torch.optim.Adagrad.add_param_group',
                             'torch.optim.Adagrad.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adagrad.html#torch.optim.Adagrad.load_state_dict',
                             'torch.optim.Adagrad.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adagrad.html#torch.optim.Adagrad.state_dict',
                             'torch.optim.Adagrad.step': 'https://pytorch.org/docs/stable/generated/torch.optim.Adagrad.html#torch.optim.Adagrad.step',
                             'torch.optim.Adagrad.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.Adagrad.html#torch.optim.Adagrad.zero_grad',
                             'torch.optim.Adam.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam.add_param_group',
                             'torch.optim.Adam.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam.load_state_dict',
                             'torch.optim.Adam.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam.state_dict',
                             'torch.optim.Adam.step': 'https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam.step',
                             'torch.optim.Adam.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam.zero_grad',
                             'torch.optim.AdamW.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW.add_param_group',
                             'torch.optim.AdamW.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW.load_state_dict',
                             'torch.optim.AdamW.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW.state_dict',
                             'torch.optim.AdamW.step': 'https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW.step',
                             'torch.optim.AdamW.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW.zero_grad',
                             'torch.optim.Adamax.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.Adamax.html#torch.optim.Adamax.add_param_group',
                             'torch.optim.Adamax.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adamax.html#torch.optim.Adamax.load_state_dict',
                             'torch.optim.Adamax.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Adamax.html#torch.optim.Adamax.state_dict',
                             'torch.optim.Adamax.step': 'https://pytorch.org/docs/stable/generated/torch.optim.Adamax.html#torch.optim.Adamax.step',
                             'torch.optim.Adamax.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.Adamax.html#torch.optim.Adamax.zero_grad',
                             'torch.optim.LBFGS.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.LBFGS.html#torch.optim.LBFGS.add_param_group',
                             'torch.optim.LBFGS.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.LBFGS.html#torch.optim.LBFGS.load_state_dict',
                             'torch.optim.LBFGS.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.LBFGS.html#torch.optim.LBFGS.state_dict',
                             'torch.optim.LBFGS.step': 'https://pytorch.org/docs/stable/generated/torch.optim.LBFGS.html#torch.optim.LBFGS.step',
                             'torch.optim.LBFGS.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.LBFGS.html#torch.optim.LBFGS.zero_grad',
                             'torch.optim.NAdam.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.NAdam.html#torch.optim.NAdam.add_param_group',
                             'torch.optim.NAdam.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.NAdam.html#torch.optim.NAdam.load_state_dict',
                             'torch.optim.NAdam.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.NAdam.html#torch.optim.NAdam.state_dict',
                             'torch.optim.NAdam.step': 'https://pytorch.org/docs/stable/generated/torch.optim.NAdam.html#torch.optim.NAdam.step',
                             'torch.optim.NAdam.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.NAdam.html#torch.optim.NAdam.zero_grad',
                             'torch.optim.Optimizer.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.Optimizer.add_param_group.html#torch.optim.Optimizer.add_param_group',
                             'torch.optim.Optimizer.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Optimizer.load_state_dict.html#torch.optim.Optimizer.load_state_dict',
                             'torch.optim.Optimizer.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Optimizer.state_dict.html#torch.optim.Optimizer.state_dict',
                             'torch.optim.Optimizer.step': 'https://pytorch.org/docs/stable/generated/torch.optim.Optimizer.step.html#torch.optim.Optimizer.step',
                             'torch.optim.Optimizer.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.Optimizer.zero_grad.html#torch.optim.Optimizer.zero_grad',
                             'torch.optim.RAdam.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.RAdam.html#torch.optim.RAdam.add_param_group',
                             'torch.optim.RAdam.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.RAdam.html#torch.optim.RAdam.load_state_dict',
                             'torch.optim.RAdam.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.RAdam.html#torch.optim.RAdam.state_dict',
                             'torch.optim.RAdam.step': 'https://pytorch.org/docs/stable/generated/torch.optim.RAdam.html#torch.optim.RAdam.step',
                             'torch.optim.RAdam.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.RAdam.html#torch.optim.RAdam.zero_grad',
                             'torch.optim.RMSprop.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop.add_param_group',
                             'torch.optim.RMSprop.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop.load_state_dict',
                             'torch.optim.RMSprop.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop.state_dict',
                             'torch.optim.RMSprop.step': 'https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop.step',
                             'torch.optim.RMSprop.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop.zero_grad',
                             'torch.optim.Rprop.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.Rprop.html#torch.optim.Rprop.add_param_group',
                             'torch.optim.Rprop.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Rprop.html#torch.optim.Rprop.load_state_dict',
                             'torch.optim.Rprop.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.Rprop.html#torch.optim.Rprop.state_dict',
                             'torch.optim.Rprop.step': 'https://pytorch.org/docs/stable/generated/torch.optim.Rprop.html#torch.optim.Rprop.step',
                             'torch.optim.Rprop.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.Rprop.html#torch.optim.Rprop.zero_grad',
                             'torch.optim.SGD.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD.add_param_group',
                             'torch.optim.SGD.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD.load_state_dict',
                             'torch.optim.SGD.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD.state_dict',
                             'torch.optim.SGD.step': 'https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD.step',
                             'torch.optim.SGD.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD.zero_grad',
                             'torch.optim.SparseAdam.add_param_group': 'https://pytorch.org/docs/stable/generated/torch.optim.SparseAdam.html#torch.optim.SparseAdam.add_param_group',
                             'torch.optim.SparseAdam.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.SparseAdam.html#torch.optim.SparseAdam.load_state_dict',
                             'torch.optim.SparseAdam.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.SparseAdam.html#torch.optim.SparseAdam.state_dict',
                             'torch.optim.SparseAdam.step': 'https://pytorch.org/docs/stable/generated/torch.optim.SparseAdam.html#torch.optim.SparseAdam.step',
                             'torch.optim.SparseAdam.zero_grad': 'https://pytorch.org/docs/stable/generated/torch.optim.SparseAdam.html#torch.optim.SparseAdam.zero_grad'},
            'torch.optim.lr_scheduler': { 'torch.optim.lr_scheduler.ChainedScheduler': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ChainedScheduler.html#torch.optim.lr_scheduler.ChainedScheduler',
                                          'torch.optim.lr_scheduler.ConstantLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ConstantLR.html#torch.optim.lr_scheduler.ConstantLR',
                                          'torch.optim.lr_scheduler.CosineAnnealingLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingLR.html#torch.optim.lr_scheduler.CosineAnnealingLR',
                                          'torch.optim.lr_scheduler.CosineAnnealingWarmRestarts': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.html#torch.optim.lr_scheduler.CosineAnnealingWarmRestarts',
                                          'torch.optim.lr_scheduler.CyclicLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CyclicLR.html#torch.optim.lr_scheduler.CyclicLR',
                                          'torch.optim.lr_scheduler.ExponentialLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ExponentialLR.html#torch.optim.lr_scheduler.ExponentialLR',
                                          'torch.optim.lr_scheduler.LambdaLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LambdaLR.html#torch.optim.lr_scheduler.LambdaLR',
                                          'torch.optim.lr_scheduler.LinearLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LinearLR.html#torch.optim.lr_scheduler.LinearLR',
                                          'torch.optim.lr_scheduler.MultiStepLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiStepLR.html#torch.optim.lr_scheduler.MultiStepLR',
                                          'torch.optim.lr_scheduler.MultiplicativeLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiplicativeLR.html#torch.optim.lr_scheduler.MultiplicativeLR',
                                          'torch.optim.lr_scheduler.OneCycleLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.OneCycleLR.html#torch.optim.lr_scheduler.OneCycleLR',
                                          'torch.optim.lr_scheduler.ReduceLROnPlateau': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ReduceLROnPlateau.html#torch.optim.lr_scheduler.ReduceLROnPlateau',
                                          'torch.optim.lr_scheduler.SequentialLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.SequentialLR.html#torch.optim.lr_scheduler.SequentialLR',
                                          'torch.optim.lr_scheduler.StepLR': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.StepLR.html#torch.optim.lr_scheduler.StepLR',
                                          'torch.optim.lr_scheduler.ChainedScheduler.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ChainedScheduler.html#torch.optim.lr_scheduler.ChainedScheduler.get_last_lr',
                                          'torch.optim.lr_scheduler.ChainedScheduler.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ChainedScheduler.html#torch.optim.lr_scheduler.ChainedScheduler.load_state_dict',
                                          'torch.optim.lr_scheduler.ChainedScheduler.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ChainedScheduler.html#torch.optim.lr_scheduler.ChainedScheduler.print_lr',
                                          'torch.optim.lr_scheduler.ChainedScheduler.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ChainedScheduler.html#torch.optim.lr_scheduler.ChainedScheduler.state_dict',
                                          'torch.optim.lr_scheduler.ConstantLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ConstantLR.html#torch.optim.lr_scheduler.ConstantLR.get_last_lr',
                                          'torch.optim.lr_scheduler.ConstantLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ConstantLR.html#torch.optim.lr_scheduler.ConstantLR.load_state_dict',
                                          'torch.optim.lr_scheduler.ConstantLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ConstantLR.html#torch.optim.lr_scheduler.ConstantLR.print_lr',
                                          'torch.optim.lr_scheduler.ConstantLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ConstantLR.html#torch.optim.lr_scheduler.ConstantLR.state_dict',
                                          'torch.optim.lr_scheduler.CosineAnnealingLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingLR.html#torch.optim.lr_scheduler.CosineAnnealingLR.get_last_lr',
                                          'torch.optim.lr_scheduler.CosineAnnealingLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingLR.html#torch.optim.lr_scheduler.CosineAnnealingLR.load_state_dict',
                                          'torch.optim.lr_scheduler.CosineAnnealingLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingLR.html#torch.optim.lr_scheduler.CosineAnnealingLR.print_lr',
                                          'torch.optim.lr_scheduler.CosineAnnealingLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingLR.html#torch.optim.lr_scheduler.CosineAnnealingLR.state_dict',
                                          'torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.html#torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.get_last_lr',
                                          'torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.html#torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.load_state_dict',
                                          'torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.html#torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.print_lr',
                                          'torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.html#torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.state_dict',
                                          'torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.step': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.html#torch.optim.lr_scheduler.CosineAnnealingWarmRestarts.step',
                                          'torch.optim.lr_scheduler.CyclicLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CyclicLR.html#torch.optim.lr_scheduler.CyclicLR.get_last_lr',
                                          'torch.optim.lr_scheduler.CyclicLR.get_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CyclicLR.html#torch.optim.lr_scheduler.CyclicLR.get_lr',
                                          'torch.optim.lr_scheduler.CyclicLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CyclicLR.html#torch.optim.lr_scheduler.CyclicLR.load_state_dict',
                                          'torch.optim.lr_scheduler.CyclicLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CyclicLR.html#torch.optim.lr_scheduler.CyclicLR.print_lr',
                                          'torch.optim.lr_scheduler.CyclicLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.CyclicLR.html#torch.optim.lr_scheduler.CyclicLR.state_dict',
                                          'torch.optim.lr_scheduler.ExponentialLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ExponentialLR.html#torch.optim.lr_scheduler.ExponentialLR.get_last_lr',
                                          'torch.optim.lr_scheduler.ExponentialLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ExponentialLR.html#torch.optim.lr_scheduler.ExponentialLR.load_state_dict',
                                          'torch.optim.lr_scheduler.ExponentialLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ExponentialLR.html#torch.optim.lr_scheduler.ExponentialLR.print_lr',
                                          'torch.optim.lr_scheduler.ExponentialLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.ExponentialLR.html#torch.optim.lr_scheduler.ExponentialLR.state_dict',
                                          'torch.optim.lr_scheduler.LambdaLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LambdaLR.html#torch.optim.lr_scheduler.LambdaLR.get_last_lr',
                                          'torch.optim.lr_scheduler.LambdaLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LambdaLR.html#torch.optim.lr_scheduler.LambdaLR.load_state_dict',
                                          'torch.optim.lr_scheduler.LambdaLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LambdaLR.html#torch.optim.lr_scheduler.LambdaLR.print_lr',
                                          'torch.optim.lr_scheduler.LambdaLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LambdaLR.html#torch.optim.lr_scheduler.LambdaLR.state_dict',
                                          'torch.optim.lr_scheduler.LinearLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LinearLR.html#torch.optim.lr_scheduler.LinearLR.get_last_lr',
                                          'torch.optim.lr_scheduler.LinearLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LinearLR.html#torch.optim.lr_scheduler.LinearLR.load_state_dict',
                                          'torch.optim.lr_scheduler.LinearLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LinearLR.html#torch.optim.lr_scheduler.LinearLR.print_lr',
                                          'torch.optim.lr_scheduler.LinearLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.LinearLR.html#torch.optim.lr_scheduler.LinearLR.state_dict',
                                          'torch.optim.lr_scheduler.MultiStepLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiStepLR.html#torch.optim.lr_scheduler.MultiStepLR.get_last_lr',
                                          'torch.optim.lr_scheduler.MultiStepLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiStepLR.html#torch.optim.lr_scheduler.MultiStepLR.load_state_dict',
                                          'torch.optim.lr_scheduler.MultiStepLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiStepLR.html#torch.optim.lr_scheduler.MultiStepLR.print_lr',
                                          'torch.optim.lr_scheduler.MultiStepLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiStepLR.html#torch.optim.lr_scheduler.MultiStepLR.state_dict',
                                          'torch.optim.lr_scheduler.MultiplicativeLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiplicativeLR.html#torch.optim.lr_scheduler.MultiplicativeLR.get_last_lr',
                                          'torch.optim.lr_scheduler.MultiplicativeLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiplicativeLR.html#torch.optim.lr_scheduler.MultiplicativeLR.load_state_dict',
                                          'torch.optim.lr_scheduler.MultiplicativeLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiplicativeLR.html#torch.optim.lr_scheduler.MultiplicativeLR.print_lr',
                                          'torch.optim.lr_scheduler.MultiplicativeLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.MultiplicativeLR.html#torch.optim.lr_scheduler.MultiplicativeLR.state_dict',
                                          'torch.optim.lr_scheduler.OneCycleLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.OneCycleLR.html#torch.optim.lr_scheduler.OneCycleLR.get_last_lr',
                                          'torch.optim.lr_scheduler.OneCycleLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.OneCycleLR.html#torch.optim.lr_scheduler.OneCycleLR.load_state_dict',
                                          'torch.optim.lr_scheduler.OneCycleLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.OneCycleLR.html#torch.optim.lr_scheduler.OneCycleLR.print_lr',
                                          'torch.optim.lr_scheduler.OneCycleLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.OneCycleLR.html#torch.optim.lr_scheduler.OneCycleLR.state_dict',
                                          'torch.optim.lr_scheduler.SequentialLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.SequentialLR.html#torch.optim.lr_scheduler.SequentialLR.get_last_lr',
                                          'torch.optim.lr_scheduler.SequentialLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.SequentialLR.html#torch.optim.lr_scheduler.SequentialLR.load_state_dict',
                                          'torch.optim.lr_scheduler.SequentialLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.SequentialLR.html#torch.optim.lr_scheduler.SequentialLR.print_lr',
                                          'torch.optim.lr_scheduler.SequentialLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.SequentialLR.html#torch.optim.lr_scheduler.SequentialLR.state_dict',
                                          'torch.optim.lr_scheduler.StepLR.get_last_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.StepLR.html#torch.optim.lr_scheduler.StepLR.get_last_lr',
                                          'torch.optim.lr_scheduler.StepLR.load_state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.StepLR.html#torch.optim.lr_scheduler.StepLR.load_state_dict',
                                          'torch.optim.lr_scheduler.StepLR.print_lr': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.StepLR.html#torch.optim.lr_scheduler.StepLR.print_lr',
                                          'torch.optim.lr_scheduler.StepLR.state_dict': 'https://pytorch.org/docs/stable/generated/torch.optim.lr_scheduler.StepLR.html#torch.optim.lr_scheduler.StepLR.state_dict'},
            'torch.package': { 'torch.package.Directory': 'https://pytorch.org/docs/stable/package.html#torch.package.Directory',
                               'torch.package.EmptyMatchError': 'https://pytorch.org/docs/stable/package.html#torch.package.EmptyMatchError',
                               'torch.package.PackageExporter': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter',
                               'torch.package.PackageImporter': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter',
                               'torch.package.PackagingError': 'https://pytorch.org/docs/stable/package.html#torch.package.PackagingError',
                               'torch.package.Directory.has_file': 'https://pytorch.org/docs/stable/package.html#torch.package.Directory.has_file',
                               'torch.package.PackageExporter.__init__': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.__init__',
                               'torch.package.PackageExporter.add_dependency': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.add_dependency',
                               'torch.package.PackageExporter.all_paths': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.all_paths',
                               'torch.package.PackageExporter.close': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.close',
                               'torch.package.PackageExporter.denied_modules': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.denied_modules',
                               'torch.package.PackageExporter.deny': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.deny',
                               'torch.package.PackageExporter.dependency_graph_string': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.dependency_graph_string',
                               'torch.package.PackageExporter.extern': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.extern',
                               'torch.package.PackageExporter.externed_modules': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.externed_modules',
                               'torch.package.PackageExporter.get_rdeps': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.get_rdeps',
                               'torch.package.PackageExporter.get_unique_id': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.get_unique_id',
                               'torch.package.PackageExporter.intern': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.intern',
                               'torch.package.PackageExporter.interned_modules': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.interned_modules',
                               'torch.package.PackageExporter.mock': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.mock',
                               'torch.package.PackageExporter.mocked_modules': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.mocked_modules',
                               'torch.package.PackageExporter.register_extern_hook': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.register_extern_hook',
                               'torch.package.PackageExporter.register_intern_hook': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.register_intern_hook',
                               'torch.package.PackageExporter.register_mock_hook': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.register_mock_hook',
                               'torch.package.PackageExporter.save_binary': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.save_binary',
                               'torch.package.PackageExporter.save_module': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.save_module',
                               'torch.package.PackageExporter.save_pickle': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.save_pickle',
                               'torch.package.PackageExporter.save_source_file': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.save_source_file',
                               'torch.package.PackageExporter.save_source_string': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.save_source_string',
                               'torch.package.PackageExporter.save_text': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageExporter.save_text',
                               'torch.package.PackageImporter.__init__': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.__init__',
                               'torch.package.PackageImporter.file_structure': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.file_structure',
                               'torch.package.PackageImporter.id': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.id',
                               'torch.package.PackageImporter.import_module': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.import_module',
                               'torch.package.PackageImporter.load_binary': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.load_binary',
                               'torch.package.PackageImporter.load_pickle': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.load_pickle',
                               'torch.package.PackageImporter.load_text': 'https://pytorch.org/docs/stable/package.html#torch.package.PackageImporter.load_text'},
            'torch.profiler': { 'torch.profiler.ProfilerAction': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.ProfilerAction',
                                'torch.profiler.ProfilerActivity': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.ProfilerActivity',
                                'torch.profiler._KinetoProfile': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile',
                                'torch.profiler.profile': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.profile',
                                'torch.profiler.ProfilerActivity.name': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.ProfilerActivity.name',
                                'torch.profiler._KinetoProfile.add_metadata': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile.add_metadata',
                                'torch.profiler._KinetoProfile.add_metadata_json': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile.add_metadata_json',
                                'torch.profiler._KinetoProfile.events': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile.events',
                                'torch.profiler._KinetoProfile.export_chrome_trace': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile.export_chrome_trace',
                                'torch.profiler._KinetoProfile.export_stacks': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile.export_stacks',
                                'torch.profiler._KinetoProfile.key_averages': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler._KinetoProfile.key_averages',
                                'torch.profiler.profile.step': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.profile.step',
                                'torch.profiler.schedule': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.schedule',
                                'torch.profiler.tensorboard_trace_handler': 'https://pytorch.org/docs/stable/profiler.html#torch.profiler.tensorboard_trace_handler'},
            'torch.quantization': { 'torch.quantization.DeQuantStub': 'https://pytorch.org/docs/stable/generated/torch.quantization.DeQuantStub.html#torch.quantization.DeQuantStub',
                                    'torch.quantization.QuantStub': 'https://pytorch.org/docs/stable/generated/torch.quantization.QuantStub.html#torch.quantization.QuantStub',
                                    'torch.quantization.QuantWrapper': 'https://pytorch.org/docs/stable/generated/torch.quantization.QuantWrapper.html#torch.quantization.QuantWrapper',
                                    'torch.quantization.add_observer_': 'https://pytorch.org/docs/stable/generated/torch.quantization.add_observer_.html#torch.quantization.add_observer_',
                                    'torch.quantization.add_quant_dequant': 'https://pytorch.org/docs/stable/generated/torch.quantization.add_quant_dequant.html#torch.quantization.add_quant_dequant',
                                    'torch.quantization.convert': 'https://pytorch.org/docs/stable/generated/torch.quantization.convert.html#torch.quantization.convert',
                                    'torch.quantization.default_eval_fn': 'https://pytorch.org/docs/stable/generated/torch.quantization.default_eval_fn.html#torch.quantization.default_eval_fn',
                                    'torch.quantization.fuse_modules': 'https://pytorch.org/docs/stable/generated/torch.quantization.fuse_modules.html#torch.quantization.fuse_modules',
                                    'torch.quantization.get_observer_dict': 'https://pytorch.org/docs/stable/generated/torch.quantization.get_observer_dict.html#torch.quantization.get_observer_dict',
                                    'torch.quantization.prepare': 'https://pytorch.org/docs/stable/generated/torch.quantization.prepare.html#torch.quantization.prepare',
                                    'torch.quantization.prepare_qat': 'https://pytorch.org/docs/stable/generated/torch.quantization.prepare_qat.html#torch.quantization.prepare_qat',
                                    'torch.quantization.propagate_qconfig_': 'https://pytorch.org/docs/stable/generated/torch.quantization.propagate_qconfig_.html#torch.quantization.propagate_qconfig_',
                                    'torch.quantization.quantize': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize.html#torch.quantization.quantize',
                                    'torch.quantization.quantize_dynamic': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize_dynamic.html#torch.quantization.quantize_dynamic',
                                    'torch.quantization.quantize_qat': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize_qat.html#torch.quantization.quantize_qat',
                                    'torch.quantization.swap_module': 'https://pytorch.org/docs/stable/generated/torch.quantization.swap_module.html#torch.quantization.swap_module'},
            'torch.quantization.fake_quantize': { 'torch.quantization.fake_quantize.FakeQuantize': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.FakeQuantize.html#torch.quantization.fake_quantize.FakeQuantize',
                                                  'torch.quantization.fake_quantize.FakeQuantizeBase': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.FakeQuantizeBase.html#torch.quantization.fake_quantize.FakeQuantizeBase',
                                                  'torch.quantization.fake_quantize.FixedQParamsFakeQuantize': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.FixedQParamsFakeQuantize.html#torch.quantization.fake_quantize.FixedQParamsFakeQuantize',
                                                  'torch.quantization.fake_quantize.FusedMovingAvgObsFakeQuantize': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.FusedMovingAvgObsFakeQuantize.html#torch.quantization.fake_quantize.FusedMovingAvgObsFakeQuantize',
                                                  'torch.quantization.fake_quantize.disable_fake_quant': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.disable_fake_quant.html#torch.quantization.fake_quantize.disable_fake_quant',
                                                  'torch.quantization.fake_quantize.disable_observer': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.disable_observer.html#torch.quantization.fake_quantize.disable_observer',
                                                  'torch.quantization.fake_quantize.enable_fake_quant': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.enable_fake_quant.html#torch.quantization.fake_quantize.enable_fake_quant',
                                                  'torch.quantization.fake_quantize.enable_observer': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.enable_observer.html#torch.quantization.fake_quantize.enable_observer',
                                                  'torch.quantization.fake_quantize.FakeQuantizeBase.with_args': 'https://pytorch.org/docs/stable/generated/torch.quantization.fake_quantize.FakeQuantizeBase.html#torch.quantization.fake_quantize.FakeQuantizeBase.with_args'},
            'torch.quantization.observer': { 'torch.quantization.observer.HistogramObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.HistogramObserver.html#torch.quantization.observer.HistogramObserver',
                                             'torch.quantization.observer.MinMaxObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.MinMaxObserver.html#torch.quantization.observer.MinMaxObserver',
                                             'torch.quantization.observer.MovingAverageMinMaxObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.MovingAverageMinMaxObserver.html#torch.quantization.observer.MovingAverageMinMaxObserver',
                                             'torch.quantization.observer.MovingAveragePerChannelMinMaxObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.MovingAveragePerChannelMinMaxObserver.html#torch.quantization.observer.MovingAveragePerChannelMinMaxObserver',
                                             'torch.quantization.observer.NoopObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.NoopObserver.html#torch.quantization.observer.NoopObserver',
                                             'torch.quantization.observer.ObserverBase': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.ObserverBase.html#torch.quantization.observer.ObserverBase',
                                             'torch.quantization.observer.PerChannelMinMaxObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.PerChannelMinMaxObserver.html#torch.quantization.observer.PerChannelMinMaxObserver',
                                             'torch.quantization.observer.PlaceholderObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.PlaceholderObserver.html#torch.quantization.observer.PlaceholderObserver',
                                             'torch.quantization.observer.RecordingObserver': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.RecordingObserver.html#torch.quantization.observer.RecordingObserver',
                                             'torch.quantization.observer.get_observer_state_dict': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.get_observer_state_dict.html#torch.quantization.observer.get_observer_state_dict',
                                             'torch.quantization.observer.load_observer_state_dict': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.load_observer_state_dict.html#torch.quantization.observer.load_observer_state_dict',
                                             'torch.quantization.observer.MinMaxObserver.calculate_qparams': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.MinMaxObserver.html#torch.quantization.observer.MinMaxObserver.calculate_qparams',
                                             'torch.quantization.observer.MinMaxObserver.forward': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.MinMaxObserver.html#torch.quantization.observer.MinMaxObserver.forward',
                                             'torch.quantization.observer.MinMaxObserver.reset_min_max_vals': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.MinMaxObserver.html#torch.quantization.observer.MinMaxObserver.reset_min_max_vals',
                                             'torch.quantization.observer.ObserverBase.with_args': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.ObserverBase.html#torch.quantization.observer.ObserverBase.with_args',
                                             'torch.quantization.observer.ObserverBase.with_callable_args': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.ObserverBase.html#torch.quantization.observer.ObserverBase.with_callable_args',
                                             'torch.quantization.observer.PerChannelMinMaxObserver.reset_min_max_vals': 'https://pytorch.org/docs/stable/generated/torch.quantization.observer.PerChannelMinMaxObserver.html#torch.quantization.observer.PerChannelMinMaxObserver.reset_min_max_vals'},
            'torch.quantization.qconfig': { 'torch.quantization.qconfig.QConfig': 'https://pytorch.org/docs/stable/generated/torch.quantization.qconfig.QConfig.html#torch.quantization.qconfig.QConfig'},
            'torch.quantization.quantize_fx': { 'torch.quantization.quantize_fx.convert_fx': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize_fx.convert_fx.html#torch.quantization.quantize_fx.convert_fx',
                                                'torch.quantization.quantize_fx.fuse_fx': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize_fx.fuse_fx.html#torch.quantization.quantize_fx.fuse_fx',
                                                'torch.quantization.quantize_fx.prepare_fx': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize_fx.prepare_fx.html#torch.quantization.quantize_fx.prepare_fx',
                                                'torch.quantization.quantize_fx.prepare_qat_fx': 'https://pytorch.org/docs/stable/generated/torch.quantization.quantize_fx.prepare_qat_fx.html#torch.quantization.quantize_fx.prepare_qat_fx'},
            'torch.quasirandom': { 'torch.quasirandom.SobolEngine': 'https://pytorch.org/docs/stable/generated/torch.quasirandom.SobolEngine.html#torch.quasirandom.SobolEngine',
                                   'torch.quasirandom.SobolEngine.draw': 'https://pytorch.org/docs/stable/generated/torch.quasirandom.SobolEngine.html#torch.quasirandom.SobolEngine.draw',
                                   'torch.quasirandom.SobolEngine.draw_base2': 'https://pytorch.org/docs/stable/generated/torch.quasirandom.SobolEngine.html#torch.quasirandom.SobolEngine.draw_base2',
                                   'torch.quasirandom.SobolEngine.fast_forward': 'https://pytorch.org/docs/stable/generated/torch.quasirandom.SobolEngine.html#torch.quasirandom.SobolEngine.fast_forward',
                                   'torch.quasirandom.SobolEngine.reset': 'https://pytorch.org/docs/stable/generated/torch.quasirandom.SobolEngine.html#torch.quasirandom.SobolEngine.reset'},
            'torch.torch': { 'torch.torch.device': 'https://pytorch.org/docs/stable/tensor_attributes.html#torch.torch.device',
                             'torch.torch.dtype': 'https://pytorch.org/docs/stable/tensor_attributes.html#torch.torch.dtype',
                             'torch.torch.finfo': 'https://pytorch.org/docs/stable/type_info.html#torch.torch.finfo',
                             'torch.torch.iinfo': 'https://pytorch.org/docs/stable/type_info.html#torch.torch.iinfo',
                             'torch.torch.layout': 'https://pytorch.org/docs/stable/tensor_attributes.html#torch.torch.layout',
                             'torch.torch.memory_format': 'https://pytorch.org/docs/stable/tensor_attributes.html#torch.torch.memory_format'},
            'torch.utils.benchmark': { 'torch.utils.benchmark.CallgrindStats': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.CallgrindStats',
                                       'torch.utils.benchmark.FunctionCounts': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.FunctionCounts',
                                       'torch.utils.benchmark.Measurement': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Measurement',
                                       'torch.utils.benchmark.Timer': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Timer',
                                       'torch.utils.benchmark.CallgrindStats.as_standardized': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.CallgrindStats.as_standardized',
                                       'torch.utils.benchmark.CallgrindStats.counts': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.CallgrindStats.counts',
                                       'torch.utils.benchmark.CallgrindStats.delta': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.CallgrindStats.delta',
                                       'torch.utils.benchmark.CallgrindStats.stats': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.CallgrindStats.stats',
                                       'torch.utils.benchmark.FunctionCounts.denoise': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.FunctionCounts.denoise',
                                       'torch.utils.benchmark.FunctionCounts.filter': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.FunctionCounts.filter',
                                       'torch.utils.benchmark.FunctionCounts.transform': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.FunctionCounts.transform',
                                       'torch.utils.benchmark.Measurement.merge': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Measurement.merge',
                                       'torch.utils.benchmark.Measurement.significant_figures': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Measurement.significant_figures',
                                       'torch.utils.benchmark.Timer.blocked_autorange': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Timer.blocked_autorange',
                                       'torch.utils.benchmark.Timer.collect_callgrind': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Timer.collect_callgrind',
                                       'torch.utils.benchmark.Timer.timeit': 'https://pytorch.org/docs/stable/benchmark_utils.html#torch.utils.benchmark.Timer.timeit'},
            'torch.utils.data': { 'torch.utils.data.BatchSampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.BatchSampler',
                                  'torch.utils.data.ChainDataset': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.ChainDataset',
                                  'torch.utils.data.ConcatDataset': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.ConcatDataset',
                                  'torch.utils.data.DataLoader': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.DataLoader',
                                  'torch.utils.data.Dataset': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.Dataset',
                                  'torch.utils.data.IterableDataset': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.IterableDataset',
                                  'torch.utils.data.RandomSampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.RandomSampler',
                                  'torch.utils.data.Sampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.Sampler',
                                  'torch.utils.data.SequentialSampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.SequentialSampler',
                                  'torch.utils.data.Subset': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.Subset',
                                  'torch.utils.data.SubsetRandomSampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.SubsetRandomSampler',
                                  'torch.utils.data.TensorDataset': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.TensorDataset',
                                  'torch.utils.data.WeightedRandomSampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.WeightedRandomSampler',
                                  'torch.utils.data.default_collate': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.default_collate',
                                  'torch.utils.data.default_convert': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.default_convert',
                                  'torch.utils.data.get_worker_info': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.get_worker_info',
                                  'torch.utils.data.random_split': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.random_split'},
            'torch.utils.data.distributed': { 'torch.utils.data.distributed.DistributedSampler': 'https://pytorch.org/docs/stable/data.html#torch.utils.data.distributed.DistributedSampler'},
            'torch.utils.tensorboard.writer': { 'torch.utils.tensorboard.writer.SummaryWriter': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter',
                                                'torch.utils.tensorboard.writer.SummaryWriter.__init__': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.__init__',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_audio': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_audio',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_custom_scalars': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_custom_scalars',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_embedding': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_embedding',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_figure': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_figure',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_graph': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_graph',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_histogram': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_histogram',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_hparams': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_hparams',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_image': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_image',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_images': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_images',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_mesh': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_mesh',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_pr_curve': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_pr_curve',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_scalar': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_scalar',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_scalars': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_scalars',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_text': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_text',
                                                'torch.utils.tensorboard.writer.SummaryWriter.add_video': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.add_video',
                                                'torch.utils.tensorboard.writer.SummaryWriter.close': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.close',
                                                'torch.utils.tensorboard.writer.SummaryWriter.flush': 'https://pytorch.org/docs/stable/tensorboard.html#torch.utils.tensorboard.writer.SummaryWriter.flush'},
            'torch.autograd.function': { 'torch.autograd.function.FunctionCtx.mark_dirty': 'https://pytorch.org/docs/stable/generated/torch.autograd.function.FunctionCtx.mark_dirty.html#torch.autograd.function.FunctionCtx.mark_dirty',
                                         'torch.autograd.function.FunctionCtx.mark_non_differentiable': 'https://pytorch.org/docs/stable/generated/torch.autograd.function.FunctionCtx.mark_non_differentiable.html#torch.autograd.function.FunctionCtx.mark_non_differentiable',
                                         'torch.autograd.function.FunctionCtx.save_for_backward': 'https://pytorch.org/docs/stable/generated/torch.autograd.function.FunctionCtx.save_for_backward.html#torch.autograd.function.FunctionCtx.save_for_backward',
                                         'torch.autograd.function.FunctionCtx.set_materialize_grads': 'https://pytorch.org/docs/stable/generated/torch.autograd.function.FunctionCtx.set_materialize_grads.html#torch.autograd.function.FunctionCtx.set_materialize_grads'},
            'torch.__config__': { 'torch.__config__.parallel_info': 'https://pytorch.org/docs/stable/__config__.html#torch.__config__.parallel_info',
                                  'torch.__config__.show': 'https://pytorch.org/docs/stable/__config__.html#torch.__config__.show'},
            'torch.ao.ns.fx.utils': { 'torch.ao.ns.fx.utils.compute_cosine_similarity': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns.fx.utils.compute_cosine_similarity',
                                      'torch.ao.ns.fx.utils.compute_normalized_l2_error': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns.fx.utils.compute_normalized_l2_error',
                                      'torch.ao.ns.fx.utils.compute_sqnr': 'https://pytorch.org/docs/stable/torch.ao.ns._numeric_suite_fx.html#torch.ao.ns.fx.utils.compute_sqnr'},
            'torch.autograd.functional': { 'torch.autograd.functional.hessian': 'https://pytorch.org/docs/stable/generated/torch.autograd.functional.hessian.html#torch.autograd.functional.hessian',
                                           'torch.autograd.functional.hvp': 'https://pytorch.org/docs/stable/generated/torch.autograd.functional.hvp.html#torch.autograd.functional.hvp',
                                           'torch.autograd.functional.jacobian': 'https://pytorch.org/docs/stable/generated/torch.autograd.functional.jacobian.html#torch.autograd.functional.jacobian',
                                           'torch.autograd.functional.jvp': 'https://pytorch.org/docs/stable/generated/torch.autograd.functional.jvp.html#torch.autograd.functional.jvp',
                                           'torch.autograd.functional.vhp': 'https://pytorch.org/docs/stable/generated/torch.autograd.functional.vhp.html#torch.autograd.functional.vhp',
                                           'torch.autograd.functional.vjp': 'https://pytorch.org/docs/stable/generated/torch.autograd.functional.vjp.html#torch.autograd.functional.vjp'},
            'torch.backends.cuda': { 'torch.backends.cuda.is_built': 'https://pytorch.org/docs/stable/backends.html#torch.backends.cuda.is_built',
                                     'torch.backends.cuda.preferred_linalg_library': 'https://pytorch.org/docs/stable/backends.html#torch.backends.cuda.preferred_linalg_library'},
            'torch.backends.cudnn': { 'torch.backends.cudnn.is_available': 'https://pytorch.org/docs/stable/backends.html#torch.backends.cudnn.is_available',
                                      'torch.backends.cudnn.version': 'https://pytorch.org/docs/stable/backends.html#torch.backends.cudnn.version'},
            'torch.backends.mkl': {'torch.backends.mkl.is_available': 'https://pytorch.org/docs/stable/backends.html#torch.backends.mkl.is_available'},
            'torch.backends.mkldnn': {'torch.backends.mkldnn.is_available': 'https://pytorch.org/docs/stable/backends.html#torch.backends.mkldnn.is_available'},
            'torch.backends.openmp': {'torch.backends.openmp.is_available': 'https://pytorch.org/docs/stable/backends.html#torch.backends.openmp.is_available'},
            'torch.cuda.comm': { 'torch.cuda.comm.broadcast': 'https://pytorch.org/docs/stable/generated/torch.cuda.comm.broadcast.html#torch.cuda.comm.broadcast',
                                 'torch.cuda.comm.broadcast_coalesced': 'https://pytorch.org/docs/stable/generated/torch.cuda.comm.broadcast_coalesced.html#torch.cuda.comm.broadcast_coalesced',
                                 'torch.cuda.comm.gather': 'https://pytorch.org/docs/stable/generated/torch.cuda.comm.gather.html#torch.cuda.comm.gather',
                                 'torch.cuda.comm.reduce_add': 'https://pytorch.org/docs/stable/generated/torch.cuda.comm.reduce_add.html#torch.cuda.comm.reduce_add',
                                 'torch.cuda.comm.scatter': 'https://pytorch.org/docs/stable/generated/torch.cuda.comm.scatter.html#torch.cuda.comm.scatter'},
            'torch.cuda.nvtx': { 'torch.cuda.nvtx.mark': 'https://pytorch.org/docs/stable/generated/torch.cuda.nvtx.mark.html#torch.cuda.nvtx.mark',
                                 'torch.cuda.nvtx.range_pop': 'https://pytorch.org/docs/stable/generated/torch.cuda.nvtx.range_pop.html#torch.cuda.nvtx.range_pop',
                                 'torch.cuda.nvtx.range_push': 'https://pytorch.org/docs/stable/generated/torch.cuda.nvtx.range_push.html#torch.cuda.nvtx.range_push'},
            'torch.distributed.GradBucket': { 'torch.distributed.GradBucket.buffer': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket.buffer',
                                              'torch.distributed.GradBucket.gradients': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket.gradients',
                                              'torch.distributed.GradBucket.index': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket.index',
                                              'torch.distributed.GradBucket.is_last': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket.is_last',
                                              'torch.distributed.GradBucket.parameters': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket.parameters',
                                              'torch.distributed.GradBucket.set_buffer': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.GradBucket.set_buffer'},
            'torch.distributed.Store': { 'torch.distributed.Store.add': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.add',
                                         'torch.distributed.Store.compare_set': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.compare_set',
                                         'torch.distributed.Store.delete_key': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.delete_key',
                                         'torch.distributed.Store.get': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.get',
                                         'torch.distributed.Store.num_keys': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.num_keys',
                                         'torch.distributed.Store.set': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.set',
                                         'torch.distributed.Store.set_timeout': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.set_timeout',
                                         'torch.distributed.Store.wait': 'https://pytorch.org/docs/stable/distributed.html#torch.distributed.Store.wait'},
            'torch.distributed.algorithms.ddp_comm_hooks.debugging_hooks': { 'torch.distributed.algorithms.ddp_comm_hooks.debugging_hooks.noop_hook': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.debugging_hooks.noop_hook'},
            'torch.distributed.algorithms.ddp_comm_hooks.default_hooks': { 'torch.distributed.algorithms.ddp_comm_hooks.default_hooks.allreduce_hook': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.default_hooks.allreduce_hook',
                                                                           'torch.distributed.algorithms.ddp_comm_hooks.default_hooks.bf16_compress_hook': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.default_hooks.bf16_compress_hook',
                                                                           'torch.distributed.algorithms.ddp_comm_hooks.default_hooks.bf16_compress_wrapper': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.default_hooks.bf16_compress_wrapper',
                                                                           'torch.distributed.algorithms.ddp_comm_hooks.default_hooks.fp16_compress_hook': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.default_hooks.fp16_compress_hook',
                                                                           'torch.distributed.algorithms.ddp_comm_hooks.default_hooks.fp16_compress_wrapper': 'https://pytorch.org/docs/stable/ddp_comm_hooks.html#torch.distributed.algorithms.ddp_comm_hooks.default_hooks.fp16_compress_wrapper'},
            'torch.distributed.elastic.events': { 'torch.distributed.elastic.events.get_logging_handler': 'https://pytorch.org/docs/stable/elastic/events.html#torch.distributed.elastic.events.get_logging_handler',
                                                  'torch.distributed.elastic.events.record': 'https://pytorch.org/docs/stable/elastic/events.html#torch.distributed.elastic.events.record'},
            'torch.distributed.elastic.metrics': { 'torch.distributed.elastic.metrics.configure': 'https://pytorch.org/docs/stable/elastic/metrics.html#torch.distributed.elastic.metrics.configure',
                                                   'torch.distributed.elastic.metrics.prof': 'https://pytorch.org/docs/stable/elastic/metrics.html#torch.distributed.elastic.metrics.prof',
                                                   'torch.distributed.elastic.metrics.put_metric': 'https://pytorch.org/docs/stable/elastic/metrics.html#torch.distributed.elastic.metrics.put_metric'},
            'torch.distributed.rpc.functions': { 'torch.distributed.rpc.functions.async_execution': 'https://pytorch.org/docs/stable/rpc.html#torch.distributed.rpc.functions.async_execution'},
            'torch.distributions.kl': { 'torch.distributions.kl.kl_divergence': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kl.kl_divergence',
                                        'torch.distributions.kl.register_kl': 'https://pytorch.org/docs/stable/distributions.html#torch.distributions.kl.register_kl'},
            'torch.fft': { 'torch.fft.fft': 'https://pytorch.org/docs/stable/generated/torch.fft.fft.html#torch.fft.fft',
                           'torch.fft.fft2': 'https://pytorch.org/docs/stable/generated/torch.fft.fft2.html#torch.fft.fft2',
                           'torch.fft.fftfreq': 'https://pytorch.org/docs/stable/generated/torch.fft.fftfreq.html#torch.fft.fftfreq',
                           'torch.fft.fftn': 'https://pytorch.org/docs/stable/generated/torch.fft.fftn.html#torch.fft.fftn',
                           'torch.fft.fftshift': 'https://pytorch.org/docs/stable/generated/torch.fft.fftshift.html#torch.fft.fftshift',
                           'torch.fft.hfft': 'https://pytorch.org/docs/stable/generated/torch.fft.hfft.html#torch.fft.hfft',
                           'torch.fft.hfft2': 'https://pytorch.org/docs/stable/generated/torch.fft.hfft2.html#torch.fft.hfft2',
                           'torch.fft.hfftn': 'https://pytorch.org/docs/stable/generated/torch.fft.hfftn.html#torch.fft.hfftn',
                           'torch.fft.ifft': 'https://pytorch.org/docs/stable/generated/torch.fft.ifft.html#torch.fft.ifft',
                           'torch.fft.ifft2': 'https://pytorch.org/docs/stable/generated/torch.fft.ifft2.html#torch.fft.ifft2',
                           'torch.fft.ifftn': 'https://pytorch.org/docs/stable/generated/torch.fft.ifftn.html#torch.fft.ifftn',
                           'torch.fft.ifftshift': 'https://pytorch.org/docs/stable/generated/torch.fft.ifftshift.html#torch.fft.ifftshift',
                           'torch.fft.ihfft': 'https://pytorch.org/docs/stable/generated/torch.fft.ihfft.html#torch.fft.ihfft',
                           'torch.fft.ihfft2': 'https://pytorch.org/docs/stable/generated/torch.fft.ihfft2.html#torch.fft.ihfft2',
                           'torch.fft.ihfftn': 'https://pytorch.org/docs/stable/generated/torch.fft.ihfftn.html#torch.fft.ihfftn',
                           'torch.fft.irfft': 'https://pytorch.org/docs/stable/generated/torch.fft.irfft.html#torch.fft.irfft',
                           'torch.fft.irfft2': 'https://pytorch.org/docs/stable/generated/torch.fft.irfft2.html#torch.fft.irfft2',
                           'torch.fft.irfftn': 'https://pytorch.org/docs/stable/generated/torch.fft.irfftn.html#torch.fft.irfftn',
                           'torch.fft.rfft': 'https://pytorch.org/docs/stable/generated/torch.fft.rfft.html#torch.fft.rfft',
                           'torch.fft.rfft2': 'https://pytorch.org/docs/stable/generated/torch.fft.rfft2.html#torch.fft.rfft2',
                           'torch.fft.rfftfreq': 'https://pytorch.org/docs/stable/generated/torch.fft.rfftfreq.html#torch.fft.rfftfreq',
                           'torch.fft.rfftn': 'https://pytorch.org/docs/stable/generated/torch.fft.rfftn.html#torch.fft.rfftn'},
            'torch.hub': { 'torch.hub.download_url_to_file': 'https://pytorch.org/docs/stable/hub.html#torch.hub.download_url_to_file',
                           'torch.hub.get_dir': 'https://pytorch.org/docs/stable/hub.html#torch.hub.get_dir',
                           'torch.hub.help': 'https://pytorch.org/docs/stable/hub.html#torch.hub.help',
                           'torch.hub.list': 'https://pytorch.org/docs/stable/hub.html#torch.hub.list',
                           'torch.hub.load': 'https://pytorch.org/docs/stable/hub.html#torch.hub.load',
                           'torch.hub.load_state_dict_from_url': 'https://pytorch.org/docs/stable/hub.html#torch.hub.load_state_dict_from_url',
                           'torch.hub.set_dir': 'https://pytorch.org/docs/stable/hub.html#torch.hub.set_dir'},
            'torch.linalg': { 'torch.linalg.cholesky': 'https://pytorch.org/docs/stable/generated/torch.linalg.cholesky.html#torch.linalg.cholesky',
                              'torch.linalg.cholesky_ex': 'https://pytorch.org/docs/stable/generated/torch.linalg.cholesky_ex.html#torch.linalg.cholesky_ex',
                              'torch.linalg.cond': 'https://pytorch.org/docs/stable/generated/torch.linalg.cond.html#torch.linalg.cond',
                              'torch.linalg.cross': 'https://pytorch.org/docs/stable/generated/torch.linalg.cross.html#torch.linalg.cross',
                              'torch.linalg.det': 'https://pytorch.org/docs/stable/generated/torch.linalg.det.html#torch.linalg.det',
                              'torch.linalg.diagonal': 'https://pytorch.org/docs/stable/generated/torch.linalg.diagonal.html#torch.linalg.diagonal',
                              'torch.linalg.eig': 'https://pytorch.org/docs/stable/generated/torch.linalg.eig.html#torch.linalg.eig',
                              'torch.linalg.eigh': 'https://pytorch.org/docs/stable/generated/torch.linalg.eigh.html#torch.linalg.eigh',
                              'torch.linalg.eigvals': 'https://pytorch.org/docs/stable/generated/torch.linalg.eigvals.html#torch.linalg.eigvals',
                              'torch.linalg.eigvalsh': 'https://pytorch.org/docs/stable/generated/torch.linalg.eigvalsh.html#torch.linalg.eigvalsh',
                              'torch.linalg.householder_product': 'https://pytorch.org/docs/stable/generated/torch.linalg.householder_product.html#torch.linalg.householder_product',
                              'torch.linalg.inv': 'https://pytorch.org/docs/stable/generated/torch.linalg.inv.html#torch.linalg.inv',
                              'torch.linalg.inv_ex': 'https://pytorch.org/docs/stable/generated/torch.linalg.inv_ex.html#torch.linalg.inv_ex',
                              'torch.linalg.lstsq': 'https://pytorch.org/docs/stable/generated/torch.linalg.lstsq.html#torch.linalg.lstsq',
                              'torch.linalg.lu_factor': 'https://pytorch.org/docs/stable/generated/torch.linalg.lu_factor.html#torch.linalg.lu_factor',
                              'torch.linalg.lu_factor_ex': 'https://pytorch.org/docs/stable/generated/torch.linalg.lu_factor_ex.html#torch.linalg.lu_factor_ex',
                              'torch.linalg.matmul': 'https://pytorch.org/docs/stable/generated/torch.linalg.matmul.html#torch.linalg.matmul',
                              'torch.linalg.matrix_exp': 'https://pytorch.org/docs/stable/generated/torch.linalg.matrix_exp.html#torch.linalg.matrix_exp',
                              'torch.linalg.matrix_norm': 'https://pytorch.org/docs/stable/generated/torch.linalg.matrix_norm.html#torch.linalg.matrix_norm',
                              'torch.linalg.matrix_power': 'https://pytorch.org/docs/stable/generated/torch.linalg.matrix_power.html#torch.linalg.matrix_power',
                              'torch.linalg.matrix_rank': 'https://pytorch.org/docs/stable/generated/torch.linalg.matrix_rank.html#torch.linalg.matrix_rank',
                              'torch.linalg.multi_dot': 'https://pytorch.org/docs/stable/generated/torch.linalg.multi_dot.html#torch.linalg.multi_dot',
                              'torch.linalg.norm': 'https://pytorch.org/docs/stable/generated/torch.linalg.norm.html#torch.linalg.norm',
                              'torch.linalg.pinv': 'https://pytorch.org/docs/stable/generated/torch.linalg.pinv.html#torch.linalg.pinv',
                              'torch.linalg.qr': 'https://pytorch.org/docs/stable/generated/torch.linalg.qr.html#torch.linalg.qr',
                              'torch.linalg.slogdet': 'https://pytorch.org/docs/stable/generated/torch.linalg.slogdet.html#torch.linalg.slogdet',
                              'torch.linalg.solve': 'https://pytorch.org/docs/stable/generated/torch.linalg.solve.html#torch.linalg.solve',
                              'torch.linalg.solve_triangular': 'https://pytorch.org/docs/stable/generated/torch.linalg.solve_triangular.html#torch.linalg.solve_triangular',
                              'torch.linalg.svd': 'https://pytorch.org/docs/stable/generated/torch.linalg.svd.html#torch.linalg.svd',
                              'torch.linalg.svdvals': 'https://pytorch.org/docs/stable/generated/torch.linalg.svdvals.html#torch.linalg.svdvals',
                              'torch.linalg.tensorinv': 'https://pytorch.org/docs/stable/generated/torch.linalg.tensorinv.html#torch.linalg.tensorinv',
                              'torch.linalg.tensorsolve': 'https://pytorch.org/docs/stable/generated/torch.linalg.tensorsolve.html#torch.linalg.tensorsolve',
                              'torch.linalg.vector_norm': 'https://pytorch.org/docs/stable/generated/torch.linalg.vector_norm.html#torch.linalg.vector_norm'},
            'torch.nn.functional': { 'torch.nn.functional.adaptive_avg_pool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.adaptive_avg_pool1d.html#torch.nn.functional.adaptive_avg_pool1d',
                                     'torch.nn.functional.adaptive_avg_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.adaptive_avg_pool2d.html#torch.nn.functional.adaptive_avg_pool2d',
                                     'torch.nn.functional.adaptive_avg_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.adaptive_avg_pool3d.html#torch.nn.functional.adaptive_avg_pool3d',
                                     'torch.nn.functional.adaptive_max_pool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.adaptive_max_pool1d.html#torch.nn.functional.adaptive_max_pool1d',
                                     'torch.nn.functional.adaptive_max_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.adaptive_max_pool2d.html#torch.nn.functional.adaptive_max_pool2d',
                                     'torch.nn.functional.adaptive_max_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.adaptive_max_pool3d.html#torch.nn.functional.adaptive_max_pool3d',
                                     'torch.nn.functional.affine_grid': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.affine_grid.html#torch.nn.functional.affine_grid',
                                     'torch.nn.functional.alpha_dropout': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.alpha_dropout.html#torch.nn.functional.alpha_dropout',
                                     'torch.nn.functional.avg_pool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.avg_pool1d.html#torch.nn.functional.avg_pool1d',
                                     'torch.nn.functional.avg_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.avg_pool2d.html#torch.nn.functional.avg_pool2d',
                                     'torch.nn.functional.avg_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.avg_pool3d.html#torch.nn.functional.avg_pool3d',
                                     'torch.nn.functional.batch_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.batch_norm.html#torch.nn.functional.batch_norm',
                                     'torch.nn.functional.bilinear': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.bilinear.html#torch.nn.functional.bilinear',
                                     'torch.nn.functional.binary_cross_entropy': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.binary_cross_entropy.html#torch.nn.functional.binary_cross_entropy',
                                     'torch.nn.functional.binary_cross_entropy_with_logits': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.binary_cross_entropy_with_logits.html#torch.nn.functional.binary_cross_entropy_with_logits',
                                     'torch.nn.functional.celu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.celu.html#torch.nn.functional.celu',
                                     'torch.nn.functional.conv1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.conv1d.html#torch.nn.functional.conv1d',
                                     'torch.nn.functional.conv2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.conv2d.html#torch.nn.functional.conv2d',
                                     'torch.nn.functional.conv3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.conv3d.html#torch.nn.functional.conv3d',
                                     'torch.nn.functional.conv_transpose1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.conv_transpose1d.html#torch.nn.functional.conv_transpose1d',
                                     'torch.nn.functional.conv_transpose2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.conv_transpose2d.html#torch.nn.functional.conv_transpose2d',
                                     'torch.nn.functional.conv_transpose3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.conv_transpose3d.html#torch.nn.functional.conv_transpose3d',
                                     'torch.nn.functional.cosine_embedding_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.cosine_embedding_loss.html#torch.nn.functional.cosine_embedding_loss',
                                     'torch.nn.functional.cosine_similarity': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.cosine_similarity.html#torch.nn.functional.cosine_similarity',
                                     'torch.nn.functional.cross_entropy': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.cross_entropy.html#torch.nn.functional.cross_entropy',
                                     'torch.nn.functional.ctc_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.ctc_loss.html#torch.nn.functional.ctc_loss',
                                     'torch.nn.functional.dropout': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.dropout.html#torch.nn.functional.dropout',
                                     'torch.nn.functional.dropout2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.dropout2d.html#torch.nn.functional.dropout2d',
                                     'torch.nn.functional.dropout3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.dropout3d.html#torch.nn.functional.dropout3d',
                                     'torch.nn.functional.elu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.elu.html#torch.nn.functional.elu',
                                     'torch.nn.functional.elu_': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.elu_.html#torch.nn.functional.elu_',
                                     'torch.nn.functional.embedding': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.embedding.html#torch.nn.functional.embedding',
                                     'torch.nn.functional.embedding_bag': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.embedding_bag.html#torch.nn.functional.embedding_bag',
                                     'torch.nn.functional.feature_alpha_dropout': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.feature_alpha_dropout.html#torch.nn.functional.feature_alpha_dropout',
                                     'torch.nn.functional.fold': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.fold.html#torch.nn.functional.fold',
                                     'torch.nn.functional.fractional_max_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.fractional_max_pool2d.html#torch.nn.functional.fractional_max_pool2d',
                                     'torch.nn.functional.fractional_max_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.fractional_max_pool3d.html#torch.nn.functional.fractional_max_pool3d',
                                     'torch.nn.functional.gaussian_nll_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.gaussian_nll_loss.html#torch.nn.functional.gaussian_nll_loss',
                                     'torch.nn.functional.gelu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.gelu.html#torch.nn.functional.gelu',
                                     'torch.nn.functional.glu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.glu.html#torch.nn.functional.glu',
                                     'torch.nn.functional.grid_sample': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.grid_sample.html#torch.nn.functional.grid_sample',
                                     'torch.nn.functional.group_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.group_norm.html#torch.nn.functional.group_norm',
                                     'torch.nn.functional.gumbel_softmax': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.gumbel_softmax.html#torch.nn.functional.gumbel_softmax',
                                     'torch.nn.functional.hardshrink': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.hardshrink.html#torch.nn.functional.hardshrink',
                                     'torch.nn.functional.hardsigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.hardsigmoid.html#torch.nn.functional.hardsigmoid',
                                     'torch.nn.functional.hardswish': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.hardswish.html#torch.nn.functional.hardswish',
                                     'torch.nn.functional.hardtanh': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.hardtanh.html#torch.nn.functional.hardtanh',
                                     'torch.nn.functional.hardtanh_': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.hardtanh_.html#torch.nn.functional.hardtanh_',
                                     'torch.nn.functional.hinge_embedding_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.hinge_embedding_loss.html#torch.nn.functional.hinge_embedding_loss',
                                     'torch.nn.functional.huber_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.huber_loss.html#torch.nn.functional.huber_loss',
                                     'torch.nn.functional.instance_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.instance_norm.html#torch.nn.functional.instance_norm',
                                     'torch.nn.functional.interpolate': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.interpolate.html#torch.nn.functional.interpolate',
                                     'torch.nn.functional.kl_div': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.kl_div.html#torch.nn.functional.kl_div',
                                     'torch.nn.functional.l1_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.l1_loss.html#torch.nn.functional.l1_loss',
                                     'torch.nn.functional.layer_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.layer_norm.html#torch.nn.functional.layer_norm',
                                     'torch.nn.functional.leaky_relu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.leaky_relu.html#torch.nn.functional.leaky_relu',
                                     'torch.nn.functional.leaky_relu_': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.leaky_relu_.html#torch.nn.functional.leaky_relu_',
                                     'torch.nn.functional.linear': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.linear.html#torch.nn.functional.linear',
                                     'torch.nn.functional.local_response_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.local_response_norm.html#torch.nn.functional.local_response_norm',
                                     'torch.nn.functional.log_softmax': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.log_softmax.html#torch.nn.functional.log_softmax',
                                     'torch.nn.functional.logsigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.logsigmoid.html#torch.nn.functional.logsigmoid',
                                     'torch.nn.functional.lp_pool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.lp_pool1d.html#torch.nn.functional.lp_pool1d',
                                     'torch.nn.functional.lp_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.lp_pool2d.html#torch.nn.functional.lp_pool2d',
                                     'torch.nn.functional.margin_ranking_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.margin_ranking_loss.html#torch.nn.functional.margin_ranking_loss',
                                     'torch.nn.functional.max_pool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.max_pool1d.html#torch.nn.functional.max_pool1d',
                                     'torch.nn.functional.max_pool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.max_pool2d.html#torch.nn.functional.max_pool2d',
                                     'torch.nn.functional.max_pool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.max_pool3d.html#torch.nn.functional.max_pool3d',
                                     'torch.nn.functional.max_unpool1d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.max_unpool1d.html#torch.nn.functional.max_unpool1d',
                                     'torch.nn.functional.max_unpool2d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.max_unpool2d.html#torch.nn.functional.max_unpool2d',
                                     'torch.nn.functional.max_unpool3d': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.max_unpool3d.html#torch.nn.functional.max_unpool3d',
                                     'torch.nn.functional.mish': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.mish.html#torch.nn.functional.mish',
                                     'torch.nn.functional.mse_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.mse_loss.html#torch.nn.functional.mse_loss',
                                     'torch.nn.functional.multi_margin_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.multi_margin_loss.html#torch.nn.functional.multi_margin_loss',
                                     'torch.nn.functional.multilabel_margin_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.multilabel_margin_loss.html#torch.nn.functional.multilabel_margin_loss',
                                     'torch.nn.functional.multilabel_soft_margin_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.multilabel_soft_margin_loss.html#torch.nn.functional.multilabel_soft_margin_loss',
                                     'torch.nn.functional.nll_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.nll_loss.html#torch.nn.functional.nll_loss',
                                     'torch.nn.functional.normalize': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.normalize.html#torch.nn.functional.normalize',
                                     'torch.nn.functional.one_hot': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.one_hot.html#torch.nn.functional.one_hot',
                                     'torch.nn.functional.pad': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.pad.html#torch.nn.functional.pad',
                                     'torch.nn.functional.pairwise_distance': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.pairwise_distance.html#torch.nn.functional.pairwise_distance',
                                     'torch.nn.functional.pdist': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.pdist.html#torch.nn.functional.pdist',
                                     'torch.nn.functional.pixel_shuffle': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.pixel_shuffle.html#torch.nn.functional.pixel_shuffle',
                                     'torch.nn.functional.pixel_unshuffle': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.pixel_unshuffle.html#torch.nn.functional.pixel_unshuffle',
                                     'torch.nn.functional.poisson_nll_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.poisson_nll_loss.html#torch.nn.functional.poisson_nll_loss',
                                     'torch.nn.functional.prelu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.prelu.html#torch.nn.functional.prelu',
                                     'torch.nn.functional.relu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.relu.html#torch.nn.functional.relu',
                                     'torch.nn.functional.relu6': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.relu6.html#torch.nn.functional.relu6',
                                     'torch.nn.functional.relu_': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.relu_.html#torch.nn.functional.relu_',
                                     'torch.nn.functional.rrelu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.rrelu.html#torch.nn.functional.rrelu',
                                     'torch.nn.functional.rrelu_': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.rrelu_.html#torch.nn.functional.rrelu_',
                                     'torch.nn.functional.selu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.selu.html#torch.nn.functional.selu',
                                     'torch.nn.functional.sigmoid': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.sigmoid.html#torch.nn.functional.sigmoid',
                                     'torch.nn.functional.silu': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.silu.html#torch.nn.functional.silu',
                                     'torch.nn.functional.smooth_l1_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.smooth_l1_loss.html#torch.nn.functional.smooth_l1_loss',
                                     'torch.nn.functional.soft_margin_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.soft_margin_loss.html#torch.nn.functional.soft_margin_loss',
                                     'torch.nn.functional.softmax': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.softmax.html#torch.nn.functional.softmax',
                                     'torch.nn.functional.softmin': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.softmin.html#torch.nn.functional.softmin',
                                     'torch.nn.functional.softplus': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.softplus.html#torch.nn.functional.softplus',
                                     'torch.nn.functional.softshrink': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.softshrink.html#torch.nn.functional.softshrink',
                                     'torch.nn.functional.softsign': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.softsign.html#torch.nn.functional.softsign',
                                     'torch.nn.functional.tanh': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.tanh.html#torch.nn.functional.tanh',
                                     'torch.nn.functional.tanhshrink': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.tanhshrink.html#torch.nn.functional.tanhshrink',
                                     'torch.nn.functional.threshold': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.threshold.html#torch.nn.functional.threshold',
                                     'torch.nn.functional.threshold_': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.threshold_.html#torch.nn.functional.threshold_',
                                     'torch.nn.functional.triplet_margin_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.triplet_margin_loss.html#torch.nn.functional.triplet_margin_loss',
                                     'torch.nn.functional.triplet_margin_with_distance_loss': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.triplet_margin_with_distance_loss.html#torch.nn.functional.triplet_margin_with_distance_loss',
                                     'torch.nn.functional.unfold': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.unfold.html#torch.nn.functional.unfold',
                                     'torch.nn.functional.upsample': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.upsample.html#torch.nn.functional.upsample',
                                     'torch.nn.functional.upsample_bilinear': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.upsample_bilinear.html#torch.nn.functional.upsample_bilinear',
                                     'torch.nn.functional.upsample_nearest': 'https://pytorch.org/docs/stable/generated/torch.nn.functional.upsample_nearest.html#torch.nn.functional.upsample_nearest'},
            'torch.nn.init': { 'torch.nn.init.calculate_gain': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.calculate_gain',
                               'torch.nn.init.constant_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.constant_',
                               'torch.nn.init.dirac_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.dirac_',
                               'torch.nn.init.eye_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.eye_',
                               'torch.nn.init.kaiming_normal_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.kaiming_normal_',
                               'torch.nn.init.kaiming_uniform_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.kaiming_uniform_',
                               'torch.nn.init.normal_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.normal_',
                               'torch.nn.init.ones_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.ones_',
                               'torch.nn.init.orthogonal_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.orthogonal_',
                               'torch.nn.init.sparse_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.sparse_',
                               'torch.nn.init.uniform_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.uniform_',
                               'torch.nn.init.xavier_normal_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.xavier_normal_',
                               'torch.nn.init.xavier_uniform_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.xavier_uniform_',
                               'torch.nn.init.zeros_': 'https://pytorch.org/docs/stable/nn.init.html#torch.nn.init.zeros_'},
            'torch.nn.modules.module': { 'torch.nn.modules.module.register_module_backward_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.module.register_module_backward_hook.html#torch.nn.modules.module.register_module_backward_hook',
                                         'torch.nn.modules.module.register_module_forward_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.module.register_module_forward_hook.html#torch.nn.modules.module.register_module_forward_hook',
                                         'torch.nn.modules.module.register_module_forward_pre_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.module.register_module_forward_pre_hook.html#torch.nn.modules.module.register_module_forward_pre_hook',
                                         'torch.nn.modules.module.register_module_full_backward_hook': 'https://pytorch.org/docs/stable/generated/torch.nn.modules.module.register_module_full_backward_hook.html#torch.nn.modules.module.register_module_full_backward_hook'},
            'torch.nn.utils': { 'torch.nn.utils.clip_grad_norm_': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.clip_grad_norm_.html#torch.nn.utils.clip_grad_norm_',
                                'torch.nn.utils.clip_grad_value_': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.clip_grad_value_.html#torch.nn.utils.clip_grad_value_',
                                'torch.nn.utils.parameters_to_vector': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parameters_to_vector.html#torch.nn.utils.parameters_to_vector',
                                'torch.nn.utils.remove_spectral_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.remove_spectral_norm.html#torch.nn.utils.remove_spectral_norm',
                                'torch.nn.utils.remove_weight_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.remove_weight_norm.html#torch.nn.utils.remove_weight_norm',
                                'torch.nn.utils.skip_init': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.skip_init.html#torch.nn.utils.skip_init',
                                'torch.nn.utils.spectral_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.spectral_norm.html#torch.nn.utils.spectral_norm',
                                'torch.nn.utils.vector_to_parameters': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.vector_to_parameters.html#torch.nn.utils.vector_to_parameters',
                                'torch.nn.utils.weight_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.weight_norm.html#torch.nn.utils.weight_norm'},
            'torch.nn.utils.parametrizations': { 'torch.nn.utils.parametrizations.orthogonal': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrizations.orthogonal.html#torch.nn.utils.parametrizations.orthogonal',
                                                 'torch.nn.utils.parametrizations.spectral_norm': 'https://pytorch.org/docs/stable/generated/torch.nn.utils.parametrizations.spectral_norm.html#torch.nn.utils.parametrizations.spectral_norm'},
            'torch.onnx': { 'torch.onnx.export': 'https://pytorch.org/docs/stable/onnx.html#torch.onnx.export',
                            'torch.onnx.export_to_pretty_string': 'https://pytorch.org/docs/stable/onnx.html#torch.onnx.export_to_pretty_string',
                            'torch.onnx.is_in_onnx_export': 'https://pytorch.org/docs/stable/onnx.html#torch.onnx.is_in_onnx_export',
                            'torch.onnx.register_custom_op_symbolic': 'https://pytorch.org/docs/stable/onnx.html#torch.onnx.register_custom_op_symbolic',
                            'torch.onnx.select_model_mode_for_export': 'https://pytorch.org/docs/stable/onnx.html#torch.onnx.select_model_mode_for_export'},
            'torch.overrides': { 'torch.overrides.get_ignored_functions': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.get_ignored_functions',
                                 'torch.overrides.get_overridable_functions': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.get_overridable_functions',
                                 'torch.overrides.get_testing_overrides': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.get_testing_overrides',
                                 'torch.overrides.handle_torch_function': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.handle_torch_function',
                                 'torch.overrides.has_torch_function': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.has_torch_function',
                                 'torch.overrides.is_tensor_like': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.is_tensor_like',
                                 'torch.overrides.is_tensor_method_or_property': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.is_tensor_method_or_property',
                                 'torch.overrides.wrap_torch_function': 'https://pytorch.org/docs/stable/torch.overrides.html#torch.overrides.wrap_torch_function'},
            'torch.random': { 'torch.random.fork_rng': 'https://pytorch.org/docs/stable/random.html#torch.random.fork_rng',
                              'torch.random.get_rng_state': 'https://pytorch.org/docs/stable/random.html#torch.random.get_rng_state',
                              'torch.random.initial_seed': 'https://pytorch.org/docs/stable/random.html#torch.random.initial_seed',
                              'torch.random.manual_seed': 'https://pytorch.org/docs/stable/random.html#torch.random.manual_seed',
                              'torch.random.seed': 'https://pytorch.org/docs/stable/random.html#torch.random.seed',
                              'torch.random.set_rng_state': 'https://pytorch.org/docs/stable/random.html#torch.random.set_rng_state'},
            'torch.sparse': { 'torch.sparse.addmm': 'https://pytorch.org/docs/stable/generated/torch.sparse.addmm.html#torch.sparse.addmm',
                              'torch.sparse.log_softmax': 'https://pytorch.org/docs/stable/generated/torch.sparse.log_softmax.html#torch.sparse.log_softmax',
                              'torch.sparse.mm': 'https://pytorch.org/docs/stable/generated/torch.sparse.mm.html#torch.sparse.mm',
                              'torch.sparse.sampled_addmm': 'https://pytorch.org/docs/stable/generated/torch.sparse.sampled_addmm.html#torch.sparse.sampled_addmm',
                              'torch.sparse.softmax': 'https://pytorch.org/docs/stable/generated/torch.sparse.softmax.html#torch.sparse.softmax',
                              'torch.sparse.sum': 'https://pytorch.org/docs/stable/generated/torch.sparse.sum.html#torch.sparse.sum'},
            'torch.special': { 'torch.special.digamma': 'https://pytorch.org/docs/stable/special.html#torch.special.digamma',
                               'torch.special.entr': 'https://pytorch.org/docs/stable/special.html#torch.special.entr',
                               'torch.special.erf': 'https://pytorch.org/docs/stable/special.html#torch.special.erf',
                               'torch.special.erfc': 'https://pytorch.org/docs/stable/special.html#torch.special.erfc',
                               'torch.special.erfcx': 'https://pytorch.org/docs/stable/special.html#torch.special.erfcx',
                               'torch.special.erfinv': 'https://pytorch.org/docs/stable/special.html#torch.special.erfinv',
                               'torch.special.exp2': 'https://pytorch.org/docs/stable/special.html#torch.special.exp2',
                               'torch.special.expit': 'https://pytorch.org/docs/stable/special.html#torch.special.expit',
                               'torch.special.expm1': 'https://pytorch.org/docs/stable/special.html#torch.special.expm1',
                               'torch.special.gammainc': 'https://pytorch.org/docs/stable/special.html#torch.special.gammainc',
                               'torch.special.gammaincc': 'https://pytorch.org/docs/stable/special.html#torch.special.gammaincc',
                               'torch.special.gammaln': 'https://pytorch.org/docs/stable/special.html#torch.special.gammaln',
                               'torch.special.i0': 'https://pytorch.org/docs/stable/special.html#torch.special.i0',
                               'torch.special.i0e': 'https://pytorch.org/docs/stable/special.html#torch.special.i0e',
                               'torch.special.i1': 'https://pytorch.org/docs/stable/special.html#torch.special.i1',
                               'torch.special.i1e': 'https://pytorch.org/docs/stable/special.html#torch.special.i1e',
                               'torch.special.log1p': 'https://pytorch.org/docs/stable/special.html#torch.special.log1p',
                               'torch.special.log_softmax': 'https://pytorch.org/docs/stable/special.html#torch.special.log_softmax',
                               'torch.special.logit': 'https://pytorch.org/docs/stable/special.html#torch.special.logit',
                               'torch.special.logsumexp': 'https://pytorch.org/docs/stable/special.html#torch.special.logsumexp',
                               'torch.special.multigammaln': 'https://pytorch.org/docs/stable/special.html#torch.special.multigammaln',
                               'torch.special.ndtr': 'https://pytorch.org/docs/stable/special.html#torch.special.ndtr',
                               'torch.special.ndtri': 'https://pytorch.org/docs/stable/special.html#torch.special.ndtri',
                               'torch.special.polygamma': 'https://pytorch.org/docs/stable/special.html#torch.special.polygamma',
                               'torch.special.psi': 'https://pytorch.org/docs/stable/special.html#torch.special.psi',
                               'torch.special.round': 'https://pytorch.org/docs/stable/special.html#torch.special.round',
                               'torch.special.sinc': 'https://pytorch.org/docs/stable/special.html#torch.special.sinc',
                               'torch.special.softmax': 'https://pytorch.org/docs/stable/special.html#torch.special.softmax',
                               'torch.special.xlog1py': 'https://pytorch.org/docs/stable/special.html#torch.special.xlog1py',
                               'torch.special.xlogy': 'https://pytorch.org/docs/stable/special.html#torch.special.xlogy',
                               'torch.special.zeta': 'https://pytorch.org/docs/stable/special.html#torch.special.zeta'},
            'torch.testing': { 'torch.testing.assert_close': 'https://pytorch.org/docs/stable/testing.html#torch.testing.assert_close',
                               'torch.testing.make_tensor': 'https://pytorch.org/docs/stable/testing.html#torch.testing.make_tensor'},
            'torch.utils.checkpoint': { 'torch.utils.checkpoint.checkpoint': 'https://pytorch.org/docs/stable/checkpoint.html#torch.utils.checkpoint.checkpoint',
                                        'torch.utils.checkpoint.checkpoint_sequential': 'https://pytorch.org/docs/stable/checkpoint.html#torch.utils.checkpoint.checkpoint_sequential'},
            'torch.utils.cpp_extension': { 'torch.utils.cpp_extension.BuildExtension': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.BuildExtension',
                                           'torch.utils.cpp_extension.CUDAExtension': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.CUDAExtension',
                                           'torch.utils.cpp_extension.CppExtension': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.CppExtension',
                                           'torch.utils.cpp_extension.check_compiler_abi_compatibility': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.check_compiler_abi_compatibility',
                                           'torch.utils.cpp_extension.include_paths': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.include_paths',
                                           'torch.utils.cpp_extension.is_ninja_available': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.is_ninja_available',
                                           'torch.utils.cpp_extension.load': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.load',
                                           'torch.utils.cpp_extension.load_inline': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.load_inline',
                                           'torch.utils.cpp_extension.verify_ninja_availability': 'https://pytorch.org/docs/stable/cpp_extension.html#torch.utils.cpp_extension.verify_ninja_availability'},
            'torch.utils.dlpack': { 'torch.utils.dlpack.from_dlpack': 'https://pytorch.org/docs/stable/dlpack.html#torch.utils.dlpack.from_dlpack',
                                    'torch.utils.dlpack.to_dlpack': 'https://pytorch.org/docs/stable/dlpack.html#torch.utils.dlpack.to_dlpack'},
            'torch.utils.mobile_optimizer': { 'torch.utils.mobile_optimizer.optimize_for_mobile': 'https://pytorch.org/docs/stable/mobile_optimizer.html#torch.utils.mobile_optimizer.optimize_for_mobile'},
            'torch.utils.model_zoo': {'torch.utils.model_zoo.load_url': 'https://pytorch.org/docs/stable/model_zoo.html#torch.utils.model_zoo.load_url'}},
  'settings': {'lib_path': 'nbdev_pytorch'}}
